*Stata version: STATA 16.1
*------------------------------------------------------------------------------*
 *World Bank Development Data Group 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Master code
** LAST UPDATE     	Jan 2024
** Market Survey   	Full and Reduced Market Survey Data

*------------------------------------------------------------------------------*
*Make Directory (RUN ONCE Before you begin)
*------------------------------------------------------------------------------*

local path C:\Users\wb551738\OneDrive - WBG\Replication Package //change this path for replication

sysdir set PLUS "`path'\Market Price\0_Do\ado"

*This should only be run the first time you run the code

mkdir "`path'\Market Price\1_Full sample"
mkdir "`path'\Market Price\1_Full sample\Intermediate files"
mkdir "`path'\Market Price\1_Full sample\Output files"


mkdir "`path'\Market Price\2_Reduced sample"
mkdir "`path'\Market Price\2_Reduced sample\Intermediate files"
mkdir "`path'\Market Price\2_Reduced sample\Output files"


mkdir "`path'\Market Price\3_Comparison"
mkdir "`path'\Market Price\3_Comparison\Intermediate files"
mkdir "`path'\Market Price\3_Comparison\Output files"


mkdir "`path'\Market Price\Tables"


*------------------------------------------------------------------------------*
*Directory shortcuts 
*------------------------------------------------------------------------------*

*version 16
set graphics off
set sortseed 5840
	
*local path C:\Users\omoni\Desktop\Replication Package //change this path for replication
local path C:\Users\wb551738\OneDrive - WBG\Replication Package 
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output files"
	gl compInt "$marketsurvey\3_Comparison\Intermediate files"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"


*------------------------------------------------------------------------------*
*******************Full sample replication*****************************************
*------------------------------------------------------------------------------*

gl ddo "`path'\Market Price\0_Do"
*------------------------------------------------------------------------------*
*Cleaning do files
*------------------------------------------------------------------------------*
	
	*--------------------------------------------------------------------------*
	*1) Clean market survey data
	*--------------------------------------------------------------------------*	
	
	do "$ddo\1_OA_MP_marketsurvey_rep.do"
	
	*--------------------------------------------------------------------------*
	*2) Add up food expenditure 
	*--------------------------------------------------------------------------*		
	
	do "$ddo\2_OA_MP_food_rep.do"
	
	
*------------------------------------------------------------------------------*	
*Analysis do files 
*------------------------------------------------------------------------------*	

	*--------------------------------------------------------------------------*
	*3) Create CPIs for expenditure deflation 
	*--------------------------------------------------------------------------*		
	
	do "$ddo\3_OA_MP_price_deflators_rep.do"

*--------------------------------------------------------------------------*

	*3a) Do Price Deflator Regressions
	
	do "$ddo\3a_OA_MP_price_deflators_limited.do"
	do "$ddo\3b_OA_MP_price_deflators_one_to_one.do"
	*3b) Do Price Deflator Regressions
	do "$ddo\3c_OA_MP_pricdeflator_reg_rep.do"
	
*--------------------------------------------------------------------------*
	*4) Add up and harmonize expenditure (Cerate consumption aggregate)
	*--------------------------------------------------------------------------*		
	
	do "$ddo\4_OA_MP_tconsumption_rep.do"
	
	*--------------------------------------------------------------------------*
	*5) Create New poverty and extreme poverty lines
	*--------------------------------------------------------------------------*		
	do "$ddo\5_OA_MP_povline_rep.do"
	do "$ddo\5a_OA_MP_povline_ref group mod_rep.do"
	do "$ddo\5b_OA_MP_povline_1911_calorie_rep.do"
	*--------------------------------------------------------------------------*
	*6) Estimate poverty headcount ratio 
	*--------------------------------------------------------------------------*		
	
	do "$ddo\6_OA_MP_prate_rep.do"
*--------------------------------------------------------------------------*
	*6) Estimate Light and Poverty relationship
	*--------------------------------------------------------------------------*	
	do "$ddo\6a_OA_MP_prate_night lights_rep.do"
	do "$ddo\6b_OA_MP_prate_night lights_rep.do"

		*--------------------------------------------------------------------------*
	*6) Alchain-Allen test for Beef ratio  
	*--------------------------------------------------------------------------*		
	
	do "$ddo\7_OA_MP_Alchain Allan_final_rep.do"

*------------------------------------------------------------------------------*
*******************Reduced sample replication***********************************
*------------------------------------------------------------------------------*
	
*------------------------------------------------------------------------------*
*Cleaning do files
*------------------------------------------------------------------------------*
		*--------------------------------------------------------------------------*
	*1) Clean market survey data
	*--------------------------------------------------------------------------*	
	
	do "$ddo\R1_OA_marketsurvey_rep"
	
	*--------------------------------------------------------------------------*
	*2) Add up food expenditure 
	*--------------------------------------------------------------------------*		
	
	do "$ddo\R2_OA_food_rep.do"
	
	
*------------------------------------------------------------------------------*	
*Analysis do files 
*------------------------------------------------------------------------------*	

	*--------------------------------------------------------------------------*
	*3) Create CPIs for expenditure deflation 
	*--------------------------------------------------------------------------*		
	
	do "$ddo\R3_OA_price_deflators_rep.do"
	
	*--------------------------------------------------------------------------*
	*4) Add up and harmonize expenditure (Cerate consumption aggregate)
	*--------------------------------------------------------------------------*		
	
	do "$ddo\R4_OA_tconsumption_rep.do"
	
	*--------------------------------------------------------------------------*
	*5) Create New poverty and extreme poverty lines
	*--------------------------------------------------------------------------*		
	
	do "$ddo\R5_OA_povline.do"
	
	*--------------------------------------------------------------------------*
	*6) Estimate poverty headcount ration  
	*--------------------------------------------------------------------------*		
	
	*do "$ddo\R6_OA_prate_rep.do"
	
		*-----------------------------------------------------------------------*
	*7)Market summary
	*--------------------------------------------------------------------------*		
	
	do "$ddo\R7_OA_markets_Summary_rep.do"
	
	
	*------------------------------------------------------------------------------*
*******************Comparison replication***********************************
*------------------------------------------------------------------------------*
	
	
*------------------------------------------------------------------------------*	
*Analysis do files 
*------------------------------------------------------------------------------*	
	
	*--------------------------------------------------------------------------*
	*6) Comparing poverty rates
	*--------------------------------------------------------------------------*		
	
	do "$ddo\X6_Comp_povrate_rep.do"
	
	
	
	
*------------------------------------------------------------------------------*
							*Remove files (NEEDED to run code again)
*------------------------------------------------------------------------------*	
*local path C:\Users\omoni\Desktop\Replication Package //change this path for replication


*------------------------------------------------------------------------------*	
* Remove files in Full sample folder	
*------------------------------------------------------------------------------*
	
	foreach folder in Output Intermediate{
	global deldir_int "`path'\Market Price\1_Full sample/`folder' files"
	
	cd "$deldir_int"
	
	local datafiles: dir "$deldir_int" files "*.dta"
		foreach datafile of local datafiles {
        rm `datafile'
			}
		
	local datafiles: dir "$deldir_int" files "*.gph"
		foreach datafile of local datafiles {
        rm `datafile'
			}
		cd  "`path'\UV"
		rmdir "`path'\Market Price\1_Full sample/`folder' files"	

		}
		
*------------------------------------------------------------------------------*	
* Remove files in Reduced sample folder
*------------------------------------------------------------------------------*	


	foreach folder in Output Intermediate{
	global deldir_int "`path'\Market Price\2_Reduced sample/`folder' files"
	
	cd "$deldir_int"
	
	local datafiles: dir "$deldir_int" files "*.dta"
		foreach datafile of local datafiles {
        rm `datafile'
			}
		
	local datafiles: dir "$deldir_int" files "*.gph"
		foreach datafile of local datafiles {
        rm `datafile'
			}
	cd  "`path'\UV"
	rmdir "`path'\Market Price\2_Reduced sample/`folder' files"
			}
			
*------------------------------------------------------------------------------*			
	* Remove files in Comparison sample folder
*------------------------------------------------------------------------------*
	

	foreach folder in Output Intermediate{
	global deldir_int "`path'\Market Price\3_Comparison/`folder' files"
	
	cd "$deldir_int"
	
	local datafiles: dir "$deldir_int" files "*.dta"
		foreach datafile of local datafiles {
        rm `datafile'
			}
		
	local datafiles: dir "$deldir_int" files "*.gph"
		foreach datafile of local datafiles {
        rm `datafile'
			}
			
	local datafiles: dir "$deldir_int" files "*.xlsx"
		foreach datafile of local datafiles {
        rm `datafile'
			}
	cd  "`path'\UV"
	rmdir "`path'\Market Price\3_Comparison/`folder' files"		
			}
	
*------------------------------------------------------------------------------*	
	* Remove Full Sample, Reduced Sample and Comparison folder (If beginning again from the start)
*------------------------------------------------------------------------------*
*local path C:\Users\omoni\Desktop\Replication Package //change this path for replication

		rmdir "`path'\Market Price\1_Full sample"
		rmdir "`path'\Market Price\2_Reduced sample"
		rmdir "`path'\Market Price\3_Comparison"	

* Tables folder which contain results will not be deleted to preserve deletion of replicated results. If running codes multiple times, this can be deleted directly from directory
