*Stata version: STATA 16.1

*------------------------------------------------------------------------------*
** 	 World Bank Data Development Group	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Market Price Survey
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*
*Author: Niyi Alimi 
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*


/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/



*------------------------------------------------------------------------------*
* This do file prepares the IHS market survey and tests for Hicksian Seperability
*------------------------------------------------------------------------------*



	
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
*1. Clean Market Survey Data 
*------------------------------------------------------------------------------*
	use "${MS_Fin}\MOD_A.dta", clear
*Actual Data collection
tab act_mnth_yr_survey mrk_region

*Planned data collection
tab month

//Ideal month of visit
	decode month, gen (ideal_month_survey)
	tab month, miss
	
//Ideal year of visit
	gen ideal_yr_survey = 2019 if inlist(month, 4,5,6,7,8,9,10,11,12)
	replace ideal_yr_survey = 2020 if inlist(month, 13,14,15) //Jan, Feb and Mar coded 13,14, 15 from raw data
	
	//Generate ideal month and year of visit in string format
	generate str ideal_mnth_yr =	substr(ideal_month_survey,1,3)	+ ""	+ string(ideal_yr_survey), after(month)
	tab ideal_mnth_yr, miss

****Generate ideal month and year of visit in Stata date format

//convert to daily to extract month
	gen psuedo_daily = date(ideal_mnth_yr, "MY")
	format psuedo_daily  %td

//convert to monthly
	gen ideal_mnth_yr_survey =mofd(psuedo_daily), after(month)
	format ideal_mnth_yr_survey %tm
	tab ideal_mnth_yr_survey ideal_mnth_yr

tab ideal_mnth_yr_survey mrk_region

*----------------------------------*/
/* Table 1 and Appendix Table A2*/
*----------------------------------*/
label define datelab 711 "Apr 2019" 712 "May 2019"  713 "Jun 2019" 714 "Jul 2019" 715 "Aug 2019"  716 "Sept 2019" 717 "Oct 2019" 718 "Nov 2019"  719 "Dec 2019"  720 "Jan 2020"   721 "Feb 2020"   722 "Mar 2020"   723 "Apr 2020" , replace


*Actual Data collection
tab act_mnth_yr_survey mrk_region

label val act_mnth_yr_survey datelab
tab act_mnth_yr_survey mrk_region
tabout act_mnth_yr_survey mrk_region using "${MS_Tout}\Table1.csv", style(csv) replace

*Planned Data collection
tab ideal_mnth_yr_survey mrk_region

label val ideal_mnth_yr_survey datelab
tab ideal_mnth_yr_survey mrk_region
tabout ideal_mnth_yr_survey mrk_region using"${MS_Tout}\Appendix_TableA2.csv", style(csv) replace

	*------------------------------------------------------------------------------*
	*1a. Classification of TA into urban or rural and creating Urban_region variable
	*------------------------------------------------------------------------------*

	clear all
	set more off
	use "${MS_Fin}\MOD_A.dta", clear
	sort MarketID
	tab mrk_a02a, miss 
	tab mrk_a02b, miss 

	*Check that no duplicate interms of region, TA code, TA name and actual month of survey
			preserve
			contract mrk_region mrk_a02a mrk_a02b act_mnth_yr_survey
			duplicates list mrk_region mrk_a02a mrk_a02b act_mnth_yr_survey // (region, TA_code,TA_name, act_mnth_yr_survey is unique)
			tab  mrk_a02b act_mnth_yr_survey
			restore
			
	*Changing urban/rural classification of some TA (based on discussion with Wilbert)                        
			replace reside = 1 if mrk_a02b == 10620
			replace reside = 2 if mrk_a02b == 31005
			replace reside = 1 if mrk_a02b == 30720
							 
	*Checking consitency of urban-rural status of Market ID						 
	collapse (mean) reside, by( dist_name mrk_a01a mrk_region mrk_a02a mrk_a02b act_mnth_yr_survey) //Confirmed after 0308 email with Wilbert

	tab mrk_region reside
	tab dist_name reside

	*Making naming adjustments to  market in TAcode=10302 where district name has been entered for TA code and vice versa
	tab mrk_a02a if mrk_a01a== 103 //Nkhata Bay is a district name not a TA name. Naming have gotten mixed up

	replace dist_name = "Nkhata Bay" if mrk_a01a== 103 & dist_name ~= "Nkhata Bay"
	replace mrk_a02a = "TA Fukamapiri" if mrk_a01a== 103 & mrk_a02a == "Nkhata Bay"
	tab dist_name reside


	collapse (mean) reside, by( dist_name mrk_a01a mrk_region mrk_a02a mrk_a02b)
	tab reside

		rename reside urban															
		//Urban/rural Identifier
		label var urban "Urban/rural"
		label define region_1 1 North 2 Central 3 South
		label val mrk_region region_1
		gen urban_region = .														
		//Rura/Urban by Region
		replace urban_region = 1 if urban==1
		replace urban_region = 2 if urban==2 & mrk_region==1
		replace urban_region = 3 if urban==2 & mrk_region==2
		replace urban_region = 4 if urban==2 & mrk_region==3
		label var urban_region "Rural/Urban division by region"
		label define urban_region_l 1 "Urban" 2 "Rural North" 3 "Rural Centre" 4 "Rural South"
		label val urban_region urban_region_l
		
*Markets by urban and rural status			
	save "${MS_Fint}\TA_urban_rural", replace

	*------------------------------------------------------------------------------*
	*1b. Merge collected Price and Qty (MOD_D) with market details (MOD_A) with TA classification (TA_urban_rural)
	*------------------------------------------------------------------------------*
	use "${MS_Fin}\MOD_A.dta", clear
	replace dist_name = "Nkhata Bay" if mrk_a01a== 103 & dist_name ~= "Nkhata Bay"
	replace mrk_a02a = "TA Fukamapiri" if mrk_a01a== 103 & mrk_a02a == "Nkhata Bay"

	//Merge Market_details (MOD_A) with TA urban_rural identifier
	merge m:1 dist_name mrk_a02a mrk_a02b  using   "${MS_Fint}\TA_urban_rural" ,keepusing(urban urban_region) 
	drop _merge
			
	//Merge  with prices and qty (MOD_D)
	merge 1:m MarketID MarketID_Visit  using  "${MS_Fin}\MOD_D.dta"
	sort _merge
	tab _merge

	//Generating string month_year and year variables 
	generate act_mnth_str = string(act_mnth_yr, "%tm")
	gen year= substr(act_mnth_str,1,4)

	//Naming needed variables
	clonevar marketid = 	MarketID
	clonevar marketid_visit = 	MarketID_Visit
	clonevar item_avail = 	D01  
	clonevar item_name= 	d1_a 
	clonevar item_code =   	d1_b
	clonevar unit =  		d1_c
	clonevar unit_code =   	d1_d
	clonevar weight1 = 		d1_g
	clonevar price1 = 		d1_h
	clonevar weight2 =		d1_i
	clonevar price2 = 		d1_j
	clonevar weight3 = 		d1_k
	clonevar price3 = 		d1_l
	clonevar item_unit_avail = d1_m
	clonevar region = 		mrk_region
	clonevar district = 	mrk_a01a
	clonevar date =			mrk_a08
	clonevar ta_name = 		mrk_a02a
	clonevar ta_code = 		mrk_a02b

	drop MarketID MarketID_Visit D01 d1_a d1_b d1_c d1_d d1_g d1_h d1_i d1_j d1_k d1_l d1_m mrk_region mrk_a01a mrk_a08 mrk_a09 mrk_a02a mrk_a02b mrk_a06 start_date end_date _merge

	//replace GROUNDNUT ROASTED as ROASTED GROUNDNUT  after conversation with Wilbert
	replace item_name  = "ROASTED GROUNDNUTS"  if item_name =="GROUNDNUT ROASTED"

	*------------------------------------------------------------------------------*
	*1c. Checking consistency of Market Data i.e. one one item_unit combination in each market for each actual month of visit
	/*(Cases where there are multiple visits to the same market in the actual month of visit are collapsed).
	Difference between planned and actual data collection could lead to multiple prices for each actual month*/
	*------------------------------------------------------------------------------*
		sort district marketid act_mnth_yr_survey item_code unit_code
		duplicates tag marketid act_mnth_yr_survey item_code item_name unit_code unit ta_code, gen(dup_id)
		tab dup_id, m
		br if dup_id==1

		tab marketid if dup_id==1

		collapse (mean) weight* price*, by(act_mnth_yr act_mnth_str marketid item_name item_code unit unit_code region district ta_code ta_name dist_name urban_region urban) //Check sensitivity to median

		sort district marketid act_mnth_yr_survey item_code unit_code

		br _all

		tab act_mnth_yr
		
		//Confirm consistency of data. 1 single item-unit combination in each market in each act month of survey
		duplicates tag marketid act_mnth_yr_survey act_mnth_str item_code item_name unit_code unit  region district urban_region urban ta_name ta_code, gen(dup_id)
		tab dup_id, m
		drop dup_id

	//Confirm consistency of region and district
	tab district region, miss

	//Confirm consistency of region and urban-region
	tab urban_region region , miss

	
*------------------------------------------------------------------------------*
*2. Cleaning Price and Weight Data
*------------------------------------------------------------------------------*

	*------------------------------------------------------------------------------*
	*2a. Cleaning Price and Weight Data
	*------------------------------------------------------------------------------*

	//Generate one single prices for each of the 3 possible price observations
	egen single_price = rowmedian(price1 price2 price3) // Use median price of 3 prices
	summ single_price, d
	
	//one extreme value for onion. Seems to be an error. Niyi set to missing
	br if single_price> 300000 & single_price <. 
	replace price1 =. if single_price> 300000 & single_price <.
	replace price3 =. if single_price> 300000 & single_price <.
	replace single_price=. if single_price> 300000 & single_price <.


	//Winsorisation of prices and weights to deal with outliers - Discussed with rest of the team
		*Prices winsorised at the item_code, unit_code and month levels (5th and 95th level).
		*Weights winsorised at the item_code, unit_code and urban_region level (5th and 95th level).  
	winsor2 single_price, suffix(_win2)  by(item_code unit_code  act_mnth_str) cuts (5 95)	
			//counts of proportion of price observations affected by winsorisation
			count if single_price ~=.
			scalar all_raw_price = r(N)
			count if single_price_win2 ~= single_price
			scalar all_winsor_price = r(N)
			scalar prop_winsorised_price = all_winsor_price/all_raw_price 
			di prop_winsorised_price
			
			gen x = 1 if single_price_win2 ~= single_price
			
	winsor2 weight*, suffix(_win2)  by(item_code unit_code  urban_region) cuts (5 95)
						//counts of proportion of weight observations affected by winsorisation
						egen weight_median_raw = rowmedian( weight1 weight2 weight3)


	winsor2 price*, suffix(_win2)  by(item_code unit_code  act_mnth_str) cuts (5 95)	

	//Clean some extreme values in survey weights by comparing with official IHS conversion factor
	
	//With offical IHS conversion factor, largest weight is around 22kg but some items have weights greater than 100KG
	summ weight*_win2, d 

	*These 2 items have implausible weights (cheese and KALONGONDA MUCUNA)
	br if	weight2_win2	>30	&	weight2_win2~=.
	
	*Use plausible weights attached to first price 
	replace weight2_win2 = weight1_win2 if	weight2_win2	>30	&	weight2_win2~=.

	*This item (PIGEONPEA (NANDOLO), FRESH) has implausible weight on third price (372kg)
	br if	weight3_win2	>30	&	weight3_win2~=.
	replace weight3_win2 = weight1_win2 if	weight3_win2	>30	&	weight3_win2~=.

	summ weight*_win2,d 

	br if weight2_win2> 2*weight1_win2 &  weight2_win2~=. //227 Observations where the second weight is twice the first weight

	* Generate median survey weight
	egen weight_median = rowmedian( weight1_win2  weight2_win2 weight3_win2)
			
			//counts of proportion of weight observations affected by winsorisation
			count if weight_median_raw~=.
			scalar all_raw_weight = r(N)

			count if weight_median_raw~=weight_median
			scalar all_winsor_weight = r(N)
			
			scalar prop_winsorised_weight = all_winsor_weight/all_raw_weight
			di prop_winsorised_weight
	
				gen y = 1 if weight_median_raw~=weight_median
				
				egen xy = rowtotal(x y)
				di  16970/133667
				drop  x y 

	*Previously SMALL ANIMAL – RABBIT, MICE, ETC had an implasible weight in this district but new weight cleaning has fixed that
	br if district==206 & item_code=="510"

	
	*Checking if Cleaning Prices and removing of outlier prices
	summ single_price_win2, d
	br if single_price_win2>5440 & single_price_win2<. //checking items with prices in the 99th percentile
	tab unit if single_price_win2>5440 & single_price_win2<. //They seem to be large items - may be plausible

	br if unit=="KILOGRAM" & single_price_win2>5440 & single_price_win2<. //They seem to be items which may be expensive and recorded prices are consistens across multiple price observations

	br if unit=="PIECE" & single_price_win2>2800 & single_price_win2<.
	tab item_name if unit=="PIECE" & single_price_win2>2800 & single_price_win2<. //Where unit is "piece" and it is in the 95th percentile. Plausible as prices are consistent across multiple prices and items


	br if single_price_win2> 15000 & single_price_win2 ~=. // Items with prices in the 90th percentile
	tab unit if single_price_win2> 15000 & single_price_win2 ~=. //Everything greater than 15000 (90th percentile) is Pail Large unit. Plausible


	br _all

	*generate missing prices
	gen miss =1 if single_price_win2 ==.
	tab miss, m

	*------------------------------------------------------------------------------*
	*2b. Merge in official IHS conversion factors
	*------------------------------------------------------------------------------*
		
	*Gen item_code variable for merging with conversion factors
	*Market price data has multiple elementary goods in some case. Conversion factors does not have this so need to create new item_code excluding the multiple elementary coding ( e.g letters - A B C)
	rename item_code item_code_ori // for merging with conversion factors
	gen code3 = substr(item_code_ori,1,3)
	gen x = substr(item_code_ori,4,1)
	tab x
	gen str item_code = code3 + x if inlist(x, "1","2","3")
	replace item_code = code3 if item_code==""
	tab1 item_code item_code_ori if item_code ~= item_code_ori // This is also a tentative list of multiple elementary goods for Hickisan seperability + UFA + Maize Grain + Cooking Oil
	destring item_code, replace
	drop x code3
	
		* Official IHS conversion factors 
			preserve
			use "${MS_Fin}\IHS_Conversion_Factor_2020.dta",clear
			*rename unit_code unit
			drop if unit_code=="23" //Drop other units
			*rename item_code item 
			rename factor_ihs5 factor
			keep region item_code item_name unit_code factor 
			save "${MS_Fint}\IHS_Conversion_Factor_2020_formerge.dta",replace
			restore
			
	*Merge data with official IHS conversion factor
	merge m:1 item_code unit_code region using  "${MS_Fint}\IHS_Conversion_Factor_2020_formerge.dta", keepusing(factor) 
	tab _merge

	*Drop items in official conversion factor file but not in Market survye
	tab item_code_ori if _merge==2
	drop if _merge==2 //items in official conversion factor only

	*replacing unit =1 for 1kg items and 1 litre items
	tab unit if unit_code=="1" 
	replace factor = 1 if unit_code=="1" & missing(factor) // 1 kilogram
	tab	item_code unit	if	unit_code=="15"
	replace factor = 1 if unit_code=="15" & (inlist(item_code,803) | inrange(item_code,850,852)) & missing(factor)	 //1 litre
	
	
	summ weight* price* if factor==.
	tab item_name unit if factor==. & price1~=. //Apart from Condensed Milk (Sachet) All remaining item-unit without conversion factors do not have weight or prices.
	tab item_code item_name if price1 ~=. & factor==.
	replace  factor=0.39 if item_code==711 & unit_code=="22" & _merge==1 & factor==. & single_price_win2 ~=. & inlist(region,1,2) ~=. //condensed milk. Sold in standard Satchet/Tube (22) and available in North and South. Weight is 0.39
	
	br  if price1 ~=. & factor==.

	/* all products with no conversion factor have no prices except for one obs in district (103) where Ground nut being sold in No.10 Plate does not have official conversion factor  */	


	summ factor weight_median,d
	*br if district==206 & item_code_ori=="510"



	br if  factor==. & single_price_win2 ~=.
	//1 change for  Groundnut No.10 Plate with no conversion factor in district 103 in March. Replace official factor with survey factoe
	replace factor = weight_median if factor==. & single_price_win2 ~=. 
	br _all



	summ single_price_win2, d	
	br  _all

		
			
	sort marketid item_code unit_code act_mnth_yr_survey


	*------------------------------------------------------------------------------*
	*2c. Generate actual month and actual year of Data collecion
	*------------------------------------------------------------------------------*
	split act_mnth_str, p(m)
	rename act_mnth_str1 syear
	rename act_mnth_str2 smonth
	destring smonth, replace
	label define month_l 1 January 2 February 3 March 4 April 5 May 6 June 7 July 8 August  9 September 10 October 11 November 12 December
	label val smonth month_l

	*------------------------------------------------------------------------------*
	*2d. Generate KG equivalent prices using survey weights
	*------------------------------------------------------------------------------*
	
	gen kg_equi_price_sw = single_price_win2/weight_median

	summ kg_equi_price_*,d

	br if kg_equi_price_sw >10000 & kg_equi_price_sw ~=.
	tab item_name if kg_equi_price_sw >10000 & kg_equi_price_sw ~=.

	*additional cleaning for some unplausible data in KG equivalent terms
	br if kg_equi_price_sw <=1 //2 observations(sugar-2kg packet and Rice-Large Pail) where  KG_equivalent price is less than 1MK. This is because of errors in price2 and price3 which affects the single(median price).
	
	*Set price2 and price3 to missing
	replace price2_win = . if kg_equi_price <1 & kg_equi_price ~=. 
	replace price3_win = . if kg_equi_price <1 & kg_equi_price ~=.
	replace kg_equi_price_sw = price1_win2/weight1_win2 if kg_equi_price_sw <=1 

	br _all


*------------------------------------------------------------------------------*
*Save KG equivalent prices using survey weights for Hicksian Seperability analysis
*------------------------------------------------------------------------------*
save "${MS_Fint}\kg_equi_price_hicksian_sep", replace



*------------------------------------------------------------------------------*
*3a Examining Missing Data and Imputation
*------------------------------------------------------------------------------*
	use "${MS_Fint}\kg_equi_price_hicksian_sep", clear
	
	label define datelab 711 "Apr 2019" 712 "May 2019"  713 "Jun 2019" 714 "Jul 2019" 715 "Aug 2019"  716 "Sept 2019" 717 "Oct 2019" 718 "Nov 2019"  719 "Dec 2019"  720 "Jan 2020"   721 "Feb 2020"   722 "Mar 2020"   723 "Apr 2020" , replace

	label val act_mnth_yr_survey datelab
	tab act_mnth_yr_survey 
tabout act_mnth_yr_survey using "${MS_Tout}\Appendix_TableA1.csv",  style(csv) replace 

	*------------------------------------------------------------------------------*
	*3a Examining Missing Data
	*------------------------------------------------------------------------------*
	*use "${MS_Fint}\kg_equi_price_hicksian_sep", clear

	drop price* weight* _merge
	drop single_price* factor

	*Proportion missing at item-unit level
	gen missing = cond(kg_equ ==.,1,0)
	tab missing, miss
	
	label define misslab 0 "Non-missing" 1 "Missing", replace
	label val missing misslab
	
	tab missing, miss
	tabout missing using "${MS_Tout}\Appendix_TableA3.csv", style(csv) replace

	*Proportion missing at item level. Median of KG-Equivalent price across KG-equivalent prices
	collapse (median) kg_equi_price_sw, by( marketid item_code_ori  item_name district ta_name ta_code region smonth syear)
	gen missing = cond(kg_equ ==.,1,0)
	tab missing, miss

	label define misslab 0 "Non-missing" 1 "Missing", replace
	label val missing misslab
	
	tab missing, miss
	tabout missing using "${MS_Tout}\Appendix_TableA4.csv", style(csv) replace	
	
	*Proportion of missing item prices at region level
	tab miss region, miss
	tabout miss region using "${MS_Tout}\Appendix_TableA5.csv",style(csv) replace	

	*Proportion of missing item prices at month level
	destring syear, replace
	gen time = ym(syear, smonth)
	label var time "Actual Year and Month of survey, GC"
	format %tm   time
		
	tab time miss, m



	label val time datelab
	tabout time miss  using "${MS_Tout}\Appendix_TableA6.csv", style(csv) replace	

	*------------------------------------------------------------------------------*
	*3b Imputation of Missing Data
	*------------------------------------------------------------------------------*
	*Imputation uses a Cascading median approach.
		*First level is median price in TA
		*Second level is median price in district 

	*First level is the median price in TA	
	egen pr_s1 = median(kg_equi_price_sw), by(smonth syear item_code_ori ta_code ta_name)
	count if kg_equi_price_sw==. & pr_s1 ~=.

	*Second level is the median price in district
	egen pr_s2 = median(kg_equi_price_sw), by(smonth syear item_code_ori district)
	count if kg_equi_price_sw==. & pr_s2~=.

	rename kg_equi_price_sw price_raw

	gen price_imp = price_raw



	*Generating Imputed price and imputed category
	gen imputed = 0 if price_imp~=.
	replace imputed = 1 if price_imp==. & pr_s1 ~=.
	replace price_imp = pr_s1 if price_imp==. & pr_s1 ~=.

	replace imputed = 1 if price_imp==. & pr_s2 ~=.
	replace price_imp = pr_s2 if price_imp==. & pr_s2 ~=.


	drop pr_s* miss

	*Proportion missing of imputed prices at item level
	gen missing = cond(price_imp ==.,1,0)
	tab missing, miss
	
	*Proportion missing of imputed prices at item and region level
	tab missing region, miss
	
	*Proportion missing of imputed prices at item and month level
	tab time missing , miss


	*Proportion from raw data (0), imputed (1) and still missing(.)
	tab imputed, miss
	
	
	
	tab imputed region, miss
	replace imputed = 99 if imputed==.
	label define implab   0 "Actual Survey" 1 "Imputed" 99 "Missing", replace

	label val imputed implab
	tab imputed region
	tabout imputed region using "${MS_Tout}\Appendix_TableA7.csv", style(csv) replace	

	
	
	tab  time imputed , miss
	tabout time imputed using "${MS_Tout}\Appendix_TableA8.csv",style(csv) replace

	
*------------------------------------------------------------------------------*
*4  Hicksian Seperability Analysis
*------------------------------------------------------------------------------*
		
	*------------------------------------------------------------------------------*
	*4a Spatial Hicksian Seperability Preparation
	*For Spatial analysis, we focus on the spatial variation in prices at the district level
	*------------------------------------------------------------------------------*

	use "${MS_Fint}\kg_equi_price_hicksian_sep", clear

	*For Spatial Hicksian analysis, we work at item price level. Collpase item-unit prices to item level
	collapse (median) kg_equi_price_sw, by( item_code_ori  item_name district ta_name ta_code marketid )

	*Imputation of missing prices
		*First level is the median price in TA	
		egen pr_s1 = median(kg_equi_price_sw), by(item_code_ori ta_code ta_name)
		count if kg_equi_price_sw==. & pr_s1 ~=.

		*Second level is the median price in district
		egen pr_s2 = median(kg_equi_price_sw), by(item_code_ori district)
		count if kg_equi_price_sw==. & pr_s2~=.

		rename kg_equi_price_sw price_raw

		gen price_imp = price_raw
		replace price_imp = pr_s1 if price_imp==. & pr_s1 ~=.
		replace price_imp = pr_s2 if price_imp==. & pr_s2 ~=.

		drop pr_s*
		
	*For Spatial Hicksian analysis, we collpase item prices to median at the district level
	collapse (median) price_*, by( item_code_ori  item_name district  marketid )
	sort item_code_ori district  
	
	
*Create list of items with multiple elementary goods for Hicksian Seperability
	gen code3 = substr(item_code_ori,1,3)
	gen x = substr(item_code_ori,4,1)
	tab x
	*drop item_code
	gen str item_code = code3 + x if inlist(x, "1","2","3")
	replace item_code = code3 if item_code==""
	tab1 item_name item_code item_code_ori if item_code ~= item_code_ori //tentative list of multiple elementary goods for Hickisan seperability
	gen hicksian_keep = 1 if item_code ~= item_code_ori | inlist(item_code, "101","102", "103","104","105", "118","119","120") | inlist(item_code, "803", "850", "851", "852")
	keep if hicksian_keep==1 //All possible items based on concordance
	tab item_name
	drop hicksian_keep
	drop code3
	
	*check for duplicates
	duplicates list item_name marketid 

	sort marketid item_code district  

	save "${MS_Fint}\hicks_regression_spatial_070921", replace


	*------------------------------------------------------------------------------*
	*4b Test of Spatial Hicksian Seperability 	
	*------------------------------------------------------------------------------*

	*All  other items apart from MAIZE and Cooking Oil
	use "${MS_Fint}\hicks_regression_spatial_070921", clear
	drop if inlist(item_code_ori,"101", "102", "103","104", "105", "118","119", "120") //Drop all Maize 
	drop if inlist(item_code_ori, "803", "850", "851", "852") //Drop oil


	egen tag = group(x)

	//For Banana
	replace tag=1 if item_code_ori=="602B"
	replace tag=2 if item_code_ori=="602C"
	
	//For chicken
	tab  item_code_ori if item_code=="508"

		replace tag=1 if item_code_ori=="508A"
		replace tag=2 if item_code_ori=="508C"
		replace tag=3 if item_code_ori=="508D"
		replace tag=4 if item_code_ori=="508E"
		replace tag=5 if item_code_ori=="508F"

	tab item_code tag
	sort  marketid item_code  district  tag


	*Gen ln price
	gen ln_price_raw = ln(price_raw)
	gen ln_price_imp = ln(price_imp)

	count if price_raw ~=.
	count if price_imp ~=.

	*save for other goods apart from Maize and Cooking oil
	save "${MS_Fint}\hicks_regression_spatial_070921_others", replace

	*------------------------------------------------------------------------------*
	*4c Spatial Hicksian Regression of all other items apart from MAIZE and Cooking Oil 
	*------------------------------------------------------------------------------*
	use "${MS_Fint}\hicks_regression_spatial_070921_others", clear

	mat DIST_mat = J(18,5,.)
	mat rownames DIST_mat = Maizeflour Rice Bread Buns Cassava IrishPotato PigeonPea Beans Onion ChineseCabbage Eggs Beef Pork  Chicken Banana FreshMilk Sugar CookingOil
	mat colnames DIST_mat = IMP_Fstat IMP_P-value IMP_Rsq IMP_sample_size /*max_sample*/ num_elem 
	matlist DIST_mat

	local r 2
	local c 2

		levelsof item_code, local(item_code_loc)
		foreach i in `item_code_loc' {

		*local i 106
		use "${MS_Fint}\hicks_regression_spatial_070921_others", clear
		keep if item_code=="`i'"
		  
			local  c 1
			  
			
			reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district
			testparm  ib1.tag#ib101.district
			mat DIST_mat[`r',`c'] = r(F)
			local c = `c'+ 1
			mat DIST_mat[`r',`c'] = r(p)
			local c = `c'+ 1
			mat DIST_mat[`r',`c'] = e(r2)
			local c = `c'+ 1
			mat DIST_mat[`r',`c'] = e(N)
			local c = `c'+ 1
			
			count if item_code=="`i'"
			/*
			mat DIST_mat[`r',`c'] = r(N)
			local c = `c'+ 1
			*/
			
			summ tag
			mat DIST_mat[`r',`c'] = r(max)
			local c = `c'+ 1
			
		 matlist DIST_mat
		 local r  = `r'+ 1
		 
			}	

		 matlist DIST_mat
 
	*------------------------------------------------------------------------------*
	*4d Setting up Spatial dataset for Maize flour 
	*------------------------------------------------------------------------------*
	use "${MS_Fint}\hicks_regression_spatial_070921", clear
	keep if inlist(item_code_ori,"101", "102", "103","104", "105", "118","119", "120") //Keep Maize


	sort  marketid item_code district 


	gen ln_price_raw = ln(price_raw)
	gen ln_price_imp = ln(price_imp)

	count if price_raw ~=.
	count if price_imp ~=.

	save "${MS_Fint}\hicks_regression_spatial_070921_maize", replace

	*------------------------------------------------------------------------------*
	*4e Spatial Hicksian regression for Maize flour and cooking oil
	*------------------------------------------------------------------------------*
	*District level for MAIZE flour
 
	use "${MS_Fint}\hicks_regression_spatial_070921_maize", clear


	local r 1
	local c 1


	keep if inlist(item_code_ori, "101", "102", "103","118", "119"/* ,"120"*/) //UFA-Normal, fine, bran processed, bran unprocecces, yellow flour, maizena
	egen tag = group(item_code_ori)

	 
		local r 1
		local c 1
		reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district
		testparm  ib1.tag#ib101.district
		mat DIST_mat[`r',`c'] = r(F)
		local c = `c'+ 1
		mat DIST_mat[`r',`c'] = r(p)
		local c = `c'+ 1
		mat DIST_mat[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat DIST_mat[`r',`c'] = e(N)
		local c = `c'+ 1
		
		summ tag
		
		/*mat DIST_mat[`r',`c'] = r(N)
		local c = `c'+ 1*/
		
		mat DIST_mat[`r',`c'] = r(max)
		local c = `c'+ 1
		
	 
	matlist DIST_mat
 
 
	
	 
	*District level for Cooking oil
 	use "${MS_Fint}\hicks_regression_spatial_070921", clear
	keep if inlist(item_code_ori,"803", "850", "851", "852") //Keep Cooking oil, Sun Flower Oil, Vegetable Oil, Soya bean Oil


	local r 1
	local c 1


	egen tag = group(item_code_ori)
	tab tag item_name
	
	gen ln_price_raw = ln(price_raw)
	gen ln_price_imp = ln(price_imp)

	count if price_raw ~=.
	count if price_imp ~=.

	 
		local r 18
		local c 1
		reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district
		testparm  ib1.tag#ib101.district
		mat DIST_mat[`r',`c'] = r(F)
		local c = `c'+ 1
		mat DIST_mat[`r',`c'] = r(p)
		local c = `c'+ 1
		mat DIST_mat[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat DIST_mat[`r',`c'] = e(N)
		local c = `c'+ 1
		summ tag
		
		/*
		mat DIST_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		
		mat DIST_mat[`r',`c'] = r(max)
		local c = `c'+ 1
	 
	matlist DIST_mat
 

	
*********************************************************************************
*******************************************************************************
	*------------------------------------------------------------------------------*
	*5a Temporal Hicksian Seperability Preparation
	*For Temporal analysis, we focus on the temporal variation in prices at the district level
	*------------------------------------------------------------------------------*
*******************************************************************************
*******************************************************************************
*******************************************************************************
	use "${MS_Fint}\kg_equi_price_hicksian_sep", clear

	drop price* weight* _merge
	drop single_price* factor

	//Temporal Hicksian - we collapse at TA level by month
	collapse (median) kg_equi_price_sw, by( item_code_ori  item_name region urban_region district ta_name ta_code syear smonth marketid )

	//Imputation
	*First level is the median price in TA	
	egen pr_s1 = median(kg_equi_price_sw), by(smonth syear item_code_ori ta_code ta_name)
	count if kg_equi_price_sw==. & pr_s1 ~=.

	*Second level is the median price in district
	egen pr_s2 = median(kg_equi_price_sw), by(smonth syear item_code_ori district)
	count if kg_equi_price_sw==. & pr_s2~=.

	rename kg_equi_price_sw price_raw

	gen price_imp = price_raw
	replace price_imp = pr_s1 if price_imp==. & pr_s1 ~=.
	replace price_imp = pr_s2 if price_imp==. & pr_s2 ~=.

	drop pr_s*

	sort syear smonth  item_code marketid 
	collapse (median) price_*, by( item_code_ori  item_name  district syear smonth marketid )


	//Create items for Hicksian Seperability
	gen code3 = substr(item_code_ori,1,3)
	gen x = substr(item_code_ori,4,1)
	tab x
	*drop item_code
	gen str item_code = code3 + x if inlist(x, "1","2","3")
	replace item_code = code3 if item_code==""
	tab1 item_name item_code item_code_ori if item_code ~= item_code_ori //tentative list of multiple elementary goods for Hickisan seperability
	gen hicksian_keep = 1 if item_code ~= item_code_ori | inlist(item_code, "101","102", "103","104","105", "118","119","120") | inlist(item_code, "803", "850", "851", "852")
	keep if hicksian_keep==1 //All possible items based on concordance

	drop hicksian_keep code3
	duplicates list item_name marketid  syear smonth


	sort syear smonth item_code  marketid  

	save "${MS_Fint}\hicks_regression_temporal_070921", replace


	*------------------------------------------------------------------------------*
	*5b Temporal Hicksian Regression of all other items apart from MAIZE and Cooking Oil 
	*------------------------------------------------------------------------------*
	use "${MS_Fint}\hicks_regression_temporal_070921", clear
	drop if inlist(item_code_ori,"101", "102", "103","104", "105", "118","119", "120") //Drop all Maize
	drop if inlist(item_code_ori, "803", "850", "851", "852") //Drop oil


	egen tag = group( x )
	//For Banana
	replace tag=1 if item_code_ori=="602B"
	replace tag=2 if item_code_ori=="602C"

	//For chicken
	replace tag=1 if item_code_ori=="508A"
	replace tag=2 if item_code_ori=="508C"
	replace tag=3 if item_code_ori=="508D"
	replace tag=4 if item_code_ori=="508E"
	replace tag=5 if item_code_ori=="508F"

	tab item_code tag

	sort  marketid item_code  district  tag


	gen ln_price_raw = ln(price_raw)
	gen ln_price_imp = ln(price_imp)

	count if price_raw ~=.
	count if price_imp ~=.


	//*Generate time ID
	sort syear smonth marketid item_code 
	by syear smonth: gen time_id = 1 if _n==1
	replace time_id = sum(time_id)


	save "${MS_Fint}\hicks_regression_temporal_070921_others", replace

	*------------------------------------------------------------------------------*
	*5c Temporal Hicksian Regressions of all other items apart from MAIZE and Cooking Oil 
	*------------------------------------------------------------------------------*
 
	use "${MS_Fint}\hicks_regression_temporal_070921_others", clear

	mat TEMP_mat = J(18,5,.)
	mat rownames TEMP_mat = Maizeflour Rice Bread Buns Cassava IrishPotato PigeonPea Beans Onion ChineseCabbage Eggs Beef Pork  Chicken Banana FreshMilk Sugar CookingOil
	mat colnames TEMP_mat = IMP_Fstat IMP_P-value IMP_Rsq IMP_sample_size /*max_sample*/ num_elem 
	matlist TEMP_mat

	local r 2
	local c 2

	levelsof item_code, local(item_code_loc)
	foreach i in `item_code_loc' {

	*local i 106
	use "${MS_Fint}\hicks_regression_temporal_070921_others", clear



	keep if item_code=="`i'"
	  
		local  c 1
		  
		 
		reg ln_price_imp ib1.tag ib1.time_id ib1.tag#ib1.time_id
		testparm  ib1.tag#ib1.time_id
		mat TEMP_mat[`r',`c'] = r(F)
		local c = `c'+ 1
		mat TEMP_mat[`r',`c'] = r(p)
		local c = `c'+ 1
		mat TEMP_mat[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat TEMP_mat[`r',`c'] = e(N)
		local c = `c'+ 1
		
		count if item_code=="`i'"
		/*mat TEMP_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		
		summ tag
		mat TEMP_mat[`r',`c'] = r(max)
		local c = `c'+ 1
		
	 matlist TEMP_mat
	local r  = `r'+ 1
	 
		}	

	 matlist TEMP_mat
 
	*------------------------------------------------------------------------------*
	*5d Temporal Hicksian Regressions for MAIZE Flour and Cooking Oil
	*------------------------------------------------------------------------------*
	use "${MS_Fint}\hicks_regression_temporal_070921", clear
	keep if inlist(item_code_ori,"101", "102", "103","104", "105", "118","119", "120") //Keep Maize

	sort  marketid item_code syear smonth /*ta_code urban_region*/ district 

	gen ln_price_raw = ln(price_raw)
	gen ln_price_imp = ln(price_imp)

	count if price_raw ~=.
	count if price_imp ~=.

	//*Generate time ID
	sort syear smonth marketid item_code 
	by syear smonth: gen time_id = 1 if _n==1
	replace time_id = sum(time_id)

	save "${MS_Fint}\hicks_regression_temporal_070921_maize", replace

 
	//District level for MAIZE flour
 	use "${MS_Fint}\hicks_regression_temporal_070921_maize", clear

	keep if inlist(item_code_ori, "101", "102", "103","118", "119" /*, "120"*/)
	egen tag = group(item_code_ori)

	 
	local r 1
	local c 1
	reg ln_price_imp ib1.tag ib1.time_id ib1.tag#ib1.time_id
	testparm  ib1.tag#ib1.time_id
	mat TEMP_mat[`r',`c'] = r(F)
	local c = `c'+ 1
	mat TEMP_mat[`r',`c'] = r(p)
	local c = `c'+ 1
	mat TEMP_mat[`r',`c'] = e(r2)
	local c = `c'+ 1
	mat TEMP_mat[`r',`c'] = e(N)
	local c = `c'+ 1
	summ tag
	/*
	mat TEMP_mat[`r',`c'] = r(N)
	local c = `c'+ 1
	*/
	mat TEMP_mat[`r',`c'] = r(max)
	local c = `c'+ 1
 
 matlist TEMP_mat
 

 
 
 //District level for Cooking Oil
	use "${MS_Fint}\hicks_regression_temporal_070921", clear



	keep if inlist(item_code_ori, "803", "850","851", "852")
	tab item_name
	egen tag = group(item_code_ori)

	gen ln_price_raw = ln(price_raw)
	gen ln_price_imp = ln(price_imp)

	count if price_raw ~=.
	count if price_imp ~=.
	
	//*Generate time ID
	sort syear smonth marketid item_code 
	by syear smonth: gen time_id = 1 if _n==1
	replace time_id = sum(time_id)


		local r 18
		local c 1
		reg ln_price_imp ib1.tag ib1.time_id ib1.tag#ib1.time_id
		testparm  ib1.tag#ib1.time_id
		mat TEMP_mat[`r',`c'] = r(F)
		local c = `c'+ 1
		mat TEMP_mat[`r',`c'] = r(p)
		local c = `c'+ 1
		mat TEMP_mat[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat TEMP_mat[`r',`c'] = e(N)
		local c = `c'+ 1
		summ tag
		/*
		mat TEMP_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		mat TEMP_mat[`r',`c'] = r(max)
		local c = `c'+ 1
	 
	 matlist TEMP_mat
	  
	  
	 matlist TEMP_mat


 
****************************************************************************
****************************************************************************
	*------------------------------------------------------------------------------*
		*6a Temporal Hicksian Seperability over Space and Time Preparation
		* We focus on lean and harvest season
	*-----------------------------------------------------------------------------*
*********************************************************************************

	use  "${MS_Fint}\hicks_regression_temporal_070921", clear

		destring syear,replace
		gen time=ym(syear, smonth)
		label var time "Year and Month of survey, GC"
		format %tm   time
		 
	gen harvest = cond(inlist(time, 711, 712, 713, 714, 715, 716, 723),1,0)
	label define harvestlab 1 "harvest" 0 "lean"
	label val harvest  harvestlab
	 
	 
	save  "${MS_Fint}\hicks_regression_spatio-temporal_070921", replace


	*For other items apart from Maize and Cooking oil
	use  "${MS_Fint}\hicks_regression_spatio-temporal_070921", clear
	drop if inlist(item_code_ori,"101", "102", "103","104", "105", "118","119", "120") | inlist(item_code_ori, "803", "850","851", "852") //Drop all Maize and cooking oil

	egen tag = group( x )
	//For Banana
	replace tag=1 if item_code_ori=="602B"
	replace tag=2 if item_code_ori=="602C"

	//For chicken
	replace tag=1 if item_code_ori=="508A"
	replace tag=2 if item_code_ori=="508C"
	replace tag=3 if item_code_ori=="508D"
	replace tag=4 if item_code_ori=="508E"
	replace tag=5 if item_code_ori=="508F"

	tab item_code tag
	tab item_code_ori harvest

	gen ln_price_imp = ln(price_imp)
	save "${MS_Fint}\hicks_regression_spatio-temporal_070921_others", replace
	 //For all other products apart from MAIZE (Spatio-temporal)
	 
	use "${MS_Fint}\hicks_regression_spatio-temporal_070921_others", clear


	mat SP_TEMP_mat_h = J(18,5,.)
	mat rownames SP_TEMP_mat_h = Maizeflour Rice Bread Buns Cassava IrishPotato PigeonPea Beans Onion ChineseCabbage Eggs Beef Pork  Chicken Banana FreshMilk Sugar CookingOil
	mat colnames SP_TEMP_mat_h = H_Fstat H_P-value H_Rsq H_sample_size /*H_max_sample*/ H_num_elem /*L_Fstat L_P-value L_Rsq L_sample_size /*L_max_sample*/ L_num_elem*/ 
	matlist SP_TEMP_mat_h

	local r 2
	local c 1

	levelsof item_code, local(item_code_loc)
	foreach i in `item_code_loc' {

	*local i 316
	use "${MS_Fint}\hicks_regression_spatio-temporal_070921_others", clear


	keep if item_code=="`i'"
	  
		local  c 1
		  
		 foreach h in 1 /*0*/{
			 *local h 1
		cap reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district if harvest==`h'
		cap testparm  ib1.tag#ib101.district
		mat SP_TEMP_mat_h[`r',`c'] = r(F)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = r(p)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = e(N)
		local c = `c'+ 1
		
		count if item_code=="`i'" & harvest==`h'
		/*mat SP_TEMP_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		summ tag
		mat SP_TEMP_mat_h[`r',`c'] = r(max)
		local c = `c'+ 1
		 }
	 matlist SP_TEMP_mat_h
	local r  = `r'+ 1
	 
		}	

	matlist SP_TEMP_mat_h
 
 //Lean season
 	use "${MS_Fint}\hicks_regression_spatio-temporal_070921_others", clear


	mat SP_TEMP_mat_l = J(15,5,.)
	mat rownames SP_TEMP_mat_l = Maizeflour Rice Bread Buns Cassava IrishPotato PigeonPea /*Beans*/ Onion /*ChineseCabbage*/ Eggs Beef Pork  Chicken Banana /*FreshMilk*/ Sugar CookingOil
	mat colnames SP_TEMP_mat_l = /*H_Fstat H_P-value H_Rsq H_sample_size /*H_max_sample*/ H_num_elem */ L_Fstat L_P-value L_Rsq L_sample_size /*L_max_sample*/ L_num_elem
	matlist SP_TEMP_mat_l

	local r 2
	local c 1

	drop if inlist(item_code, "701","316", "405")
	levelsof item_code, local(item_code_loc)
	foreach i in `item_code_loc' {

	*local i 316
	use "${MS_Fint}\hicks_regression_spatio-temporal_070921_others", clear
	
	drop if inlist(item_code, "701","316","405")

	keep if item_code=="`i'"
	  
		local  c 1
		  
		 foreach h in /*1*/ 0{
			 *local h 1
		cap reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district if harvest==`h'
		cap testparm  ib1.tag#ib101.district
		mat SP_TEMP_mat_l[`r',`c'] = r(F)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = r(p)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = e(N)
		local c = `c'+ 1
		
		count if item_code=="`i'" & harvest==`h'
		/*mat SP_TEMP_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		summ tag
		mat SP_TEMP_mat_l[`r',`c'] = r(max)
		local c = `c'+ 1
		 }
	 matlist SP_TEMP_mat_l
	local r  = `r'+ 1
	 
		}	

	matlist SP_TEMP_mat_l
 
 
  //For Maize
	use  "${MS_Fint}\hicks_regression_spatio-temporal_070921", clear
	keep if inlist(item_code_ori,"101", "102", "103","104", "105", "118","119", "120") //Keep all Maize

	gen ln_price_imp = ln(price_imp)
	save "${MS_Fint}\hicks_regression_spatio-temporal_070921_maize", replace

	//District level for  MAIZE flour
	 use "${MS_Fint}\hicks_regression_spatio-temporal_070921_maize", clear

	
	keep if inlist(item_code_ori, "101", "102", "103","118", "119"/*, "120"*/)
	egen tag = group(item_code_ori)

	 
	local r 1
	local c 1


	 foreach h in 1 /*0*/{
			 *local h 1
		 reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district if harvest==`h'
		 testparm  ib1.tag#ib101.district
		mat SP_TEMP_mat_h[`r',`c'] = r(F)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = r(p)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = e(N)
		local c = `c'+ 1
		
		
		summ tag if harvest==`h'
		/*mat SP_TEMP_mat_maize_fl[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		mat SP_TEMP_mat_h[`r',`c'] = r(max)
		local c = `c'+ 1
		 }
		 
	 matlist SP_TEMP_mat_h
 

	local r 1
	local c 1


	 foreach h in /*1*/ 0{
			 *local h 1
		 reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district if harvest==`h'
		 testparm  ib1.tag#ib101.district
		mat SP_TEMP_mat_l[`r',`c'] = r(F)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = r(p)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = e(N)
		local c = `c'+ 1
		
		
		summ tag if harvest==`h'
		/*mat SP_TEMP_mat_maize_fl[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		mat SP_TEMP_mat_l[`r',`c'] = r(max)
		local c = `c'+ 1
		 }
		 
	 matlist SP_TEMP_mat_l
 	 
	 
	matlist SP_TEMP_mat_h
	matlist SP_TEMP_mat_l

   //For Cooking Oil
	use  "${MS_Fint}\hicks_regression_spatio-temporal_070921", clear
	keep if inlist(item_code_ori,"803", "850", "851","852") //Keep Cooking oil
	egen tag = group(item_code_ori)

	gen ln_price_imp = ln(price_imp)
 
 
	local r 18
	local c 1


	 foreach h in 1 /*0*/{
			 *local h 1
		 reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district if harvest==`h'
		 testparm  ib1.tag#ib101.district
		mat SP_TEMP_mat_h[`r',`c'] = r(F)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = r(p)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat SP_TEMP_mat_h[`r',`c'] = e(N)
		local c = `c'+ 1
		
		summ tag if harvest==`h'
		/*mat SP_TEMP_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		mat SP_TEMP_mat_h[`r',`c'] = r(max)
		local c = `c'+ 1
		 }
		 
	 matlist SP_TEMP_mat_h
 
	local r 15
	local c 1


	 foreach h in /*1*/ 0{
			 *local h 1
		 reg ln_price_imp ib1.tag ib101.district ib1.tag#ib101.district if harvest==`h'
		 testparm  ib1.tag#ib101.district
		mat SP_TEMP_mat_l[`r',`c'] = r(F)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = r(p)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = e(r2)
		local c = `c'+ 1
		mat SP_TEMP_mat_l[`r',`c'] = e(N)
		local c = `c'+ 1
		
		summ tag if harvest==`h'
		/*mat SP_TEMP_mat[`r',`c'] = r(N)
		local c = `c'+ 1
		*/
		mat SP_TEMP_mat_l[`r',`c'] = r(max)
		local c = `c'+ 1
		 }
		 
	 matlist SP_TEMP_mat_l
	 
	 matlist SP_TEMP_mat_h
	 matlist SP_TEMP_mat_l

*-----------------------------------------------------------* * Table 2, 3 and 4
*Output in Excel sheet "$MS_Fout\Hickisan_separabilityresults"
*-----------------------------------------------------------*
 
  putexcel set "$MS_Tout\Table_2_3_4", sheet(Table2) replace 
	  //Spatial
	
	 matlist DIST_mat
putexcel B1 = matrix(DIST_mat), names	
		 
	//Temporal
	  putexcel set "$MS_Tout\Table_2_3_4", sheet(Table3) modify
	 matlist TEMP_mat
putexcel B1 = matrix(TEMP_mat), names	

  putexcel set "$MS_Tout\Table_2_3_4", sheet(Table4) modify 
	 //Spatio-temporal
	 matlist SP_TEMP_mat_h
putexcel B1 = matrix(SP_TEMP_mat_h), names	
putexcel H1 = matrix(SP_TEMP_mat_l), names	

	 putexcel save 
	 putexcel clear
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

// For poverty work, Spatial price indicators and valuation of consumption
foreach v in sw  {
	local v sw
		use "${MS_Fint}\kg_equi_price_hicksian_sep", clear
		*drop weight* price* single_price*

		//item district smonth syear level		
		egen pr_s1 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name district smonth syear)
		count if pr_s1>0 & pr_s1 <.


		//item urban_region smonth syear level
		egen pr_s2 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name urban_region smonth syear)
		count if pr_s2>0 & pr_s2 <.		
				
		//item urban_region level		
		egen pr_s3 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name urban_region )
		count if pr_s3>0 & pr_s3 <.				
				
		//item level	
		egen pr_s4 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name)


		gen price_CD =pr_s1
		replace price_CD = pr_s2 if price_CD==.  & pr_s2 ~=. 
		replace price_CD= pr_s3 if price_CD==. & pr_s3 ~=. 
		replace price_CD = pr_s4 if price_CD==. & pr_s4 ~=. 

		summ price_CD kg_equi_price_sw,d
		br if kg_equi_price_sw==. & pr_s1 ~=.
		drop  pr_s*
		br _all
		
		
	summ price_CD,d

********************************************************************************************************		
*Creating item district prices

save "${MS_Fint}\MP_price_base_`v'.dta", replace
		
use "${MS_Fint}\MP_price_base_`v'.dta", clear		

*Item price by district 
		preserve	
		collapse (median) price_CD, by(item_name item_code_ori item_code urban_region district dist_name region smonth syear)
		sort  syear smonth  urban_region district region dist_name item_code   item_code_ori item_name
		summ price_CD, d
		br if price_CD>10000
			destring syear, replace
			gen time=ym(syear, smonth)                                               
			label var time "Year and Month of survey, GC"
			format %tm   time
		save "${MS_Fint}\MP_item_price_district_`v'.dta", replace
		
*Item price by region		
		collapse (median) price_CD, by(  item_code_ori item_name item_code   urban_region smonth syear)
		sort  syear smonth  urban_region  item_code   item_code_ori item_name
			destring syear, replace
			gen time=ym(syear, smonth)                                               
			label var time "Year and Month of survey, GC"
			format %tm   time
		save "${MS_Fint}\MP_item_price_region_`v'.dta", replace
		restore

		local v sw

use "${MS_Fint}\MP_item_price_district_`v'.dta", clear
drop syear smonth
reshape wide price_CD, i(item_code_ori urban_region district) j(time)		


use "${MS_Fint}\MP_item_price_region_`v'.dta", clear
drop syear smonth
reshape wide price_CD, i(item_code_ori urban_region ) j(time)
	
*------------------------------------------------------------------------------* 
*7) Save median prices by month for CPI 
*------------------------------------------------------------------------------* 
use "${MS_Fint}\MP_price_base_`v'.dta", clear
	
	*--------------------------------------------------------------------------*
	*7.1) At the regional level
	*--------------------------------------------------------------------------*
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD , by(urban_region item_code_ori item_code item_name syear smonth)
	sort urban_region syear smonth item_code_ori
	foreach i in syear smonth price_CD{
	rename `i' `i'_MP
	}
	order urban_region syear smonth item_code_ori
	save "${MS_Fint}\MP_reg_month_`v'", replace
	restore

	*--------------------------------------------------------------------------*
	*7.2) At the national level
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  syear smonth)
	sort  syear smonth item_code_ori
	foreach i in syear smonth price_CD {
	rename `i' `i'_MP
	}
	order  syear smonth item_code_ori item_code	
	save "${MS_Fint}\MP_nat_month_`v'", replace
	restore 
	
	*--------------------------------------------------------------------------*
	*7.3) Item regional
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  urban_region)
	sort   item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code
	save "${MS_Fint}\MP_reg_`v'", replace
	restore 
	
	*--------------------------------------------------------------------------*
	*7.4) Item national
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD , by(item_code_ori item_code item_name )
	sort   item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code	
	save "${MS_Fint}\MP_nat_`v'", replace
	restore 	
	
	
	*--------------------------------------------------------------------------*
	*7.5) Item national reference month
	*--------------------------------------------------------------------------*
	destring syear, replace
	preserve
	keep if inlist(smonth,4,5) & inlist(syear,2019)
	drop if missing(price_CD)
	collapse (p50) price_CD , by(item_code_ori item_code item_name )
	sort  item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code
	save "${MS_Fint}\MP_nat_rm_`v'", replace
	restore 
	

	*--------------------------------------------------------------------------*
	*7.6) Item regional reference month
	*--------------------------------------------------------------------------*
	
	preserve
	keep if inlist(smonth,4,5) & inlist(syear,2019)
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  urban_region)
	sort item_code_ori item_code
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code	
	save "${MS_Fint}\MP_reg_rm_`v'", replace
	restore 
	
	
******************Create concodances between Market survey and IHS**************
use "${MS_Fint}\MP_nat_`v'", clear
cap rename item_code item
//Creating concordances for some items
replace item=102 if inlist(item_code_ori, "119","120") //Maize, yellow flour and Maizena to Ufa,refined flour(IHS)
replace item=301 if inlist(item_code_ori, "316A","316B","316C") //Beans Demetta, Kenyata and spotted to Bean, brown(IHS)
replace item=811 if inlist(item_code_ori, "806","807","808") //Cinnamon, Ginger and curry powder to Spices(IHS)
replace item=803 if inlist(item_code_ori, "850","851","852") //Sun flower, Vegetable and Soya Bean oil to Cooking Oil(IHS)

save "${MS_Fint}\MP_nat_`v'", replace
	
}

	
*Price ratio of normal and Fine UFA for Map	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
	
keep if inlist(item_code, 101,102)	
	
collapse (mean) price_CD, by(district dist_name item_code item_code_ori)

drop item_code_ori

reshape wide price_CD, i(district dist_name) j(item_code)	

gen price_ratio = price_CD101/price_CD102 //Normal divided by Fine

	preserve
	shp2dta using "${MS_Fin}\Other inputs\Shape files\mwi_admbnda_adm2_nso_hotosm_20230405", data("${MS_Fint}\MWI_gph") coor("${MS_Fint}\MWI_coor") genid(n_id) replace
	use "${MS_Fint}\MWI_gph", clear
	gen district = substr(ADM2_PCODE, 3,.)
	destring district, replace
	save "${MS_Fint}\MWI_gph2", replace
	restore

merge 1:1 district using "${MS_Fint}\MWI_gph2"
drop _merge

xtile ratio_status = price_ratio, nq(5)
_pctile price_ratio, nq(5) 

label define ratio_status_lab 1 "Q1: <0.73" 2 "Q2: 0.73-0.75" 3 "Q3: 0.75-0.82" 4"Q4: 0.82-0.86" 5 "Q5: >0.86", replace
label val ratio_status ratio_status_lab
spmap ratio_status using "${MS_Fint}\MWI_coor.dta", id(n_id) clmethod(u) fcolor(Reds2) legend(pos(6) row(2) ring(1) size(*.99)) title ("Ratio of Median Price" "of Normal flour to Fine Flour") saving("${MS_Fint}\PR_MF_normal_fine", replace)

*Price ratio of Medium Grain rice to Broken rice for Map	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
	
keep if inlist(item_code_ori, "106B","106A")	
	
collapse (mean) price_CD, by(district dist_name item_code item_code_ori)

drop item_code

reshape wide price_CD, i(district dist_name) j(item_code_ori) string	

gen price_ratio = price_CD106B/price_CD106A //Medium divided by Broken

	preserve
	shp2dta using "${MS_Fin}\Other inputs\Shape files\mwi_admbnda_adm2_nso_hotosm_20230405", data("${MS_Fint}\MWI_gph") coor("${MS_Fint}\MWI_coor") genid(n_id) replace
	use "${MS_Fint}\MWI_gph", clear
	gen district = substr(ADM2_PCODE, 3,.)
	destring district, replace
	save "${MS_Fint}\MWI_gph2", replace
	restore

merge 1:1 district using "${MS_Fint}\MWI_gph2"
drop _merge

xtile ratio_status = price_ratio, nq(5)
_pctile price_ratio, nq(5) 

label define ratio_status_lab 1 "Q1: <1.08" 2 "Q2: 1.08-1.13" 3 "Q3: 1.13-1.23" 4"Q4: 1.23-1.29" 5 "Q5: >1.29", replace
label val ratio_status ratio_status_lab
spmap ratio_status using "${MS_Fint}\MWI_coor.dta", id(n_id) clmethod(u) fcolor(Greens) legend(pos(6) row(2) ring(1) size(*.99)) title ("Ratio of Median Price" "of Medium Grain Rice to Broken Rice") saving("${MS_Fint}\PR_Rice_Medium_Broken", replace)


*Price ratio of Pigeon Pea for Map	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
	
keep if inlist(item_code_ori, "303B","303A")	
	
collapse (mean) price_CD, by(district dist_name item_code item_code_ori)

drop item_code

reshape wide price_CD, i(district dist_name) j(item_code_ori) string	

gen price_ratio = price_CD303B/price_CD303A //Fresh divided by Dry

	preserve
	shp2dta using "${MS_Fin}\Other inputs\Shape files\mwi_admbnda_adm2_nso_hotosm_20230405", data("${MS_Fint}\MWI_gph") coor("${MS_Fint}\MWI_coor") genid(n_id) replace
	use "${MS_Fint}\MWI_gph", clear
	gen district = substr(ADM2_PCODE, 3,.)
	destring district, replace
	save "${MS_Fint}\MWI_gph2", replace
	restore

merge 1:1 district using "${MS_Fint}\MWI_gph2"
drop _merge

xtile ratio_status = price_ratio, nq(5)
_pctile price_ratio, nq(5) 
return list

label define ratio_status_lab 1 "Q1: <0.63" 2 "Q2: 0.63-0.77" 3 "Q3: 0.77-0.83" 4"Q4: 0.83-0.93" 5 "Q5: >0.93", replace
label val ratio_status ratio_status_lab
spmap ratio_status using "${MS_Fint}\MWI_coor.dta", id(n_id) clmethod(u) fcolor(Blues) legend(pos(6) row(2) ring(1) size(*.99)) title ("Ratio of Median Price" "of Fresh Pigeon Pea to Dry Pigeon Pea") saving("${MS_Fint}\PR_PP_Fresh_Dry", replace)

*Price ratio of Eggs Hybrid to Eggs Local for Map	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
	
keep if inlist(item_code_ori, "501B","501A")	
	
collapse (mean) price_CD, by(district dist_name item_code item_code_ori)

drop item_code

reshape wide price_CD, i(district dist_name) j(item_code_ori) string	

gen price_ratio = price_CD501B/price_CD501A //Hybrid divided by Local

	preserve
	shp2dta using "${MS_Fin}\Other inputs\Shape files\mwi_admbnda_adm2_nso_hotosm_20230405", data("${MS_Fint}\MWI_gph") coor("${MS_Fint}\MWI_coor") genid(n_id) replace
	use "${MS_Fint}\MWI_gph", clear
	gen district = substr(ADM2_PCODE, 3,.)
	destring district, replace
	save "${MS_Fint}\MWI_gph2", replace
	restore

merge 1:1 district using "${MS_Fint}\MWI_gph2"
drop _merge

xtile ratio_status = price_ratio, nq(5)
_pctile price_ratio, nq(5) 

return list

label define ratio_status_lab 1 "Q1: < 0.77" 2 "Q2: 0.77-0.79" 3 "Q3:0.79-0.82" 4"Q4: 0.82-0.85" 5 "Q5: > 0.85", replace
label val ratio_status ratio_status_lab
spmap ratio_status using "${MS_Fint}\MWI_coor.dta", id(n_id) clmethod(u) fcolor(Purples) legend(pos(6) row(2) ring(1) size(*.99)) title ("Ratio of Median Price" "of Hybrid Eggs to Local Eggs") saving("${MS_Fint}\PR_Eggs_Hybrid_Local", replace)

*Price ratio of Sugar Brown to Sugar White for Map	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
	
keep if inlist(item_code_ori, "801B","801A")	
	
collapse (mean) price_CD, by(district dist_name item_code item_code_ori)

drop item_code

reshape wide price_CD, i(district dist_name) j(item_code_ori) string	

gen price_ratio = price_CD801B/price_CD801A //Brown Sugar divided by White

	preserve
	shp2dta using "${MS_Fin}\Other inputs\Shape files\mwi_admbnda_adm2_nso_hotosm_20230405", data("${MS_Fint}\MWI_gph") coor("${MS_Fint}\MWI_coor") genid(n_id) replace
	use "${MS_Fint}\MWI_gph", clear
	gen district = substr(ADM2_PCODE, 3,.)
	destring district, replace
	save "${MS_Fint}\MWI_gph2", replace
	restore

merge 1:1 district using "${MS_Fint}\MWI_gph2"
drop _merge

xtile ratio_status = price_ratio, nq(5)
_pctile price_ratio, nq(5) 

return list

label define ratio_status_lab 1 "Q1: <0.45" 2 "Q2: 0.45-0.54" 3 "Q3: 0.54-0.73" 4"Q4: 0.73-0.96" 5 "Q5: >0.96", replace
label val ratio_status ratio_status_lab
spmap ratio_status using "${MS_Fint}\MWI_coor.dta", id(n_id) clmethod(u) fcolor(Blues2) legend(pos(6) row(2) ring(1) size(*.99)) title ("Ratio of Median Price" "of Brown Sugar to White Sugar") saving("${MS_Fint}\PR_Sugar_Brown_White", replace)

*Price ratio of Soya Bean Oil to Vegetable Oil for Map	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
	
keep if inlist(item_code_ori, "852","851")	
	
collapse (mean) price_CD, by(district dist_name item_code item_code_ori)

drop item_code

reshape wide price_CD, i(district dist_name) j(item_code_ori) string	

gen price_ratio = price_CD852/price_CD851 //Soya Bean oil divided Vegetable Oil

	preserve
	shp2dta using "${MS_Fin}\Other inputs\Shape files\mwi_admbnda_adm2_nso_hotosm_20230405", data("${MS_Fint}\MWI_gph") coor("${MS_Fint}\MWI_coor") genid(n_id) replace
	use "${MS_Fint}\MWI_gph", clear
	gen district = substr(ADM2_PCODE, 3,.)
	destring district, replace
	save "${MS_Fint}\MWI_gph2", replace
	restore

merge 1:1 district using "${MS_Fint}\MWI_gph2"
drop _merge

xtile ratio_status = price_ratio, nq(5)
_pctile price_ratio, nq(5) 

return list

label define ratio_status_lab 1 "Q1: <0.90" 2 "Q2: 0.90-0.93" 3 "Q3: 0.93-0.97" 4"Q4: 0.97-1.1" 5 "Q5: >1.1", replace
label val ratio_status ratio_status_lab
spmap ratio_status using "${MS_Fint}\MWI_coor.dta", id(n_id) clmethod(u) fcolor(Reds2) legend(pos(6) row(2) ring(1) size(*.99)) title ("Ratio of Median Price" "of Soya Bean oil to Vegetable oil") saving("${MS_Fint}\PR_Oil_Soya_Vegetable", replace)

*-----------------------------------------------------------*
*Figure 1 : Price ratio of selected food items across districts in Malawi
*-----------------------------------------------------------*
gr combine "${MS_Fint}\PR_MF_normal_fine" "${MS_Fint}\PR_Rice_Medium_Broken" "${MS_Fint}\PR_PP_Fresh_Dry" "${MS_Fint}\PR_Eggs_Hybrid_Local" "${MS_Fint}\PR_Sugar_Brown_White" "${MS_Fint}\PR_Oil_Soya_Vegetable", col(3) iscale(*.75) scheme( s2color) saving("${MS_Tout}\Figure1", replace)
