*------------------------------------------------------------------------------*
** 	 World Bank Data Development Group	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			One to One goods Price Deflators based on Unit values and market prices
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*
*Author: Niyi Alimi 
*-----------------------------------------------------------------------------
*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
*Directory shortcuts
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/
*------------------------------------------------------------------------------*
*1) Calculate food budget shares/weights for all items using  market price and Unit value IHS5 food dataset
*------------------------------------------------------------------------------*
 local ic 100
*foreach ic in 50 60 70 80 90 100{
*foreach v in sw  { 
    local v sw
	 *local ic 100
 use "$MS_Fout\OA_food_ihs5_MP_UV_`v'_FM_`ic'", clear
	merge m:1 HHID using "$dout\basicvars_ihs5.dta",nogen   
	drop if inrange(item,913,915) | inlist(item,908) | inlist(item,911)
	drop value_UV_*  value_CD2_*  reported_value
	
	save "$MS_Fint\OA_food_ihs5_MP_UV_temp_`v'", replace
	
	foreach f in UV CD2{
	 *local v sw
	 *local f UV
	use "$MS_Fint\OA_food_ihs5_MP_UV_temp_`v'", clear
	preserve
	keep HHID item urban_region time value_`f' ea_id district TA region urban sdate smonth syear hhsize adulteq hh_wgt
	bys HHID: egen tfoodexp=total(value)                                
	gen share=value/tfoodexp                //Household Budget Share for Demand elasticities. Use UV budget share           
	save "$MS_Fint\food_share_stat_`f'_`v'", replace //Household Budget Share for Demand elasticities. Use UV budget share    

	collapse (mean) sharemean=share (p99) share99=share (p95) share95=share (p50) sharemedian=share [aw=hh_wgt], by(item urban_region)
	save "$MS_Fint\food_share_stat_urbr_`f'_`v'", replace
	restore
		
	keep HHID value_`f'  urban_region urban item hh_wgt hhsize
	drop if item==.
	reshape wide value_`f',i(HHID) j(item)
	reshape long value_`f', i(HHID) j(item)
	save "$MS_Fint\food_ihs5_reshaped_`f'_`v'", replace  			  
	replace value=0 if value==.
	bys HHID: egen tfoodexp=total(value) 
	gen share=value/tfoodexp 
	
	merge m:1 item urban_region using "$MS_Fint\food_share_stat_urbr_`f'_`v'"
	replace share=share95 if share >share95 
	drop if _merge==2
	drop _merge
	save "$MS_Fint\food_ihs5_share_`f'_`v'", replace
	
	preserve
	collapse (mean) share [aw=hh_wgt], by(urban_region item) 
	save "$MS_Fint\share_ihs5_`f'_`v'", replace  			         
	restore
	
	preserve
	collapse (mean) share [aw=hh_wgt], by(item)  
	save "$MS_Fint\share_ihs5_nat_`f'_`v'", replace 
	restore
}

*------------------------------------------------------------------------------*
*Comparison of budget share from unit value and market price valuation
*------------------------------------------------------------------------------*
	preserve
	local v sw
	*Comparison of budget share (Unit values vs Market Prices)- urban-region level
	use "$MS_Fint\share_ihs5_UV_`v'", clear
	mmerge item urban_region  using "$dout\share_ihs5", type(1:1) uname(ori_)
	mmerge item urban_region  using "$MS_Fint\share_ihs5_CD2_`v'", type(1:1) uname(MP_)

	sort urban_region item

	drop _merge
	reshape wide share ori_share MP_share, i(item) j(urban_region)
	order share* ori_share* MP_share*, after(item)

	reshape long share ori_share MP_share, i(item) j(urban_region)
	sort urban_region item

	local v sw
	*Comparison of budget share (Unit values vs Market Prices)- National
	use "$MS_Fint\share_ihs5_nat_UV_`v'", clear
	mmerge item  using "$dout\share_ihs5_nat", type(1:1) uname(ori_)
	mmerge item  using "$MS_Fint\share_ihs5_nat_CD2_`v'", type(1:1) uname(MP_)	
	restore	
	
	
*------------------------------------------------------------------------------* 
*15) Save median prices by month for CPI from market price data
*------------------------------------------------------------------------------* 
local v sw
use "${MS_Fint}\MP_price_base_`v'.dta", clear
	destring syear,replace

*--------------------------------------------------------------------------*
	*15.1) At the District level
	*--------------------------------------------------------------------------*
	preserve
	drop if missing(price_CD)

	collapse (p50) price_CD , by(urban_region district item_code_ori item_code item_name syear smonth)
	sort urban_region syear smonth item_code_ori
	foreach i in syear smonth price_CD{
	rename `i' `i'_MP
	}
	order urban_region syear smonth item_code_ori
	
	destring syear,replace
	gen time=ym(syear, smonth)
	label var time "Year and Month of survey, GC"
	format %tm   time
	drop syear smonth /*_merge*/
	
	save "${MS_Fint}\MP_reg_dist_month_`v'", replace
	restore

	*--------------------------------------------------------------------------*
	*15.2) At the national level
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)

	collapse (p50) price_CD, by(item_code_ori item_code item_name  syear smonth)
	sort  syear smonth item_code_ori
	foreach i in syear smonth price_CD {
	rename `i' `i'_MP
	}
	order  syear smonth item_code_ori item_code	
	save "${MS_Fint}\MP_nat_dist_month_`v'", replace
	restore 
	
	*--------------------------------------------------------------------------*
	*15.3) Item District
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  district urban_region)
	sort   item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code
		
	save "${MS_Fint}\MP_reg_dist_`v'", replace
	restore 
	
	*--------------------------------------------------------------------------*
	*15.4) Item national
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name )
	sort   item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code	
	save "${MS_Fint}\MP_nat_`v'", replace
	restore 	
	
	
	*--------------------------------------------------------------------------*
	*15.6) Item national reference month
	*--------------------------------------------------------------------------*
	*destring syear, replace
	preserve
	keep if inlist(smonth,4,5) & inlist(syear,2019)
	drop if missing(price_CD)
	collapse (p50) price_CD , by(item_code_ori item_code item_name )
	sort  item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code
	save "${MS_Fint}\MP_nat_rm_`v'", replace
	restore 
	

	*--------------------------------------------------------------------------*
	*15.7) Item regional reference month
	*--------------------------------------------------------------------------*
	
	preserve
	keep if inlist(smonth,4,5) & inlist(syear,2019)
	drop if missing(price_CD)

	collapse (p50) price_CD, by(item_code_ori item_code item_name  urban_region)
	sort item_code_ori item_code
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code	
	save "${MS_Fint}\MP_reg_dist_rm_`v'", replace
	restore 
	
	
******************Create concodances between Market survey and IHS for national prices**************
use "${MS_Fint}\MP_nat_`v'", clear
cap rename item_code item
//Creating concordances for some items
replace item=102 if inlist(item_code_ori, "119","120") //Maize, yellow flour and Maizena to Ufa,refined flour(IHS)
replace item=301 if inlist(item_code_ori, "316A","316B","316C") //Beans Demetta, Kenyata and spotted to Bean, brown(IHS)
replace item=811 if inlist(item_code_ori, "806","807","808") //Cinnamon, Ginger and curry powder to Spices(IHS)
replace item=803 if inlist(item_code_ori, "850","851","852") //Sun flower, Vegetable and Soya Bean oil to Cooking Oil(IHS)

save "${MS_Fint}\MP_nat_`v'", replace





*********************************************************************
**********Rectangularisation of market prices for each month***********************************************************
*********************************************************************
*********************************************************************
*local v sw

use "${MS_Fint}\MP_reg_dist_month_`v'", clear
drop if urban_region==.
*destring syear, replace
sort urban_region item_code_ori time



drop item_code /*item*/
	reshape wide price_CD_MP, i(urban_region district item_code_ori) j(time)
	reshape long price_CD_MP, i(urban_region district item_code_ori) j(time) 
	rename price_CD_MP price_CD
	foreach i in CD{
	    *local i CD
			egen pr_s2_`i' = median(price_`i'), by(item_code_ori district time)
			
			/*/item urban_region level*/
			egen pr_s3_`i' = median(price_`i'), by(item_code_ori urban_region time)
			
			/*/item urban_region level*/
			egen pr_s4_`i' = median(price_`i'), by(item_code_ori urban_region)
			
			/*/item  level*/
			egen pr_s5_`i' = median(price_`i'), by(item_code_ori)
			
			gen price_`i'2 =price_`i'

			 local i CD		
			replace price_`i'2 = pr_s2_`i' if price_`i'2==. & pr_s2_`i' ~=. 
			replace price_`i'2 = pr_s3_`i' if price_`i'2==. & pr_s3_`i' ~=. 
			replace price_`i'2 = pr_s4_`i' if price_`i'2==. & pr_s4_`i' ~=. //0 real changes should be made
			replace price_`i'2 = pr_s5_`i' if price_`i'2==. & pr_s5_`i' ~=. //0 real changes should be made
}
	
keep urban_region district item_code time price_CD price_CD2 

save "${MS_Fint}\MP_reg_dist_month_rect_4merge_`v'", replace

reshape wide price_CD  price_CD2, i(urban_region district item_code_ori) j(time)


*------------------------------------------------------------------------------*
*2) Calulate temporal food CPI within IHS-5 survey period using market prices (raw and imputed)
*Closely follows approach from unit value method by poverty GP
*------------------------------------------------------------------------------*
	
	foreach var in price_CD  price_CD2{
	egen rm`var'=rowmean(`var'711 `var'712)

	gen r`var'711=1	
		
	forval i= 712/723 {
	gen r`var'`i'=(`var'`i'/rm`var')                         
	replace r`var'`i'=r(p95) if r`var'`i'>=r(p95) & r`var'`i'!=.     
		}
										}
	
*Creating item code from multiple elementary items	
	gen code3 = substr(item_code_ori,1,3)
	gen x = substr(item_code_ori,4,1)
	tab x
	gen str item_code = code3 + x if inlist(x, "1","2","3")
	replace item_code = code3 if item_code==""
	tab1 item_code item_code_ori if item_code ~= item_code_ori //tentative list of multiple elementary goods for Hickisan seperability+ UFA
	destring item_code, replace
	drop x code3	
	
//Creating concordances for some items
replace item_code=102 if inlist(item_code_ori, "119","120") //Maize, yellow flour and Maizena to Ufa,refined flour(IHS)
replace item_code=301 if inlist(item_code_ori, "316A","316B","316C") //Beans Demetta, Kenyata and spotted to Bean, brown(IHS)
replace item_code=811 if inlist(item_code_ori, "806","807","808") //Cinnamon, Ginger and curry powder to Spices(IHS)
replace item_code=803 if inlist(item_code_ori, "850","851","852") //Sun flower, Vegetable and Soya Bean oil to Cooking Oil(IHS)
	
	

reshape long rprice_CD rprice_CD2 , i(urban_region item_code_ori district) j(time)

  
	drop if urban_region==.
	*tempfile test
	
	save "${MS_Fint}\MP_reg_dist_month_rect_`v'", replace
	
**********************************************************************************
*2a) USing geometric mean of price relativities for items with multiple elementary products
***********************************************************************************

local v sw	
foreach var in price_CD  price_CD2 {	
	  *local v sw
	  *local var price_CD2
	  use "${MS_Fint}\MP_reg_dist_month_rect_`v'", replace
		drop if r`var'==. 
		egen r`var'_gmean = gmean(r`var'), by(urban_region time item_code)
		egen r`var'_temp = mean(r`var'), by(urban_region time item_code)

		collapse (mean) r`var'*, by(urban_region time item_code) //arithmetic mean
	
	//check
	br if r`var'  ~= r`var'_temp
	count if r`var' ~= r`var'_temp
	br _all
	drop r`var'_temp
	
replace	r`var'= r`var'_gmean if  inlist(item, 102, 106, 111, 112, 201, 205, 301, 303, 401, 405, 501, 504, 506, 508, 602, 701, 801, 803, 811) // Change price relativities from arithmentic to geometric mean of multiple elementary groups 

	
	
	tempfile rprices_`var'
	save `rprices_`var''
				}

				
//Merge price relativities based on raw data with that based on imputed data				
use `rprices_price_CD', clear
merge 1:1 urban_region item_code  time  using `rprices_price_CD2'
drop _m

	//Check codes with IHS using item names
		preserve
		use "$MS_Fint\share_ihs5_nat_CD2_`v'", clear	
		decode item, gen (item_name_str)
		summ share
		di r(sum)
		gen tot = r(sum)

		gen share_pct = (share/tot)*100
		save "${MS_Fint}\item_shr_pct_CD2_`v'", replace
		restore
	
gen item= item_code	
merge m:1 item using "${MS_Fint}\item_shr_pct_CD2_`v'", keepusing(item_name_str)
sort _merge
tab item_name_str if _merge==2
tab item if _merge==2

drop if _merge==2	//Other items in IHS not collected in Market survey***
tab item if _merge==1
drop if _merge==1	//Condensed Milk (711)*Only in Market and not in IHS*************


save "${MS_Fint}\price_relatives_MP_new_imp_`v'", replace


local v sw
*------------------------------------------------------------------------------*
*2b) Merge with budget shares
*------------------------------------------------------------------------------*
use "${MS_Fint}\price_relatives_MP_new_imp_`v'", clear
sort urban_region time item	
tab item urban_region
	
	preserve
	*local v sw
	use "$MS_Fint\share_ihs5_CD2_`v'" , clear
	decode item, gen(S_item_name)
	tempfile item_sh
	save `item_sh'
	restore
	
	
mmerge  urban_region item using `item_sh', ukeep(share S_item_name) type(n:1)
tab item_name if _merge==2
tab S_item_name if _merge==2 //Other items in IHS not collected in Market survey***
drop if _merge==2

keep urban_region time item_code rprice_CD  rprice_CD2 item item_name  share

order item_name rprice_CD rprice_CD2  share, after(item)

sort urban_region time item

bys urban_region time : egen tshare=total(share)
                    
*------------------------------------------------------------------------------*
*2c) Food index based on market prices (raw and imputed)					
*------------------------------------------------------------------------------*
gen food_index_MP=rprice_CD*(share/tshare)*100
gen food_index_MP2=rprice_CD2*(share/tshare)*100


keep if ~inlist(item, /*101, 102, 103, 104, 105, 118,*/ 106, 111, 112, 201, 205, 301, 303, 401, 405, 501, 504, 506, 508, 602, 701, 801, 803, 811)
drop if inlist(item, 707) //Cheese in Market Survey but not in IHS5


numlabel, add
tab item

collapse (sum) food_index*, by(urban_region time) 
format %tm   time 


*------------------------------------------------------------------------------*
*2d) Food index based on market prices (raw and imputed)	merged with UV derived food index				
*------------------------------------------------------------------------------*
merge 1:1 urban_region time using "$dout\food_index_temporal_ihs5_one_to_one_items",keepusing (food_index)	//Bring in food index for one to one UV 


*------------------------------------------------------------------------------*
*2e) Compare in a graph
*------------------------------------------------------------------------------*
graph twoway line food_index_MP  food_index_MP2 food_index time, by(urban_region)


save "${MS_Fint}\test_foodindex_MP_comp2_one_to_one_items", replace



*------------------------------------------------------------------------------*	
*4) Combine food and non food temporal CPI using raw market price, imputed market price and unit value
*------------------------------------------------------------------------------* 
	local v sw
	use "${MS_Fint}\test_foodindex_MP_comp2_one_to_one_items", clear
	merge 1:1 urban_region time using "$dout\non_food_index_temporal_ihs5",nogen
	sort urban_region time
	
	bys urban_region: egen food_cpim_MP=mean(food_index_MP) if inlist(time,714,716)
	bys urban_region: egen food_cpim_MP2=mean(food_index_MP2) if inlist(time,714,716)
	bys urban_region: egen food_cpim=mean(food_index) if inlist(time,714,716)
			
	bys urban_region: egen food_cpim2_MP=mean(food_cpim_MP)
	bys urban_region: egen food_cpim2_MP2=mean(food_cpim_MP2)
	bys urban_region: egen food_cpim2=mean(food_cpim) 
	
	replace food_index_MP=food_cpim2_MP if food_index_MP==. & time==715
	replace food_index_MP2=food_cpim2_MP2 if food_index_MP2==. & time==715
	replace food_index=food_cpim2 if food_index==. & time==715
	
	
	drop food_cpim*
	
		gen cpi_uv_ori=(non_food_index*w_nonfood + food_index*(100-w_nonfood))/100
		gen cpi_MP=(non_food_index*w_nonfood + food_index_MP*(100-w_nonfood))/100
		gen cpi_MP2=(non_food_index*w_nonfood + food_index_MP2*(100-w_nonfood))/100
	
	
	keep urban_region time cpi*
	
	
	label var cpi_uv_ori "CPI Current PovertyTeam_one_to_one"
	*label var cpi_uv "CPI-Unit Values(Common Items)"
	label var cpi_MP "CPI-MP,_one_to_one"
	label var cpi_MP2 "CPI-MP,_one_to_one(Rect)"
	
	graph twoway line  cpi_uv_ori cpi_MP   cpi_MP2  time, by(urban_region)
	graph twoway line  cpi_uv_ori   cpi_MP2  time, by(urban_region)


	
	save "${MS_Fint}\cpi_temporal_MP_comp2_one_to_one_items", replace 
	
*********************************************************************************	
********************************************************************************

*------------------------------------------------------------------------------*
*5) Create Spatial regional food CPI
*------------------------------------------------------------------------------*
	local v sw	
	
	use "${MS_Fint}\MP_nat_rm_`v'", clear  //"$dout\unitvalue_ihs5_nat_rm"
	rename price_CD_MP price_CD
	//Creating concordances for some items
replace item_code=102 if inlist(item_code_ori, "119","120") //Maize, yellow flour and Maizena to Ufa,refined flour(IHS)
replace item_code=301 if inlist(item_code_ori, "316A","316B","316C") //Beans Demetta, Kenyata and spotted to Bean, brown(IHS)
replace item_code=811 if inlist(item_code_ori, "806","807","808") //Cinnamon, Ginger and curry powder to Spices(IHS)
replace item_code=803 if inlist(item_code_ori, "850","851","852") //Sun flower, Vegetable and Soya Bean oil to Cooking Oil(IHS)
	
	
	ren (price_CD) (price_CD_nat)
	*gen item= item_code
	save "${MS_Fint}\MP_nattemp_`v'", replace     //"$dout\unitvalue_ihs5_month_nattemp", replace
	
	use "${MS_Fint}\MP_reg_dist_rm_`v'", clear // "$dout\unitvalue_ihs5_rm", clear
	rename price_CD_MP price_CD
	
	//Creating concordances for some items
	replace item_code=102 if inlist(item_code_ori, "119","120") //Maize, yellow flour and Maizena to Ufa,refined flour(IHS)
	replace item_code=301 if inlist(item_code_ori, "316A","316B","316C") //Beans Demetta, Kenyata and spotted to Bean, brown(IHS)
	replace item_code=811 if inlist(item_code_ori, "806","807","808") //Cinnamon, Ginger and curry powder to Spices(IHS)
	replace item_code=803 if inlist(item_code_ori, "850","851","852") //Sun flower, Vegetable and Soya Bean oil to Cooking Oil(IHS)
		
	merge m:1 item_code_ori using "${MS_Fint}\MP_nattemp_`v'", nogen //"$dout\unitvalue_ihs5_month_nattemp",nogen
	gen item= item_code
	
    gen rprice_CD=(price_CD/price_CD_nat) 
	
	egen rprice_CD_gmean = gmean(rprice_CD), by(urban_region item_code) //Where we use geometric mean of price relativitites

	tab  item_code if rprice_CD ~= rprice_CD_gmean  //20 items where we combine elementary items
	
	collapse (mean) rprice*, by(urban_region item_code item)
	
	br if  inlist(item, 106, 111, 112, 201, 205, 301, 303, 401, 405, 501, 504, 506, 508, 602, 701, 801, 803, 811) 
	
replace	rprice_CD = rprice_CD_gmean if  inlist(item, 102, 106, 111, 112, 201, 205, 301, 303, 401, 405, 501, 504, 506, 508, 602, 701, 801, 803, 811) // Change price relativities from arithmentic to geometric mean of multiple elementary groups 


   //merge with budget share

		preserve
		use "$MS_Fint\share_ihs5_CD2_`v'" , clear
		decode item, gen(S_item_name)
		tempfile item_sh
		save `item_sh'
		restore
		
	
	merge 1:1 urban_region item using `item_sh', keepusing(S_item_name)
	tab S_item_name if _merge ~=3
	tab item if _merge==1
	tab item if _merge==2
	
	keep if _m==3  
	drop _m
	
	
	
	merge 1:1 urban_region item using "$MS_Fint\share_ihs5_CD2_`v'"
	tab S_item_name if _merge ~=3
	keep if _m==3  
	drop _m
	
	
	
	*quietly sum rprice_ihs5,d 
	bys urban_region: egen tshare=total(share)
	gen food_index_MP=rprice_CD*(share/tshare)*100

	save "${MS_Fint}\test_food_itemindex_spatial_MP2_`v'", replace
	
keep if ~inlist(item, /*101, 102, 103, 104, 105, 118,*/ 106, 111, 112, 201, 205, 301, 303, 401, 405, 501, 504, 506, 508, 602, 701, 801, 803, 811)
drop if inlist(item, 707) //Cheese in Market Survey but not in IHS5
	
	collapse (sum) food_index_MP, by(urban_region)
	gen spatial=1                           
	reshape wide  food_index_MP , i(spatial) j(urban_region)
	
	rename (food_index_MP1 food_index_MP2 food_index_MP3 food_index_MP4) (urbanrpr_food_MP northrurrpr_food_MP centralrurrpr_food_MP southrurrpr_food_MP)


	
	merge 1:1 spatial using  "$dout\food_index_spatial_ihs5_one_to_one_items"
	
	save "${MS_Fint}\food_index_spatial_MP2_one_to_one_items", replace
*------------------------------------------------------------------------------*
*6) Import Non food CPI
*------------------------------------------------------------------------------*	 

	import excel "$din\Non-food_CPI_IHS5.xlsx", sheet("Sheet1") firstrow clear
	ren time month
	keep if month==711 | month==712  
	keep urban_region month non_food_cpi w_nonfood
	collapse (mean) non_food_cpi w_nonfood,by(urban_region)
	gen spatial=1                              
	reshape wide non_food_cpi w_nonfood,i(spatial) j(urban_region) 	   		   
	gen urbanrpr_nonfood=(non_food_cpi1/non_food_cpi5)*100
	gen northrurrpr_nonfood=(non_food_cpi2/non_food_cpi5) *100  
	gen centralrurrpr_nonfood=(non_food_cpi3/non_food_cpi5)*100  
	gen southrurrpr_nonfood=(non_food_cpi4/non_food_cpi5)*100  
	keep spatial urbanrpr_nonfood northrurrpr_nonfood centralrurrpr_nonfood southrurrpr_nonfood

*------------------------------------------------------------------------------*
*7) Combine food and non food spatial regional CPI
*------------------------------------------------------------------------------*	
	local v sw	
	merge 1:1 spatial using "${MS_Fint}\food_index_spatial_MP2_one_to_one_items",nogen
	*reshape long urbanrpr* southrurrpr* centralrurrpr* northrurrpr*, i(spatial) j(food_cat) str
	reshape long urbanrpr southrurrpr centralrurrpr northrurrpr, i(spatial) j(food_cat) str
	
	gen id = _n	
	
	save "${MS_Fint}\food_nonfood_index_spatial_MP2_one_to_one_items", replace
	
	foreach i in 1 2  {
		*local i 2
	use "${MS_Fint}\food_nonfood_index_spatial_MP2_one_to_one_items", clear
	*local i 1
	keep if inlist(id,`i', 3)	
	gen food_cat2= "1" if food_cat=="_food"|  food_cat=="_food_MP" , after(food_cat)
	replace food_cat2="2" if food_cat=="_nonfood"
	destring food_cat2,replace
	
	gen weight_urban=.
	replace weight_urban=.453 if food_cat2==1 
	replace weight_urban=(1-.453) if food_cat2==2 
	gen weight_northrur=.
	replace weight_northrur=.453 if food_cat2==1 
	replace weight_northrur=1-.453 if food_cat2==2 
	gen weight_centralrur=.
	replace weight_centralrur=.453 if food_cat2==1 
	replace weight_centralrur=1-.453 if food_cat2==2 
	gen weight_southrur=.
	replace weight_southrur=.453 if food_cat2==1 
	replace weight_southrur=1-.453 if food_cat2==2 
	gen spatial_indexL1=urbanrpr*weight_urban
	gen spatial_indexL2=northrurrpr*weight_northrur
	gen spatial_indexL3=centralrurrpr*weight_centralrur
	gen spatial_indexL4=southrurrpr*weight_southrur
	
	collapse (sum) spatial*
	gen id = `i'
	expand 13
	
	gen month = _n + 3
	reshape long spatial_indexL, i(month) j(urban_region)
	label define urban_region 1 "Urban" 2 "Rural North" 3 "Rural Centre" 4 "Rural South"
	label values urban_region urban_region
	
	
	gen syear = .
	replace syear = 2019 if inrange(month,4,12)  
	replace syear = 2020 if inrange(month,13,16)   
	gen smonth = .
	replace smonth = month if syear==2019
	replace smonth = month-12 if syear==2020
	drop month
	label var syear "Calender year of the fieldwork"
	label var urban_region "4 geographical domains with price series"
	label var smonth "Calendar month of the fieldwork"
	sort urban syear smonth
	order urban syear smonth
	gen time=ym(syear, smonth)
	label var time "Year and Month of survey, GC"
	format %tm   time
	
	save "${MS_Fint}\spatial_`i'_comp_one_to_one_items", replace
	}
	
*------------------------------------------------------------------------------*
*8) Merge temporal and spatial CPI
*------------------------------------------------------------------------------*
	//Replicating Poverty Team Approach
	local v sw
	use "${MS_Fint}\spatial_1_comp_one_to_one_items", clear
	merge 1:1 urban_region time using "${MS_Fint}\cpi_temporal_MP_comp2_one_to_one_items",nogen
	gen price_indexL_a = (spatial_indexL*cpi_uv_ori)/100
	
	drop  cpi_MP  cpi_MP2 spatial spatial_
	
	reshape wide cpi_uv_ori price_indexL_a, i(time) j(urban_region)

	label var price_indexL_a1 "Urban"
	label var price_indexL_a2 "Rural North"
	label var price_indexL_a3 "Rural Centre"
	label var price_indexL_a4 "Rural South"

	*graph twoway line price_indexL_a1 price_indexL_a2 price_indexL_a3 price_indexL_a4 time, title(" Spatial and temporal deflators" "One to One items using UV") saving("${MS_Fout}\price_index_UV_NA_rep_one_to_one_items", replace)
	
	drop cpi*
	
	reshape long price_indexL_a, i(time) j(urban_region)
	sort urban_region time
	save "${MS_Fint}\spatial_1_gph_comp_one_to_one_items", replace
	
	
	
	
	local v sw
	local ic 100
	//Market Prices- Cascading Medians (rectangularised)
		*local v sw
	use "${MS_Fint}\spatial_2_comp_one_to_one_items", clear
	merge 1:1 urban_region time using "${MS_Fint}\cpi_temporal_MP_comp2_one_to_one_items",nogen
	gen price_indexL_e = (spatial_indexL*cpi_MP2)/100
	
	drop  cpi_uv_ori cpi_MP spatial spatial_
	
	reshape wide cpi_MP2 price_indexL_e, i(time) j(urban_region)

	label var price_indexL_e1 "Urban"
	label var price_indexL_e2 "Rural North"
	label var price_indexL_e3 "Rural Centre"
	label var price_indexL_e4 "Rural South"

	*graph twoway line price_indexL_e1 price_indexL_e2 price_indexL_e3 price_indexL_e4 time, title("Spatial and temporal price deflators" "Market price - one_to_one items" /*"but using Cascading medians method of price imputation"*/) saving("$MS_Fout\price_index_MP2_one_to_one_items", replace)	


	drop cpi*
	
	reshape long price_indexL_e, i(time) j(urban_region)
	sort urban_region time
	save "${MS_Fint}\spatial_2a_gph_comp_one_to_one_items", replace
		
	
	//Current Poverty team approach
	local v sw
	use "$dout\Price_index_ihs5_one_to_one_items.dta", clear
	drop spatial spatial_
	reshape wide cpi  price_indexL, i(time) j(urban_region)
	
	label var price_indexL1 "Urban"
	label var price_indexL2 "Rural North"
	label var price_indexL3 "Rural Centre"
	label var price_indexL4 "Rural South"
	graph twoway line price_indexL1 price_indexL2 price_indexL3 price_indexL4 time, title(" Spatial and temporal price deflators" "Unit-Value One_to_one items") saving("$MS_Fout\price_index_PT_one_to_one_items", replace)
	
	drop cpi*
	
	reshape long price_indexL, i(time) j(urban_region)
	sort urban_region time
	save "${MS_Fint}\Price_index_ihs5_one_to_one_items_gph", replace
	
	local v sw
	*gr combine "$MS_Fout\price_index_PT_one_to_one_items.gph" "$MS_Fout\price_index_MP2_one_to_one_items.gph", iscale(*.75) ycommon saving("$MS_Fout\spatial_deflators_one_to_one_items", replace)

/*
}


foreach v in  sw  { 
	local v sw	
	local ic 100
	//Graphs of spatial-temporal price indices from different methods	
use "${MS_Fint}\Price_index_ihs5_one_to_one_items_gph", clear

foreach i in  /*2*/ 2a  {
merge 1:1 time urban_region using "${MS_Fint}\spatial_`i'_gph_comp_one_to_one_items", keepusing(price)
drop _merge
}
	
label var price_indexL " Unit Value"
label var price_indexL_e "Market Price"

sort urban_region time	
*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)

*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)
}
}

/*
local i 2a
local v sw
foreach ic in 50 60 70 80 90 100{
	gr use "$MS_Fout\price_index_MP2_`v'_FM_`ic'"
}

/************For comparison***********************************************
local v sw
local i 2a

local ic 100
use "${MS_Fint}\spatial_`i'_gph_comp_`v'", clear
save "${MS_Fint}\spatial_`i'_gph_comp_`v'_FM_`ic'", replace


gr use  price_index_PT_sw //UV approach
gr use price_index_MP2_sw //Market approach -  Reduced market, All items
gr save "$MS_Fout\price_index_MP2_sw_FM_`ic'", replace