*STATA Version: STATA 16.1
*------------------------------------------------------------------------------*
** 	 World Bank Data Development Group	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Price Deflators regressions for Unit values and market prices
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*
*Author: Niyi Alimi 
*-----------------------------------------------------------------------------
*------------------------------------------------------------------------------*
*Directory shortcuts
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/


		
	

//FULL ITEMS

foreach v in  sw  { 
	local v sw	
	local ic 100
	//Graphs of spatial-temporal price indices from different methods	
use "${MS_Fint}\Price_index_ihs5_gph", clear

foreach i in  2 2a  {
merge 1:1 time urban_region using "${MS_Fint}\spatial_`i'_gph_comp_`v'_FM_`ic'", keepusing(price)
drop _merge
}
	
label var price_indexL " Unit Value"
label var price_indexL_b "MarketPrice_NO_Rect`v'"
label var price_indexL_e "Market Price"

sort urban_region time	
*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)

*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)
}


drop  price_indexL_b

rename (price_indexL price_indexL_e) (price_index_full_UV  price_index_full_MP) 



*-------------------------------------------------------------------------------*
*Bring in Spatial-temporal deflators based on limited items
*-------------------------------------------------------------------------------*	
	
	preserve
	foreach v in  sw  { 
		local v sw	
		local ic 100
		//Graphs of spatial-temporal price indices from different methods	
	use "${MS_Fint}\Price_index_ihs5_limited_items_gph", clear

	foreach i in  2a  {
	merge 1:1 time urban_region using "${MS_Fint}\spatial_`i'_gph_comp_limited_items", keepusing(price)
	drop _merge
	}
		
	label var price_indexL " Unit Value"
	label var price_indexL_e "Market Price"

	sort urban_region time	
	*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)

	*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)
	}

	rename (price_indexL price_indexL_e) (price_index_lim_UV  price_index_lim_MP) 

	tempfile limited
	save `limited'
	restore

merge 1:1 time urban_region using `limited',keepusing(price_index_lim_UV  price_index_lim_MP)
drop _merge
*-------------------------------------------------------------------------------*
*Bring in Spatial-temporal deflators based on items mapped one-to-one 
*-------------------------------------------------------------------------------*	
	
	preserve
	foreach v in  sw  { 
		local v sw	
		local ic 100
		//Graphs of spatial-temporal price indices from different methods	
	use "${MS_Fint}\Price_index_ihs5_one_to_one_items_gph", clear

	foreach i in  2a  {
	merge 1:1 time urban_region using "${MS_Fint}\spatial_`i'_gph_comp_one_to_one_items", keepusing(price)
	drop _merge
	}
		
	label var price_indexL " Unit Value"
	label var price_indexL_e "Market Price"

	sort urban_region time	
	*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)

	*graph twoway line price_indexL   price_indexL_e time,	by(urban_region)
	}

	rename (price_indexL price_indexL_e) (price_index_one_to_one_UV price_index_one_to_one_MP   ) 

	tempfile one_to_one
	save `one_to_one'
	restore
	
merge 1:1 time urban_region using `one_to_one',keepusing(price_index_one_to_one_UV   price_index_one_to_one_MP)


*--------------------------------------------------/
/***************Table 7***************/
*Table 7 output in "${MS_Fout}\pricedef_reg_one_to_one_MP_UV.out"
*--------------------------------------------------/


*-------------------------------------------------------------------------------*
*Regressions of Market Price on Unit Value for one-to-one items
*-------------------------------------------------------------------------------*
global regopts se bra
local apprep replace

/*
reg price_index_one_to_one_MP  price_index_one_to_one_UV
outreg2 using "${MS_Fout}\pricedef_reg_one_to_one_MP_UV.out", `apprep' ${regopts} dec(4) ctitle(All)
*/

foreach u in 1 2 3 4{
	*local u 2
reg price_index_one_to_one_MP  price_index_one_to_one_UV if urban_region==`u'
test price_index_one_to_one_UV=1

if `u'==1{
	label var price_index_one_to_one_MP "Urban"
}

if `u'==2{
	label var price_index_one_to_one_MP "Rural-North"
}

if `u'==3{
	label var price_index_one_to_one_MP "Rural-Centre"
}

if `u'==4{
	label var price_index_one_to_one_MP "Rural-South"
}
outreg2 using "${MS_Tout}\Table7.out", `apprep' ${regopts} dec(4) adds(F-test(UV =1), r(F)) label /*ctitle(`u')*/
local apprep append
	}
	
	


