*STATA Version: STATA 16.1

*------------------------------------------------------------------------------*
** 	 World Bank Data Development Group	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Re-calculation of total expenditure
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*
*Author: Niyi Alimi 
*-----------------------------------------------------------------------------

*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/


	
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
*1) Merging all components
*------------------------------------------------------------------------------*

	*--------------------------------------------------------------------------*
	*1.1) Collapse food item expenditure by categries 
	*--------------------------------------------------------------------------*
	*foreach v in sw /*ihsw  hybw*/ {
*local ic 100
foreach ic in 50 60 70 80 90 100{
local v sw
	foreach m in UV CD2{
	*local m CD2
	
	use "$MS_Fout\OA_food_ihs5_MP_UV_`v'_FM_`ic'", clear
	
	
	keep HHID item urban_region time value_UV value_CD2
	br if value_`m'==. & value_UV~=.
	br _all
	
	tab item if value_`m'==. & value_UV~=.
	gen x = 1 if value_`m'==. & value_UV~=.
	replace value_`m'= value_UV if x==1
	
	rename value_`m' value
	drop value_* x
	
	*Beverages
	gen exp_cat012_i = value*52 if inrange(item,901,907) | inlist(item,912) | inlist(item,909,910,916)		
	*Alcohol
	gen exp_cat021 = value*52 if inrange(item,913,915) | inlist(item,908) | inlist(item,911)
	*Vendor
	gen exp_cat111 = value*52 if inrange(item,820,830)
	*Food
	gen exp_cat011 = value*52 if inrange(item,101,818) | inrange(item,831,838) | inrange(item,5021,5123)
	collapse  (sum) exp_cat*, by(HHID) 
	label var exp_cat012_i "Beverage consumption, Sec G"
	label var exp_cat021   "Alcohol consumption, Sec G"
	label var exp_cat111   "Vendor consumption, Sec G"
	label var exp_cat011   "Food, non-vendor consumption, Sec G"

	*--------------------------------------------------------------------------*
	*1.2) Merge Non-Food Expenditure
	*--------------------------------------------------------------------------*
	
		foreach f in educa health house ijk durables {
		merge 1:1 HHID using "$dout\nonfood_`f'.dta"
		drop _merge
		}
		merge 1:1 HHID using "$dout\rent.dta", nogen

	*--------------------------------------------------------------------------*
	*1.3) Group items f same categories from diferent data sources
	*--------------------------------------------------------------------------*	

		foreach coicop in 12 45 51 53 55 56 91 95{
		egen exp_cat0`coicop' = rsum( exp_cat0`coicop'_*)
		}

	*--------------------------------------------------------------------------*
	*1.4) Label categories
	*--------------------------------------------------------------------------*

		label var exp_cat011 "Food, nominal annual consumption"
		label var exp_cat012 "Beverage, nominal annual consumption"
		label var exp_cat021 "Alcohol, nominal annual consumption"
		label var exp_cat022 "Tobacco, nominal annual consumption"
		label var exp_cat031 "Clothing, nominal annual consumption"
		label var exp_cat032 "Footwear, nominal annual consumption"
		label var exp_cat041 "Actual rents for housing, nominal annual consumption"
		label var exp_cat042 "Estimated rents for housing, nominal annual consumption"
		label var exp_cat045 "Electricity, gas, other fuels, nominal annual consumption"
		label var exp_cat051 "Decorations, carpets, nominal annual consumption"
		label var exp_cat052 "Household textiles, nominal annual consumption"
		label var exp_cat053 "Appliances, nominal annual consumption"
		label var exp_cat054 "Dishes, nominal annual consumption"
		label var exp_cat055 "Tools/equipment for home, nominal annual consumption"
		label var exp_cat056 "Routine Home maintenance, nominal annual consumption"
		label var exp_cat061 "Health drugs, nominal annual consumption"
		label var exp_cat062 "Health out-patient, nominal annual consumption"
		label var exp_cat063 "Health hospitalization, nominal annual consumption"
		label var exp_cat071 "Vehicles, nominal annual consumption"
		label var exp_cat072 "Operation of vehicles, nominal annual consumption"
		label var exp_cat073 "Transport, nominal annual consumption"
		label var exp_cat081 "Postal services, nominal annual consumption"
		label var exp_cat083 "Phone and fax services, nominal annual consumption"
		label var exp_cat091 "Audio-visual, nominal annual consumption"
		label var exp_cat092 "Major durables for rec, nominal annual consumption"
		label var exp_cat093 "Other recreational items, pets, nominal annual consumption"
		label var exp_cat094 "Recreational services, nominal annual consumption"
		label var exp_cat095 "Newspapers, books, stationery, nominal annual consumption"
		label var exp_cat101 "Education, nominal annual consumption"
		label var exp_cat111 "Vendors/Cafes/Restaurants, nominal annual consumption"
		label var exp_cat112 "Accommodation services, nominal annual consumption"
		label var exp_cat121 "Personal care, nominal annual consumption"
		label var exp_cat123 "Personal effects, nominal annual consumption"
		recode exp_cat* (.=0)

	*--------------------------------------------------------------------------*
	*1.5) Merge basic variables
	*--------------------------------------------------------------------------*
	
	merge 1:1 HHID using "$dout\basicvars_ihs5.dta", nogen

	*--------------------------------------------------------------------------*
	*1.6) Merge price index
	*--------------------------------------------------------------------------*
	merge m:1 urban_region syear smonth using "$dout\Price_index_ihs5.dta", nogen
	rename cpi temporal
	
	rename price_index price_index_UV
	
	merge m:1 urban_region syear smonth using "$MS_Fint\spatial_2a_gph_comp_`v'_FM_`ic'.dta", nogen
	*rename cpi temporal
	
	rename price_indexL_e price_index_CD2

	
	*For Hybrid Approach
	*drop price_index_UV
	*rename price_index_CD2 price_index_UV
*------------------------------------------------------------------------------*
*2) Generate real consumption
*------------------------------------------------------------------------------*

	foreach c of varlist exp_cat??? {		
	gen r`c' = (`c'/price_index_`m')*100
	}	
	foreach c of varlist exp_cat??? {
	local Name : variable label `c'
	local Real : subinstr local Name ", nominal" ", real(April 2019 price)"
	label var r`c' "`Real'"
	}

*------------------------------------------------------------------------------*
*3) Aggregating NOMINAL consumption into broad groups (Coicop 2 digits)
*------------------------------------------------------------------------------*
	
	foreach n of numlist 1/9 {
	egen exp_cat0`n' = rsum(exp_cat0`n'?)
	}
	foreach n of numlist 10/12 {
	egen exp_cat`n' = rsum(exp_cat`n'?)
	}
	label var exp_cat01 "Food/Bev, nominal annual consumption"
	label var exp_cat02 "Alc/Tobacco, nominal annual consumption"
	label var exp_cat03 "Clothing/Footwear, nominal annual consumption"
	label var exp_cat04 "Housing/Utilities, nominal annual consumption"
	label var exp_cat05 "Furnishings, nominal annual consumption"
	label var exp_cat06 "Health, nominal annual consumption"
	label var exp_cat07 "Transport, nominal annual consumption"
	label var exp_cat08 "Communication, nominal annual consumption"
	label var exp_cat09 "Recreation, nominal annual consumption"
	label var exp_cat10 "Education, nominal annual consumption"
	label var exp_cat11 "Hotels and restaurants, nominal annual consumption"
	label var exp_cat12 "Misc Goods & Services, nominal annual consumption"

*------------------------------------------------------------------------------*	
*4) aggregating REAL (Spatially & within survey Temporally adjusted) consumption
*------------------------------------------------------------------------------*

	foreach n of numlist 1/9 {
	egen rexp_cat0`n' = rsum(rexp_cat0`n'?)
	}
	foreach n of numlist 10/12 {
	egen rexp_cat`n' = rsum(rexp_cat`n'?)
	}
	foreach c of varlist exp_cat?? {
	local Name : variable label `c'
	local Real : subinstr local Name ", nominal" ", real(April 2019 price)"
	label var r`c' "`Real'"
	}

*------------------------------------------------------------------------------*	
*5) Generate total consumption of the household
*------------------------------------------------------------------------------*
	
	egen rexpagg = rsum(rexp_cat??)
	egen expagg = rsum(exp_cat??)
	label var expagg  "Total nominal annual consumption per household"
	label var rexpagg "Total real annual consumption per household"
	gen rexpaggpc=rexpagg/hhsize
	gen expaggpc=expagg/hhsize	
	label var expaggpc  "Total nominal annual per capita consumption"
	label var rexpaggpc "Total real annual per capita consumption"

*------------------------------------------------------------------------------*
*6) Keep & save desired variables
*------------------------------------------------------------------------------*
	
	local d HHID ea_id district TA region urban_region urban sdate smonth syear hhsize adulteq hh_wgt exp_cat* rexp_cat* price_index_`m' expagg rexpagg expaggpc rexpaggpc
	keep `d'
	order `d'
	sort HHID
	summ expagg rexpagg expaggpc rexpaggpc
	summ exp_cat??[w= hhsize*hh_wgt]
	summ rexp_cat??[w= hhsize*hh_wgt]
	
	sort HHID, stable
	gen nid = _n
	sort nid
	save "$MS_Fout\tconsumption_`m'_`v'_FM_`ic'.dta", replace

	keep  HHID hhsize adulteq hh_wgt price_index_`m' expagg rexpagg rexpaggpc
	save "$MS_Fout\tconsumption_`m'_4povline_`v'_FM_`ic'.dta", replace

	}
	}
	
	
use "$MS_Fout\tconsumption_UV_sw_FM_100.dta", clear
summ exp_cat?? rexp_cat?? expagg rexpagg expaggpc rexpaggpc

use "$MS_Fout\tconsumption_UV_sw_FM_50.dta", clear
summ exp_cat?? rexp_cat?? expagg rexpagg expaggpc rexpaggpc	

/*/Remove un-needed replications of UV analysis	
	foreach ic in 50 60 70 80 90{
	erase "$MS_Fout\tconsumption_UV_sw_FM_`ic'.dta"
	}
	
*/
	
	
	
*------------------------------------------------------------------------------*
*Output Tables	
*------------------------------------------------------------------------------*	
*1) Mean Nominal and Real consumption by COICOP category and test of difference of means
	
	//Mean Nominal and Real consumption average by COICOP category
	use "$MS_Fout\tconsumption_UV_sw_FM_100.dta", clear
	*gen nid = _n
	*sort nid
	keep  HHID hhsize adulteq hh_wgt price_index_UV expagg rexpagg rexpaggpc exp_cat?? rexp_cat??
	gen popw = hh_wgt*hhsize
	svyset[w=popw]
	
	foreach ic in /*50 60 70 80 90*/ 100{
	    *local ic 50
	mmerge HHID using  "$MS_Fout\tconsumption_CD2_sw_FM_`ic'.dta", type(1:1) ukeep(exp_cat?? rexp_cat?? expagg rexpagg rexpaggpc) uname(FMP_`ic'_)
	
	drop _merge

	
	svy: mean exp_cat?? FMP_`ic'_exp_cat?? 
	
	
	}
	
	save "$MS_Fint\for_testing_diff_cons", replace
	
*------------------------------------------------------------------------------*
*X) Test of Difference in Mean between Unit Value and Market price based method
*Examines difference between UV and Market Price 50-100% item coverage
*------------------------------------------------------------------------------*	
*--------------------------------------------------------------------*
***Table 8 and 9 Panel C (Test of Difference between Unit Value and Market Price)
*--------------------------------------------------------------------*
	use "$MS_Fint\for_testing_diff_cons", replace


		putexcel set "$MS_Tout\Tables8_9panelC", replace

		putexcel A1=("COICOP Category") 
		putexcel B1= ("Raw diff")
		putexcel C1=("Std Error")
		putexcel D1=("T-test") 
		putexcel E1=("P-value") 
		putexcel F1=("IC")
		putexcel G1=("Nominal")
		
		putexcel J1=("COICOP Category") 
		putexcel K1= ("Raw diff")
		putexcel L1=("Std Error")
		putexcel M1=("T-test") 
		putexcel N1=("P-value") 
		putexcel O1=("IC")
		putexcel P1=("Real")
		
		
				
		//Test of difference- Nominal
		rename exp_cat0(#) exp_cat(#)
		rename rexp_cat0(#) rexp_cat(#)
		rename expagg exp_cat13
		rename rexpagg rexp_cat13
		
		
		rename FMP_*_exp_cat0(#) FMP_*_exp_cat(#)
		rename FMP_*_rexp_cat0(#) FMP_*_rexp_cat(#)
		rename FMP_*_expagg FMP_*_exp_cat13
		rename FMP_*_rexpagg FMP_*_rexp_cat13

		//Nominal
		local row 2
		foreach ic in /*50 60 70 80 90*/ 100{
	
			
			foreach i of numlist 1/13{
		  
		  svy: mean exp_cat`i' FMP_`ic'_exp_cat`i' 
			lincom FMP_`ic'_exp_cat`i' - exp_cat`i'
				putexcel A`row'=(`i')
				*putexcel B`row'=(r(estimate))
				putexcel C`row'=(r(se))
				putexcel D`row'=(r(t))
				putexcel E`row'=(r(p))
				putexcel F`row'=(`ic')
				putexcel G`row'=("Nominal")

		  
		  
		  
			svy: mean rexp_cat`i' FMP_`ic'_rexp_cat`i' 
			lincom FMP_`ic'_rexp_cat`i' - rexp_cat`i'
				putexcel J`row'=(`i')
				*putexcel K`row'=(r(estimate))
				putexcel L`row'=(r(se))
				putexcel M`row'=(r(t))
				putexcel N`row'=(r(p))
				putexcel O`row'=(`ic')
				putexcel P`row'=("Real")

			local row = `row'+1				
		}
		
								}
								
*------------------------------------------------------------------------------*
	//Mean and Std Err for  Nominal COICOP categories for all item coverage
	*Save in matrices
*------------------------------------------------------------------------------*


*--------------------------------------------------------------------*

***Table 8 and 9 Panel A and Panel B (Mean and Standard Error Unit Value and Market Price)
*--------------------------------------------------------------------*

putexcel set "$MS_Tout\Tables8_9panelAB", sheet(nominal) replace
use "$MS_Fint\for_testing_diff_cons", clear
svy: mean exp_cat?? expagg FMP_100_exp_cat?? FMP_100_expagg
putexcel A1= matrix(r(table)), names
putexcel save
putexcel clear 

putexcel set "$MS_Tout\Tables8_9panelAB", sheet(real) modify
use "$MS_Fint\for_testing_diff_cons", clear
svy: mean rexp_cat?? rexpagg FMP_100_rexp_cat?? FMP_100_rexpagg
putexcel A1= matrix(r(table)), names
putexcel save
putexcel clear 		
		
		/*
		preserve
		svy: mean exp_cat?? FMP_*_exp_cat?? expagg FMP_*_expagg
		
		matrix define A_ = e(b)  //Mean
		matrix sd_err = e(V)             // <- gets the variance-covariance matrix
		matrix sd_err = vecdiag(sd_err)     // <- gets the diagonal elements. SE is sqrt of diagonal elements
		svmat sd_err
		
		keep sd_err*
		foreach i of numlist 1/91 {
		replace sd_err`i' = sqrt(sd_err`i')
		}
		
		keep if _n==1
		summ sd_err*
		mkmat sd_err*, mat(sd_err) 
		matrix A_ = A_\sd_err
		matlist A_
		
		restore
*------------------------------------------------------------------------------*
	//Mean and Std Err for Real COICOP categories for all item coverage
	*Save in matrices
*------------------------------------------------------------------------------*
		preserve
		svy: mean rexp_cat?? FMP_*_rexp_cat?? rexpagg FMP_*_rexpagg
		matrix define B_ = e(b)  //Mean
		matrix sd_err_r = e(V)             // <- gets the variance-covariance matrix
		matrix sd_err_r = vecdiag(sd_err_r)     // <- gets the diagonal elements
		svmat sd_err_r
		
		keep sd_err_r*
		foreach i of numlist 1/91 {
		replace sd_err_r`i' = sqrt(sd_err_r`i')
		}
		
		keep if _n==1
		summ sd_err_r*
		mkmat sd_err_r*, mat(sd_err_r) 
		matrix B_ = B_\sd_err_r
		matlist B_
		restore
			*/
*------------------------------------------------------------------------------*
	//Calculate COICOP share
*------------------------------------------------------------------------------*
	collapse (sum) exp_cat?? rexp_cat??  expagg rexpagg FMP_*_exp_cat?? FMP_*_rexp_cat?? FMP_*_expagg FMP_*_rexpagg[w=popw]
	
	rename exp_cat0(#) exp_cat(#)
	rename rexp_cat0(#) rexp_cat(#)

	rename FMP_*_exp_cat0(#) FMP_*_exp_cat(#)
	rename FMP_*_rexp_cat0(#) FMP_*_rexp_cat(#)
	
	
	preserve
	keep exp_cat* expagg rexp_cat* rexpagg
	
	reshape long exp_cat rexp_cat, i(expagg rexpagg) j(coicop)
	
	gen nom_coicop_shr_UV = exp_cat/expagg
	gen real_coicop_shr_UV = rexp_cat/rexpagg
	keep coicop  *_coicop_*
	tempfile coicop_UV_real_nom
	save `coicop_UV_real_nom'
	restore
	
	preserve
	keep FMP_*_exp_cat*   FMP_*_expagg 
	reshape long /*FMP_50_exp_cat  FMP_60_exp_cat  FMP_70_exp_cat  FMP_80_exp_cat  FMP_90_exp_cat*/  FMP_100_exp_cat , i(/*FMP_50_expagg FMP_60_expagg FMP_70_expagg FMP_80_expagg FMP_90_expagg*/ FMP_100_expagg) j(coicop)
	
	foreach ic in /*50 60 70 80 90*/ 100{
	 gen nom_coicop_shr_MP_`ic' = FMP_`ic'_exp_cat/ FMP_`ic'_expagg
		}
		
	keep coicop  *_coicop_*
	tempfile coicop_MP_nom
	save `coicop_MP_nom'
	restore
	
	preserve
	keep FMP_*_rexp_cat*   FMP_*_rexpagg 
	reshape long /*FMP_50_rexp_cat  FMP_60_rexp_cat  FMP_70_rexp_cat  FMP_80_rexp_cat  FMP_90_rexp_cat*/  FMP_100_rexp_cat , i(/*FMP_50_rexpagg FMP_60_rexpagg FMP_70_rexpagg FMP_80_rexpagg FMP_90_rexpagg*/ FMP_100_rexpagg) j(coicop)
	
	foreach ic in /*50 60 70 80 90*/ 100{
	 gen real_coicop_shr_MP`ic' = FMP_`ic'_rexp_cat/ FMP_`ic'_rexpagg
		}
		
	keep coicop  *_coicop_*
	tempfile coicop_MP_real
	save `coicop_MP_real'
	restore
	
	preserve
	use `coicop_UV_real_nom', clear
	merge 1:1 coicop using `coicop_MP_nom'
	drop _merge
	merge 1:1 coicop using `coicop_MP_real'
	
	export excel using  "$MS_Tout\Tables8_9_share", replace firstrow(var)
	restore

*--------------------------------------------------------------------*

***Table 8 and 9 Panel A and Panel B (Panel A and B Share Reported Above for Unit Value and Market Price in $MS_Fout\val_cons_UV_MP_shr")
*--------------------------------------------------------------------*	
	
		
*Densities and Test of equality of distribution	

	use "$MS_Fout\tconsumption_UV_sw_FM_100.dta", clear
	keep  HHID hhsize adulteq hh_wgt price_index_UV exp_cat01 rexp_cat01 expagg expaggpc rexpagg rexpaggpc
	gen popw = hh_wgt*hhsize
	svyset[w=popw]
	
mmerge HHID using  "$MS_Fout\tconsumption_CD2_sw_FM_100.dta", type(1:1) ukeep( exp_cat01 rexp_cat01 expagg expaggpc rexpagg rexpaggpc) uname(FMP_100_)


	*Nominal Total Consumption Densities
	kdensity expagg[aw=hh_wgt], addplot(kdensity FMP_100_expagg[aw=popw]) ylabel(#2) xlabel(#3) legend (order(1 "UV: Nominal Cons" 2 "MP: Nominal Cons")) title ("Nominal Consumption Derived from" "Unit Value and Market Price Approach") saving("${MS_Fout}\Figure4PanelA", replace)
	
	*Real Consumption Densities
	kdensity rexpagg[aw=hh_wgt], addplot(kdensity FMP_100_rexpagg[aw=popw]) ylabel(#2) xlabel(#3) legend (order(1 "UV: Real Cons" 2 "MP: Real Cons")) title ("Real Consumption Derived from" "Unit Value and Market Price Approach") saving("${MS_Fout}\Figure4PanelB", replace)
	
	*--------------------------------------------------------------------*

***Figure 4: Density Distribution
*--------------------------------------------------------------------*
	
	gr combine "${MS_Fout}\Figure4PanelA" "${MS_Fout}\Figure4PanelB", col(2) iscale(*.99) scheme( s2color) saving("${MS_Tout}\Figure4", replace)
	
		
		
