
*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Development Data Group**
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement(Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Generate Poverty lines
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*
*Author: Niyi Alimi 
*-----------------------------------------------------------------------------
*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/

*------------------------------------------------------------------------------*
*1) Prepare food items for merge 
*------------------------------------------------------------------------------*	
	*use "$dout\food_ihs5_forpovline.dta", clear
	*local ic 100
	foreach ic in 50 60 70 80 90 100{
		*local ic 100
	foreach v in sw  {
	foreach m in UV CD2{
	*local m UV
	
	*local ic 100
	*local v sw
	*local m CD2

	use "$MS_Fout\OA_food_ihs5_forpovline_`m'_`v'_FM_`ic'", clear

	keep HHID item hhsize qkg_`m' pcqkg_`m' hh_wgt price_`m'
	gen mprice = 1 if missing(price)
	replace mprice = 0 if !missing(price)
	drop if mprice==1
	drop mprice
	merge m:1 item using "$din\calories",nogen keep(match)
	drop if e_kcal==0 | missing(e_kcal)
	replace qkg = qkg/7
	rename (e_kcal) (cal)		
	gen cal_int = (((qkg*cal*10)))
	keep item qkg cal_int HHID cal hh_wgt hhsize
	tempfile basketnoout
	save `basketnoout'	
	
*------------------------------------------------------------------------------*
*2) Choose the reference group and with food items
*------------------------------------------------------------------------------*
*foreach cal of numlist 2215(100)2815{
	
	local cal  2215
	use "$MS_Fout\tconsumption_`m'_`v'_FM_`ic'.dta",clear

	xtile rexpaggpc_q=rexpaggpc[aw=hhsize*hh_wgt],nq(10) 
		
	keep if inrange(rexpaggpc_q,5,6)


	save "$MS_Fout\refgroup_`m'_`v'_FM_`ic'", replace
	
	
	keep HHID hhsize adulteq hh_wgt price_index_`m' expagg rexpagg rexpaggpc
	merge 1:m HHID using `basketnoout'
	keep if _merge==3 
	drop _merge
	
*------------------------------------------------------------------------------*
*3) Generate panel 
*------------------------------------------------------------------------------*

	*--------------------------------------------------------------------------*
	*3.1) Generate structure
	*--------------------------------------------------------------------------*
	
		egen hhid = group(HHID)
		egen itid = group(item)
		tsset hhid itid
		tsfill, full
	
	*--------------------------------------------------------------------------*
	*3.2) Replace with 0 if missing consumption
	*--------------------------------------------------------------------------*
	
		replace qkg_`m'=0 if qkg_`m'==.
		tsset, clear
	
	*--------------------------------------------------------------------------*
	*3.3) Fill missing variables
	*--------------------------------------------------------------------------*
	
		bysort hhid (HHID): replace HHID=HHID[_N]	
		bysort itid: carryforward item, gen (itemf)
		replace item = itemf if missing(item)
		drop itemf
		foreach var in hhsize adulteq hh_wgt price_index_`m' expagg rexpagg rexpaggpc{
		bysort hhid (`var'): replace `var'=`var'[1]
		}

*------------------------------------------------------------------------------*
*4) Set calories requirement
*------------------------------------------------------------------------------*
	gen cal_req = `cal'


*------------------------------------------------------------------------------*
*5) Generate population
*------------------------------------------------------------------------------*

	gsort HHID -qkg
	by HHID: gen first = 1 if _n==1
	egen totalhh =  total(hh_wgt) if first ==1
	bysort hhid (totalhh): replace totalhh=totalhh[1]

*------------------------------------------------------------------------------*
*6) Food popularity
*------------------------------------------------------------------------------*
	bysort item: egen hh_consumer = total(hh_wgt) if qkg_`m'>0 & qkg_`m'!=. 
	gen popularity = hh_consumer/totalhh
	sort item popularity, stable
	bysort item (popularity): replace popularity = popularity[1]
	replace popularity = 0 if popularity==.	
	
*------------------------------------------------------------------------------*
*7)	Creates caloric intake share of each food in total consumption
*------------------------------------------------------------------------------*
	
	bysort hhid: egen cal_int_hh = total(cal_int) 
	gen tot_intake_temp = cal_int_hh*hh_wgt if first ==1 
	egen tot_intake = total(tot_intake_temp) if first ==1 
	drop tot_intake_temp
	bysort hhid (tot_intake): replace tot_intake=tot_intake[1] 
	gen food_intake_temp = cal_int*hh_wgt
	bysort item: egen food_cal_intake = total(food_intake_temp)
	gen share_intake = food_cal_intake/tot_intake

*------------------------------------------------------------------------------*
*8) Select Items
*------------------------------------------------------------------------------*	

	keep if share_intake>0.05 | popularity>0.3	

*------------------------------------------------------------------------------*
*9) Quantity adjustment to match caloric requirements
*------------------------------------------------------------------------------*
	
	*--------------------------------------------------------------------------*
	*9.1) New population
	*--------------------------------------------------------------------------*

		drop first
		sort HHID, stable
		by HHID: gen first = 1 if _n==1
		egen population = total(hh_wgt) if first == 1
		sort population, stable 
		replace population=population[1] 

	*--------------------------------------------------------------------------*
	*9.2) Total consumption
	*--------------------------------------------------------------------------*
		gen cantidad_h_temp = qkg_`m'/hhsize*hh_wgt
		bys item: egen qkg_tot = total(cantidad_h_temp) 
		
	*--------------------------------------------------------------------------*
	*9.3) Generate quantities pc
	*--------------------------------------------------------------------------*
		
		keep item qkg_tot population cal cal_req
		drop if cal ==. 
		duplicates drop 
		gen qkg = qkg_tot/population
		gen cal_intake_pre_adj = qkg*cal*10
	
	*--------------------------------------------------------------------------*
	*9.4) Generate adjustement on quantities
	*--------------------------------------------------------------------------*
		
		egen total_cal_pre_adj = total(cal_intake_pre_adj)
		gen caloric_adj = cal_req/total_cal_pre_adj
		gen q_adj = qkg * caloric_adj 
		gen cal_intake = q_adj*cal*10
		gsort -cal_intake
		drop qkg_tot
		save "$MS_Fout/daily_basket_`m'_`cal'_`v'_FM_`ic'.dta", replace

		/*local ic 100
		use "$MS_Fout/daily_basket_UV_2215_sw_FM_`ic'.dta", clear
		use "$MS_Fout/daily_basket_CD2_2215_sw_FM_`ic'.dta", clear
		*/
*------------------------------------------------------------------------------*
*10) Impute prices 
*------------------------------------------------------------------------------*
*local m CD2
*local v sw
*local ic 100
	use "$MS_Fout\OA_food_ihs5_forpovline_`m'_`v'_FM_`ic'", clear

	merge m:1 urban_region syear smonth using  "$dout\Price_index_ihs5.dta", nogen	
	rename price_indexL price_indexL_UV
	drop cpi spatial_indexL
	
	merge m:1 urban_region syear smonth using "$MS_Fint\spatial_2a_gph_comp_`v'_FM_`ic'.dta" , nogen	
	rename price_indexL_e price_indexL_CD2
	drop id spatial
	

	
	gen rprice = (price_`m'/price_indexL_`m')*100
	collapse (count) nobs=rprice (mean) mnprice=rprice (p50) mdprice=rprice (min) minprice=rprice  (max) maxprice=rprice, by(item)
	save "$MS_Fout\pricebyurbanregion_`m'_`v'_FM_`ic'.dta",replace
	
	*local m UV
	use "$MS_Fout/daily_basket_`m'_`cal'_`v'_FM_`ic'.dta", clear
	merge 1:1 item using "$MS_Fout\pricebyurbanregion_`m'_`v'_FM_`ic'.dta"
	keep if _merge==3
	drop _merge
	gen value = q_adj*mdprice
	collapse (sum) d_upline = value (mean) cal_req
	gen m = 1
	tab d_upline
	save "$MS_Fout/upline_ihs5_`m'_`cal'_`v'_FM_`ic'", replace 

*------------------------------------------------------------------------------*
*11) Create poverty line out of food poverty line
*------------------------------------------------------------------------------*
	*local m UV
	use "$MS_Fout\refgroup_`m'_`v'_FM_`ic'", clear
	summ rexpaggpc_q
	gen lb = r(min)
	gen ub = r(max)
	gen m = 1
	merge m:1 m using "$MS_Fout/upline_ihs5_`m'_`cal'_`v'_FM_`ic'", nogen
	gen logyz = log(rexpaggpc/d_upline)
	gen foodshr=rexp_cat01/rexpagg
	sum foodshr, d
	regress foodshr logyz [aw=hhsize*hh_wgt]
	gen nfoodshr=(1-_b[_cons])
	label var nfoodshr "Share of non-food expenditure in total exp"
	sum nfoodshr,d		
	gen m_pline= d_upline*(1+nfoodshr)
	collapse m_pline cal_req lb ub nfoodshr
	gen m = 1
	save "$MS_Fout\pline_ihs5_`m'_`cal'_`v'_FM_`ic'", replace 
	
	
	*********************************************
	*------------------------------------------------------------------------------*
*11) Merge food poverty with CBN poverty line
*------------------------------------------------------------------------------*
	use "$MS_Fout/upline_ihs5_`m'_`cal'_`v'_FM_`ic'", clear	
	mmerge m using	"$MS_Fout\pline_ihs5_`m'_`cal'_`v'_FM_`ic'", type(1:1) ukeep(m_pline cal_req lb ub nfoodshr)
	drop m
	gen m =1
	save "$MS_Fout\povline_`m'_`cal'_`v'_FM_`ic'", replace

}	
}
	
	
	}
	
	/*
	******Comparing calorie requirement
		local m UV
	use "$MS_Fout\povline_`m'_2215_sw_FM_100", replace
	foreach m in UV CD2{
	foreach cal in 2215 2315 2415 2515 2615 2715 2815{
	append using "$MS_Fout\povline_`m'_`cal'_sw_FM_100"
		}
		}
	
	/*/Keeping only Pov lines that is required
use  "$MS_Fout\povline_UV_2215_sw_FM_100", clear	
foreach ic in 50 60 70 80 90 {
append using "$MS_Fout\povline_UV_2215_sw_FM_`ic'"
erase "$MS_Fout\povline_UV_2215_sw_FM_`ic'"
}
*/	

// Comparing Poverty Lines across Item Coverage for Full Market using Market Price
use  "$MS_Fout\povline_CD2_2215_sw_FM_100", clear
gen IC =100
gen method= "Market Price- Full Sample"
foreach ic in 90 80 70 60 50  {
append using "$MS_Fout\povline_CD2_2215_sw_FM_`ic'"
replace IC =`ic' if  IC==.
}

tempfile MP_Povline_IC
save 	`MP_Povline_IC'

// Poverty Lines from Unit Values. No variation in UV as Item Coverage does not vary
use  "$MS_Fout\povline_UV_2215_sw_FM_100", clear
gen IC =100
gen method= "Unit Value"

foreach ic in 90 80 70 60 50  {
append using "$MS_Fout\povline_UV_2215_sw_FM_`ic'"
replace IC =`ic' if  IC==.
}		

append using `MP_Povline_IC'
	

		
*------------------------------------------------------------------------------*
*12a Show matrix or number of population in each group UV vs MP(survey weight)
*------------------------------------------------------------------------------*

*foreach ic in 50 60 70 80 90 100{
	local ic 100
	foreach v in sw  {
	*local v sw
	use "$MS_Fout\tconsumption_UV_`v'_FM_`ic'.dta",clear

	*xtile rexpaggpc_q=rexpaggpc[aw=hhsize*hh_wgt],nq(10) 
	xtile rexpaggpc_q=rexpaggpc[aw=hhsize*hh_wgt],nq(5) 

	keep HHID ea_id district TA region urban_region urban sdate smonth syear hhsize adulteq hh_wgt rexpaggpc rexpaggpc_q
	
	mmerge HHID using "$MS_Fout\tconsumption_CD2_`v'_FM_`ic'.dta", type(1:1) ukeep(rexpaggpc) uname(MP_)
	xtile MP_rexpaggpc_q=MP_rexpaggpc[aw=hhsize*hh_wgt], nq(5) 
	
	tab MP_rexpaggpc_q rexpaggpc_q [iw=hhsize*hh_wgt] //Population
	tab rexpaggpc_q MP_rexpaggpc_q  [iw=hhsize*hh_wgt] //Population

	
	}

	}
	
