
*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Data Development Grou[] 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Poverty head count ratio
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/




*------------------------------------------------------------------------------*
*Use Total Cons and poverty line from Unit Value approach and merge with
*Total Cons and Poverty line from Market Price approaches
*------------------------------------------------------------------------------*

use "$MS_Fout\tconsumption_UV_sw_FM_100.dta", clear
keep HHID-hh_wgt rexpagg 

//Merge Unit Value Poverty Line
gen m=1
mmerge m using "$MS_Fout\pline_ihs5_UV_2215_sw_FM_100", type(n:1) ukeep(m_pline) 
mmerge m using "$MS_Fout\upline_ihs5_UV_2215_sw_FM_100", type(n:1) ukeep(d_upline) 

//Merge real cons and poverty line from diff item coverage assumptions
foreach ic in 50 60 70 80 90 100 {
mmerge HHID using "$MS_Fout\tconsumption_CD2_sw_FM_`ic'.dta", ukeep(rexpagg) uname(FM`ic'_) //Merge real cons from diff item coverage assimptions

	mmerge  m using "$MS_Fout\pline_ihs5_CD2_2215_sw_FM_`ic'", type(n:1)  ukeep(m_pline) uname(FM`ic'_) //Merge poverty line
	mmerge  m using "$MS_Fout\upline_ihs5_CD2_2215_sw_FM_`ic'", type(n:1)  ukeep(d_upline) uname(FM`ic'_) //Merge poverty line
	
	
}	

*******************Generate quarterly variables********************************
			gen time=ym(syear, smonth)                                               
			gen quarter=.
			replace quarter=1 if inrange(time, 711,713)
			replace quarter=2 if inrange(time, 714,716)
			replace quarter=3 if inrange(time, 717,719)
			replace quarter=4 if inrange(time, 720,723)
			
			label var time "Year and Month of survey, GC"
			format %tm   time
			tab time quarter
	


		putexcel set "$MS_Tout\Table15_16_20_A19",sheet(Tables15_20_A19) replace
		putexcel A1=("Geography") 
		*putexcel B1=("Item Coverage") 
		*putexcel C1=("Method") 
		putexcel D1=("Food Pov rate")
		putexcel E1=("CBN Pov rate") 
		putexcel F1=("Gini")
		putexcel G1=("Gini")
		putexcel H1=("Gini-SE")
		putexcel I1=("MLD")
		putexcel J1=("CoV")
		putexcel K1=("90-10")
		putexcel L1=("80-20")
		putexcel M1=("90-50")
		putexcel N1=("50-10")
		putexcel O1=("95-5")


	local row 10
*------------------------------------------------------------------------------*	
*UV analysis
*------------------------------------------------------------------------------*
	*----------------------------------*	
	*National
	*----------------------------------*

	gen pcrexp = rexpagg/hhsize
	replace pcrexp =  pcrexp/365
	gen popw = hh_wgt*hhsize
	svyset [w=popw]
	
	*Food Poverty rates across diff item coverage at the National Level
	apoverty pcrexp[w=hh_wgt*hhsize], varpl(d_upline) gen(food_poor_UV)
	putexcel A`row'=("National")
	putexcel B`row'=(r(head_1))

	*CBN Poverty rates across diff item coverage at the National Level
	apoverty pcrexp[w=hh_wgt*hhsize], varpl(m_pline) gen(CBN_poor_UV)
	putexcel C`row'=(r(head_1))
	
	*Consumption inequality
	inequal7 pcrexp[w=hh_wgt*hhsize]
	putexcel D`row'=(r(gini))
	
	putexcel G`row'=(r(mld))
	putexcel H`row'=(r(cov))
	

	
	*Consumption Inequality and Standard errors
	svylorenz pcrexp
	putexcel E`row'= (e(gini))
	putexcel F`row'= (e(se_gini))
	 
	 
	*Decile Ratios (90/10;80/20;90/50;50/10)
	_pctile pcrexp[w=hh_wgt*hhsize], nq(100)
	return list
	scalar A1 = r(r90)/r(r10)
	di A1
	scalar A2 = r(r80)/r(r20)
	di A2
	scalar A3 = r(r90)/r(r50)
	di A3
	scalar A4 = r(r50)/r(r10)
	di A4
	scalar A5 = r(r95)/r(r5)
	di A5
	putexcel I`row'= A1
	putexcel J`row'= A2
	putexcel K`row'= A3
	putexcel L`row'= A4
	putexcel M`row'= A5

	putexcel N`row'=("Unit Value")
	*----------------------------------*	
	*Quarterly
	*----------------------------------*		
		mat prate_q_UV = J(4,12,.)
		mat rownames prate_q_UV  = Q1 Q2 Q3 Q4
		mat colnames prate_q_UV  = FoodPov CBNPov Gini Gini Gini-SE MLD CoV 90-10 80-20 90-50 50-10 95-5
	foreach q in 1 2 3 4{
	*Food Poverty line
	apoverty pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(d_upline) gen(food_poor_UV_Q`q')
	mat prate_q_UV[`q',1]= `r(head_1)'

	*summ food_poor_`m'_`q'[w=hh_wgt*hhsize]
	*tab food_poor_`m'_`q'[iw=hh_wgt*hhsize]
	*svy: tab food_poor_`m'_`q'
	
	
	*CBN Poverty line
	apoverty pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(m_pline) gen(CBN_poor_UV_Q`q')
	mat prate_q_UV[`q',2]= `r(head_1)'

	*summ CBN_poor_`m'_`q'[w=hh_wgt*hhsize]
	*tab CBN_poor_`m'_`q'[iw=hh_wgt*hhsize]
	*svy: tab CBN_poor_`m'_`q'
	
	*Consumption inequality
	inequal7 pcrexp[w=hh_wgt*hhsize] if quarter==`q'
	mat prate_q_UV[`q',3]= `r(gini)'
	
	mat prate_q_UV[`q',6]= `r(mld)'

	mat prate_q_UV[`q',7]= `r(cov)'
	
	*Decile Ratios (90/10;80/20;90/50;50/10)
	_pctile pcrexp[w=hh_wgt*hhsize] if quarter==`q', nq(100)
	return list
	scalar A1 = r(r90)/r(r10)
	di A1
	scalar A2 = r(r80)/r(r20)
	di A2
	scalar A3 = r(r90)/r(r50)
	di A3
	scalar A4 = r(r50)/r(r10)
	di A4
	scalar A5 = r(r95)/r(r5)
	di A5
	
	mat prate_q_UV[`q',8]= A1
	mat prate_q_UV[`q',9]= A2
	mat prate_q_UV[`q',10]= A3
	mat prate_q_UV[`q',11]= A4
	mat prate_q_UV[`q',12]= A5
	
	*Consumption Inequality and Standard errors
	svylorenz pcrexp if quarter==`q'
	 mat prate_q_UV[`q',4]= (e(gini))
	 mat prate_q_UV[`q',5]= (e(se_gini))

	




	save "$MS_Fout\poor_UV_`q'", replace 	
	
	}
	
	matlist prate_q_UV
	

	
	rename food_poor_UV_Q?? food_poor_UV_Q?
	rename CBN_poor_UV_Q?? CBN_poor_UV_Q?
	
	
	
	*-----------------------------------------------*	
		*Regional Poverty Rates
	*------------------------------------------------*
*Unit Value
		mat prate_UV = J(4,12,.)
		mat rownames prate_UV = Urban Rural-North Rural-Centre Rural-South
		mat colnames prate_UV = FoodPov CBNPov Gini Gini Gini-SE MLD CoV 90-10 80-20 90-50 50-10 95-5
	foreach r in 1 2 3 4{
	 
	 *Food Poverty
	apoverty pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(d_upline) gen(food_poor_UV_`r')
	mat prate_UV[`r',1] = `r(head_1)'
	
	*CBN Poverty
	apoverty pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(m_pline) gen(CBN_poor_UV_`r')
	mat prate_UV[`r',2] = `r(head_1)'

	*inequality
	inequal7 pcrexp[w=hh_wgt*hhsize] if urban_region==`r'
	mat prate_UV[`r',3] = `r(gini)'
	mat prate_UV[`r',6] = `r(mld)'
	mat prate_UV[`r',7] = `r(cov)'

	_pctile pcrexp[w=hh_wgt*hhsize] if urban_region==`r', nq(100)
	return list
	scalar A1 = r(r90)/r(r10)
	di A1
	scalar A2 = r(r80)/r(r20)
	di A2
	scalar A3 = r(r90)/r(r50)
	di A3
	scalar A4 = r(r50)/r(r10)
	di A4
	scalar A5 = r(r95)/r(r5)
	di A5
	
	mat prate_UV[`r',8]= A1
	mat prate_UV[`r',9]= A2
	mat prate_UV[`r',10]= A3
	mat prate_UV[`r',11]= A4
	mat prate_UV[`r',12]= A5
	
	*Inequality and SE
	svylorenz pcrexp if urban_region==`r'
	mat prate_UV[`r',4] = `e(gini)'
	mat prate_UV[`r',5] = `e(se_gini)'

	
		}
		
	matlist prate_UV
		
	putexcel A5=mat(prate_UV), names
	
*------------------------------------------------------------------------------*
*Market Price Analysis at different Item Coverage
*------------------------------------------------------------------------------*	
	*----------------------------------*	
	*National
	*----------------------------------*
	
	local row 20
	foreach ic in 100 90 80 70 60 50 {
	    
	gen FM`ic'_pcrexp = FM`ic'_rexpagg/hhsize
	replace FM`ic'_pcrexp =  FM`ic'_pcrexp/365
	
	*Food Poverty rates across diff item coverage at the National Level
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize], varpl(FM`ic'_d_upline) gen(FM`ic'_food_poor)
	putexcel A`row'=("National")
	putexcel B`row'=(r(head_1))
	
	
	*CBN Poverty rates across diff item coverage at the National Level
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize], varpl(FM`ic'_m_pline) gen(FM`ic'_CBN_poor)
	putexcel C`row'=(r(head_1))
	
	*Consumption inequality
	inequal7 FM`ic'_pcrexp[w=hh_wgt*hhsize]
	putexcel D`row'=(r(gini))
	putexcel G`row'=(r(mld))
	putexcel H`row'=(r(cov))

	putexcel I`row'=(`ic')

	*Decile Ratios (90/10;80/20;90/50;50/10)
	_pctile FM`ic'_pcrexp[w=hh_wgt*hhsize], nq(100)
	return list
	scalar A1 = r(r90)/r(r10)
	di A1
	scalar A2 = r(r80)/r(r20)
	di A2
	scalar A3 = r(r90)/r(r50)
	di A3
	scalar A4 = r(r50)/r(r10)
	di A4
	scalar A5 = r(r95)/r(r5)
	di A5	
	
	
	putexcel J`row'= A1
	putexcel K`row'= A2
	putexcel L`row'= A3
	putexcel M`row'= A4
	putexcel N`row'= A5

	putexcel O`row'=("Market Price")
	
	*Consumption Inequality and Standard errors
	svylorenz FM`ic'_pcrexp
	 putexcel E`row'= (e(gini))
	 putexcel F`row'= (e(se_gini))
	 
	local row = `row'+6
	

	}
	
	
	*----------------------------------*	
	*Regional
	*----------------------------------*		
*Regional Poverty rates at different IC level
foreach ic in 100 90 80 70 60 50 {		
		mat prate_`ic' = J(4,13,.)
		mat rownames prate_`ic' = Urban Rural-North Rural-Centre Rural-South 
		mat colnames prate_`ic' = FoodPov CBNPov Gini Gini Gini-SE MLD CoV IC 90-10 80-20 90-50 50-10 95-5
	foreach r in 1 2 3 4{
	 
	 *Food Poverty
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(FM`ic'_d_upline) gen(FM`ic'_food_poor_`r')
	mat prate_`ic'[`r',1] = `r(head_1)'
	
	*CBN Poverty
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(FM`ic'_m_pline) gen(FM`ic'_CBN_poor_`r')
	mat prate_`ic'[`r',2] = `r(head_1)'

	*inequality
	inequal7 FM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r'
	mat prate_`ic'[`r',3] = `r(gini)'
	mat prate_`ic'[`r',6] = `r(mld)'
	mat prate_`ic'[`r',7] = `r(cov)'
	
	_pctile FM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', nq(100)
	return list
	scalar A1 = r(r90)/r(r10)
	di A1
	scalar A2 = r(r80)/r(r20)
	di A2
	scalar A3 = r(r90)/r(r50)
	di A3
	scalar A4 = r(r50)/r(r10)
	di A4
	scalar A5 = r(r95)/r(r5)
	di A5
	
	mat prate_`ic'[`r',9]= A1
	mat prate_`ic'[`r',10]= A2
	mat prate_`ic'[`r',11]= A3
	mat prate_`ic'[`r',12]= A4
	mat prate_`ic'[`r',13]= A5

		*Inequality and SE
	svylorenz FM`ic'_pcrexp if urban_region==`r'
	mat prate_`ic'[`r',4] = `e(gini)'
	mat prate_`ic'[`r',5] = `e(se_gini)'
	
	mat prate_`ic'[`r',8] = `ic'

		}		
		
}	
		
putexcel A15=mat(prate_100), names
putexcel A21=mat(prate_90), names
putexcel A27=mat(prate_80), names
putexcel A33=mat(prate_70), names
putexcel A39=mat(prate_60), names
putexcel A45=mat(prate_50), names


	*----------------------------------*	
	*Quartely
	*----------------------------------*	
	foreach ic in 100 90 80 70 60 50 {	
		mat FM`ic'_prate_q = J(4,13,.)
		mat rownames FM`ic'_prate_q = Q1 Q2 Q3 Q4
		mat colnames FM`ic'_prate_q = FoodPov CBNPov Gini Gini Gini-SE MLD CoV IC 90-10 80-20 90-50 50-10 95-5
	
	foreach q in 1 2 3 4{
	*Food Poverty line
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(FM`ic'_d_upline) gen(FM`ic'_food_poor_Q`q')
	mat FM`ic'_prate_q[`q',1]= `r(head_1)'
	
	*CBN Poverty line
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl( FM`ic'_m_pline) gen(FM`ic'_CBN_poor_Q`q')
	mat FM`ic'_prate_q[`q',2]= `r(head_1)'

	*Consumption inequality
	inequal7 FM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q'
	mat FM`ic'_prate_q[`q',3]= `r(gini)'
	mat FM`ic'_prate_q[`q',6]= `r(mld)'
	mat FM`ic'_prate_q[`q',7]= `r(cov)'
	
	*Decile Ratios (90/10;80/20;90/50;50/10)
	_pctile FM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', nq(100)
	return list
	scalar A1 = r(r90)/r(r10)
	di A1
	scalar A2 = r(r80)/r(r20)
	di A2
	scalar A3 = r(r90)/r(r50)
	di A3
	scalar A4 = r(r50)/r(r10)
	di A4
	scalar A5 = r(r95)/r(r5)
	di A5
	
	mat FM`ic'_prate_q[`q',9]= A1
	mat FM`ic'_prate_q[`q',10]= A2
	mat FM`ic'_prate_q[`q',11]= A3
	mat FM`ic'_prate_q[`q',12]= A4
	mat FM`ic'_prate_q[`q',13]= A5

	*Consumption Inequality and Standard errors
	svylorenz FM`ic'_pcrexp if quarter==`q'
	 mat FM`ic'_prate_q[`q',4]= (e(gini))
	 mat FM`ic'_prate_q[`q',5]= (e(se_gini))

	mat FM`ic'_prate_q[`q',8]= `ic'
	
	

	save "$MS_Fout\FM`ic'_poor_`q'", replace 	
	
	mat list FM`ic'_prate_q
	}
	
		
		}
		
mat list FM100_prate_q
mat list FM90_prate_q		
mat list FM80_prate_q
mat list FM70_prate_q
mat list FM60_prate_q
mat list FM50_prate_q


	putexcel set "$MS_Tout\Table15_16_20_A19", sheet(Table16) modify
	
	putexcel A1 = matrix(prate_q_UV), names
	putexcel A7=mat(FM100_prate_q), names
	putexcel A12=mat(FM90_prate_q), names
	putexcel A17=mat(FM80_prate_q), names
	putexcel A22=mat(FM70_prate_q), names
	putexcel A27=mat(FM60_prate_q), names
	putexcel A32=mat(FM50_prate_q), names


	rename *_poor_UV_1? *_poor_UV_1
	rename *_poor_UV_2? *_poor_UV_2
	rename *_poor_UV_3? *_poor_UV_3
	rename *_poor_UV_4? *_poor_UV_4

	rename *_*_UV? *_*_UV
	
	rename *_CBN_poor? *_CBN_poor
	rename *_food_poor? *_food_poor

	rename *_food_poor_?? *_food_poor_?
	rename *_CBN_poor_?? *_CBN_poor_?
	
	rename *_food_poor_Q?? *_food_poor_Q?
	rename *_CBN_poor_Q?? *_CBN_poor_Q?	
*------------------------------------------------------------------------------*
*Test of difference in Food and CBN Poverty Rates at the National Level
*------------------------------------------------------------------------------*		

	*------------------------------------------------------------------------------*
	*Test of difference between market price and unit value at 100% item coverage
	*------------------------------------------------------------------------------*
	*Test for Difference in Means for Food Poverty rates  at the National level
	foreach i in food CBN{
	    
	  mat MP_UV_`i'_pov = J(1,5,.)
	  mat rownames  MP_UV_`i'_pov  = National
	  mat colnames  MP_UV_`i'_pov  =  est Tstat stderr pvalue  IC
	  matlist MP_UV_`i'_pov
	svy: mean `i'_poor_UV  FM100_`i'_poor
	lincom  FM100_`i'_poor-`i'_poor_UV 
	return list
	
	mat MP_UV_`i'_pov[1,1]= `r(estimate)'
	mat MP_UV_`i'_pov[1,2] = `r(t)'
	mat MP_UV_`i'_pov[1,3]= `r(se)'
	mat MP_UV_`i'_pov[1,4] = `r(p)'
	mat MP_UV_`i'_pov[1,5] = 100
			}
			
putexcel set "$MS_Tout\Table15_16_20_A19", sheet(Tables15_20_A19) modify
	putexcel W20=mat( MP_UV_food_pov), rownames 
	putexcel AC20=mat( MP_UV_CBN_pov), rownames	
			

	
	
	*Test for Difference at the quartely level for UV
*------------------------------------------------------------------------------*
*Test of difference in Food and CBN Poverty Rates at the quartely Level
*------------------------------------------------------------------------------*		

	*------------------------------------------------------------------------------*
	*Test of difference between market price and unit value at 100% item coverage
	*------------------------------------------------------------------------------*
	*Test for Difference in Means for Food Poverty rates  at the quartely level
	foreach i in   food CBN{
	  mat q_`i'_pov = J(4,5,.)
	  mat rownames q_`i'_pov = Q1 Q2 Q3 Q4 
	  mat colnames q_`i'_pov =  est Tstat stderr pvalue  IC
	  matlist q_`i'_pov
	  
	    foreach q in 1 2 3 4{
		    

	svy: mean `i'_poor_UV_Q`q'  FM100_`i'_poor_Q`q'
	lincom  FM100_`i'_poor_Q`q'-`i'_poor_UV_Q`q'  
	return list
	
	mat q_`i'_pov[`q',1]= `r(estimate)'
	mat q_`i'_pov[`q',2] = `r(t)'
	mat q_`i'_pov[`q',3]= `r(se)'
	mat q_`i'_pov[`q',4] = `r(p)'
	mat q_`i'_pov[`q',5] = 100
	
			}
	}
			
matlist q_food_pov
matlist q_CBN_pov
		
	putexcel set "$MS_Tout\Table15_16_20_A19", sheet(Table16) modify
	putexcel S7=mat(q_food_pov), names
	putexcel Y7=mat(q_CBN_pov), names
*---------------------------------------
*------------------------------------------------------------------------------*
	*Test of difference between market price approaches
	*Difference between complete item coverage and other levels of coverage
*------------------------------------------------------------------------------*
	
*Test for Difference in Means between diff item coverage levels (market price) for Food/CBN Poverty rates at the National level
	foreach i in  food CBN{
	foreach ic in 90 80 70 60 50 {
	    
	  mat MP100_MP`ic'_`i'_pov = J(1,4,.)
	  mat rownames  MP100_MP`ic'_`i'_pov  = National
	  mat colnames  MP100_MP`ic'_`i'_pov =  est Tstat stderr pvalue 
	  matlist MP100_MP`ic'_`i'_pov
	svy: mean FM100_`i'_poor  FM`ic'_`i'_poor
		
		lincom  FM100_`i'_poor -FM`ic'_`i'_poor
		return list
		
	mat MP100_MP`ic'_`i'_pov[1,1]= `r(estimate)'
	mat MP100_MP`ic'_`i'_pov[1,2] = `r(t)'
	mat MP100_MP`ic'_`i'_pov[1,3]= `r(se)'
	mat MP100_MP`ic'_`i'_pov[1,4] = `r(p)'
		
		local row = `row'+1
}	
	}
putexcel set "$MS_Tout\Table15_16_20_A19",sheet(Tables15_20_A19) modify
putexcel W26=mat(MP100_MP90_food_pov), rownames
putexcel W32=mat(MP100_MP80_food_pov), rownames
putexcel W38=mat(MP100_MP70_food_pov), rownames
putexcel W44=mat(MP100_MP60_food_pov), rownames
putexcel W50=mat(MP100_MP50_food_pov), rownames


putexcel AC26=mat(MP100_MP90_CBN_pov), rownames
putexcel AC32=mat(MP100_MP80_CBN_pov), rownames
putexcel AC38=mat(MP100_MP70_CBN_pov), rownames
putexcel AC44=mat(MP100_MP60_CBN_pov), rownames
putexcel AC50=mat(MP100_MP50_CBN_pov), rownames
		
*------------------------------------------------------------------------------*
*Test of regional difference between market price and unit value at 100% item coverage
*------------------------------------------------------------------------------*
		
	*Test for Difference in Means for Food and CBN Poverty rates  at the Regional level
	
	/*
	rename *_poor_UV_1? *_poor_UV_1
	rename *_poor_UV_2? *_poor_UV_2
	rename *_poor_UV_3? *_poor_UV_3
	rename *_poor_UV_4? *_poor_UV_4

	rename *_*_UV? *_*_UV
	
	rename *_CBN_poor? *_CBN_poor
	rename *_food_poor? *_food_poor

	rename *_food_poor_?? *_food_poor_?
	rename *_CBN_poor_?? *_CBN_poor_?
	
	rename *_food_poor_Q?? *_food_poor_Q?
	rename *_CBN_poor_Q?? *_CBN_poor_Q?
	*/
	

	foreach i in food CBN{
	mat reg_`i'_pov = J(4,4,.)
	 mat rownames reg_`i'_pov = Urban Rural-North Rural-Centre Rural-South 
	 mat colnames reg_`i'_pov =  est Tstat stderr pvalue  
	matlist reg_`i'_pov 
	  
	  foreach r in 1 2 3 4{
	svy: mean  FM100_`i'_poor_`r' `i'_poor_UV_`r'
	lincom  FM100_`i'_poor_`r'-`i'_poor_UV_`r' 
	return list
	mat reg_`i'_pov[`r',1]= `r(estimate)'
	mat reg_`i'_pov[`r',2] = `r(t)'
	mat reg_`i'_pov[`r',3]= `r(se)'
	mat reg_`i'_pov[`r',4] = `r(p)'
	
			}
			
	matlist reg_`i'_pov
	
}	
matlist reg_food_pov
matlist reg_CBN_pov

	putexcel set "$MS_Tout\Table15_16_20_A19",sheet(Tables15_20_A19) modify
	putexcel W15=mat(reg_food_pov), names
	putexcel AC15=mat(reg_CBN_pov), names
*------------------------------------------------------------------------------*
*Test for Difference in Means between 100% coverage and other item coverage levels (market price) for Food/CBN Poverty rates at the Regional level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 90 80 70 60 50{
	  mat reg_`i'_pov_`ic' = J(4,5,.)
	  mat rownames reg_`i'_pov_`ic' = Urban Rural-North Rural-Centre Rural-South 
	  mat colnames reg_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist reg_`i'_pov_`ic' 
	  
	
	  foreach r in 1 2 3 4{
	svy: mean  FM100_`i'_poor_`r' FM`ic'_`i'_poor_`r'
	lincom  FM100_`i'_poor_`r'-FM`ic'_`i'_poor_`r' 
	return list
	
	mat reg_`i'_pov_`ic'[`r',1]= `r(estimate)'
	mat reg_`i'_pov_`ic'[`r',2] = `r(t)'
	mat reg_`i'_pov_`ic'[`r',3]= `r(se)'
	mat reg_`i'_pov_`ic'[`r',4] = `r(p)'
	mat reg_`i'_pov_`ic'[`r',5] = `ic'

			}
			}
	
}

foreach i in food CBN{
mat all_`i' = reg_`i'_pov_90,reg_`i'_pov_80,reg_`i'_pov_70, reg_`i'_pov_60, reg_`i'_pov_50
mat list all_`i'
}


putexcel W21=mat(reg_food_pov_90), names
putexcel W27=mat(reg_food_pov_80), names
putexcel W33=mat(reg_food_pov_70), names
putexcel W39=mat(reg_food_pov_60), names
putexcel W45=mat(reg_food_pov_50), names

putexcel AC21=mat(reg_CBN_pov_90), names
putexcel AC27=mat(reg_CBN_pov_80), names
putexcel AC33=mat(reg_CBN_pov_70), names
putexcel AC39=mat(reg_CBN_pov_60), names
putexcel AC45=mat(reg_CBN_pov_50), names



*------------------------------------------------------------------------------*
*Test for Difference in Means between 100% coverage and other item coverage levels (market price) for Food/CBN Poverty rates at the Quarterly level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 90 80 70 60 50{
	  mat q_`i'_pov_`ic' = J(4,5,.)
	  mat rownames q_`i'_pov_`ic' = Q1 Q2 Q3 Q4 
	  mat colnames q_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist q_`i'_pov_`ic' 
	  
	
	  foreach q in 1 2 3 4{
	svy: mean  FM100_`i'_poor_Q`q' FM`ic'_`i'_poor_Q`q'
	lincom  FM100_`i'_poor_Q`q'-FM`ic'_`i'_poor_Q`q' 
	return list
	
	mat q_`i'_pov_`ic'[`q',1]= `r(estimate)'
	mat q_`i'_pov_`ic'[`q',2] = `r(t)'
	mat q_`i'_pov_`ic'[`q',3]= `r(se)'
	mat q_`i'_pov_`ic'[`q',4] = `r(p)'
	mat q_`i'_pov_`ic'[`q',5] = `ic'

			}
			}
	
}

foreach i in food CBN{
mat all_`i' = q_`i'_pov_90,q_`i'_pov_80,q_`i'_pov_70, q_`i'_pov_60, q_`i'_pov_50
mat list all_`i'
}



putexcel set "$MS_Tout\Table15_16_20_A19", sheet(Table16) modify

putexcel S12=mat(q_food_pov_90), names
putexcel S17=mat(q_food_pov_80), names
putexcel S22=mat(q_food_pov_70), names
putexcel S27=mat(q_food_pov_60), names
putexcel S32=mat(q_food_pov_50), names

putexcel Y12=mat(q_CBN_pov_90), names
putexcel Y17=mat(q_CBN_pov_80), names
putexcel Y22=mat(q_CBN_pov_70), names
putexcel Y27=mat(q_CBN_pov_60), names
putexcel Y32=mat(q_CBN_pov_50), names


*------------------------------------------------------------------------------*
*Test for Difference in Means between unit value and market price (at different item coverage levels) for Food/CBN Poverty rates at the Regional and National  level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 100 90 80 70 60 50{
	  mat geo_`i'_pov_`ic' = J(5,5,.)
	  mat rownames geo_`i'_pov_`ic' = Urban Rural-North Rural-Centre Rural-South National 
	  mat colnames geo_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist geo_`i'_pov_`ic' 
	  
	//Region
	foreach r in 1 2 3 4{
	svy: mean  `i'_poor_UV_`r' FM`ic'_`i'_poor_`r'
	lincom  FM`ic'_`i'_poor_`r'-`i'_poor_UV_`r'
	return list
	
	mat geo_`i'_pov_`ic'[`r',1]= `r(estimate)'
	mat geo_`i'_pov_`ic'[`r',2] = `r(t)'
	mat geo_`i'_pov_`ic'[`r',3]= `r(se)'
	mat geo_`i'_pov_`ic'[`r',4] = `r(p)'
	mat geo_`i'_pov_`ic'[`r',5] = `ic'
			}
			
	//National 		
	svy: mean  `i'_poor_UV FM`ic'_`i'_poor
	lincom  FM`ic'_`i'_poor-`i'_poor_UV		
	mat geo_`i'_pov_`ic'[5,1]= `r(estimate)'
	mat geo_`i'_pov_`ic'[5,2] = `r(t)'
	mat geo_`i'_pov_`ic'[5,3]= `r(se)'
	mat geo_`i'_pov_`ic'[5,4] = `r(p)'
	mat geo_`i'_pov_`ic'[5,5] = `ic'
		
			}
	
}

putexcel set "$MS_Tout\Table15_16_20_A19", sheet(Table15_other) modify

putexcel A1=mat(geo_food_pov_100), names
putexcel A7=mat(geo_food_pov_90), names
putexcel A13=mat(geo_food_pov_80), names
putexcel A19=mat(geo_food_pov_70), names
putexcel A25=mat(geo_food_pov_60), names
putexcel A31=mat(geo_food_pov_50), names

putexcel J1=mat(geo_CBN_pov_100), names
putexcel J7=mat(geo_CBN_pov_90), names
putexcel J13=mat(geo_CBN_pov_80), names
putexcel J19=mat(geo_CBN_pov_70), names
putexcel J25=mat(geo_CBN_pov_60), names
putexcel J31=mat(geo_CBN_pov_50), names

*------------------------------------------------------------------------------*
*Test for Difference in Means between unit value and market price (at different item coverage levels) for Food/CBN Poverty rates at the quarterly  level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 100 90 80 70 60 50{
	  mat q_`i'_pov_`ic' = J(4,5,.)
	  mat rownames q_`i'_pov_`ic' = Q1 Q2 Q3 Q4
	  mat colnames q_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist q_`i'_pov_`ic' 
	  
	//Region
	foreach q in 1 2 3 4{
	svy: mean  `i'_poor_UV_Q`q' FM`ic'_`i'_poor_Q`q'
	lincom  FM`ic'_`i'_poor_Q`q'-`i'_poor_UV_Q`q'
	return list
	
	mat q_`i'_pov_`ic'[`q',1]= `r(estimate)'
	mat q_`i'_pov_`ic'[`q',2] = `r(t)'
	mat q_`i'_pov_`ic'[`q',3]= `r(se)'
	mat q_`i'_pov_`ic'[`q',4] = `r(p)'
	mat q_`i'_pov_`ic'[`q',5] = `ic'
			}
						
	
}

}

putexcel set "$MS_Tout\Table15_16_20_A19", sheet(Table16_other) modify

putexcel A1=mat(q_food_pov_100), names
putexcel A7=mat(q_food_pov_90), names
putexcel A13=mat(q_food_pov_80), names
putexcel A19=mat(q_food_pov_70), names
putexcel A25=mat(q_food_pov_60), names
putexcel A31=mat(q_food_pov_50), names

putexcel J1=mat(q_CBN_pov_100), names
putexcel J7=mat(q_CBN_pov_90), names
putexcel J13=mat(q_CBN_pov_80), names
putexcel J19=mat(q_CBN_pov_70), names
putexcel J25=mat(q_CBN_pov_60), names
putexcel J31=mat(q_CBN_pov_50), names



putexcel set "$MS_Tout\Table15_16_20_A19", sheet(UVquarterly) modify
putexcel A1 = matrix(prate_q_UV), names
	

*******Comparison of both approaches***** 

*---------------------------------------------------------------------------	
	// cross-tabs of poverty from both approaches
	foreach ic in 100 /*90 80 70 60 50*/ {
	    *local ic 100
	tab FM`ic'_food_poor food_poor_UV[iw=hhsize*hh_wgt]

	tabout FM100_food_poor food_poor_UV[iw=popw] using "$MS_Tout\Table17_a.csv", cells(freq) style(csv) replace
	}
	
	foreach ic in 100 /*90 80 70 60 50*/ {
	tab FM`ic'_CBN_poor CBN_poor_UV[iw=hhsize*hh_wgt] 
	tabout FM100_CBN_poor CBN_poor_UV[iw=popw] using "$MS_Tout\Table18_a.csv", cells(freq) style(csv) replace
	}

	
	
import delimited "$MS_Tout\Table17_a.csv", clear
drop if _n<=3

replace v1= "99" if v1=="Total"

forvalues i= 2/4{
destring v`i', gen(v`i'_new) ignore(",")
}

keep v1 v*_new

forvalues i= 2/3{
summ v`i'_new if _n<3
gen v`i'_n = (v`i'_new/`r(sum)')*100
}

rename (v2_new v2_n v3_new v3_n v4_new) (Not_Food_poor NFP_prop Food_poor FP_prop Total)
replace v1 = "Not_Food_poor" if v1=="0" 
replace v1 = "Food_poor" if v1== "1"
replace v1 = "Total" if v1=="99"  
format Not_Food_poor NFP_prop Food_poor FP_prop Total %9.0f
order NFP_prop FP_prop, after(Food_poor)
export excel "$MS_Tout\Table17",firstrow(var) replace


*Table 18

import delimited "$MS_Tout\Table18_a.csv", clear
drop if _n<=3

replace v1= "99" if v1=="Total"

forvalues i= 2/4{
destring v`i', gen(v`i'_new) ignore(",")
}

keep v1 v*_new

forvalues i= 2/3{
summ v`i'_new if _n<3
gen v`i'_n = (v`i'_new/`r(sum)')*100
}

rename (v2_new v2_n v3_new v3_n v4_new) (Not_CBN_poor NCBNP_prop CBN_poor CBNP_prop Total)
replace v1 = "Not_CBN_poor" if v1=="0" 
replace v1 = "CBN_poor" if v1== "1"
replace v1 = "Total" if v1=="99"  
format Not_CBN_poor NCBNP_prop CBN_poor CBNP_prop Total %9.0f
order NCBNP_prop CBNP_prop, after(CBN_poor)
export excel "$MS_Tout\Table18", firstrow(var) replace

erase "$MS_Tout\Table17_a.csv"
erase "$MS_Tout\Table18_a.csv"
*---------------------------------------------------------------------------