
*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Data Development Grou[] 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Poverty headcount and nightlight relationship
** LAST UPDATE      Feb 2024
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
*Author: Niyi Alimi 
*-----------------------------------------------------------------------------
*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/



*------------------------------------------------------------------------------*
*Use Total Cons and poverty line from Unit Value approach and merge with
*Total Cons and Poverty line from Market Price approaches
*------------------------------------------------------------------------------*

	
use "$MS_Fout\tconsumption_UV_sw_FM_100.dta", clear
keep HHID-hh_wgt exp_cat01 rexp_cat01 rexpagg expagg expaggpc rexpaggpc

//Merge Unit Value Poverty Line
gen m=1
mmerge m using "$MS_Fout\pline_ihs5_UV_2215_sw_FM_100", type(n:1) ukeep(m_pline) 
mmerge m using "$MS_Fout\upline_ihs5_UV_2215_sw_FM_100", type(n:1) ukeep(d_upline) 

//Merge real cons and poverty line from diff item coverage assumptions
foreach ic in 50 60 70 80 90 100 {
mmerge HHID using "$MS_Fout\tconsumption_CD2_sw_FM_`ic'.dta", ukeep(rexpagg expagg  rexpaggpc  expaggpc rexp_cat01 exp_cat01) uname(FM`ic'_) //Merge real cons from diff item coverage assimptions

	mmerge  m using "$MS_Fout\pline_ihs5_CD2_2215_sw_FM_`ic'", type(n:1)  ukeep(m_pline) uname(FM`ic'_) //Merge poverty line
	mmerge  m using "$MS_Fout\upline_ihs5_CD2_2215_sw_FM_`ic'", type(n:1)  ukeep(d_upline) uname(FM`ic'_) //Merge poverty line
	
	
}	

*******************Generate quarterly variables********************************
			gen time=ym(syear, smonth)                                               
			gen quarter=.
			replace quarter=1 if inrange(time, 711,713)
			replace quarter=2 if inrange(time, 714,716)
			replace quarter=3 if inrange(time, 717,719)
			replace quarter=4 if inrange(time, 720,723)
			
			label var time "Year and Month of survey, GC"
			format %tm   time
			tab time quarter
	


		

	local row 2
*------------------------------------------------------------------------------*	
*UV analysis
*------------------------------------------------------------------------------*
	*----------------------------------*	
	*National
	*----------------------------------*

	gen pcrexp = rexpagg/hhsize
	replace pcrexp =  pcrexp/365
	gen popw = hh_wgt*hhsize
	svyset [w=popw]
	
	*Food Poverty rates across diff item coverage at the National Level
	apoverty pcrexp[w=hh_wgt*hhsize], varpl(d_upline) gen(food_poor_UV)
	

	*CBN Poverty rates across diff item coverage at the National Level
	apoverty pcrexp[w=hh_wgt*hhsize], varpl(m_pline) gen(CBN_poor_UV)
	
	 
	*----------------------------------*	
	*Quarterly
	*----------------------------------*		
		
	foreach q in 1 2 3 4{
	*Food Poverty line
	apoverty pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(d_upline) gen(food_poor_UV_Q`q')
		
	*CBN Poverty line
	apoverty pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(m_pline) gen(CBN_poor_UV_Q`q')

	
	
	
	save "$MS_Fout\poor_UV_`q'", replace 	
	
	}
	
	
	
	
	rename food_poor_UV_Q?? food_poor_UV_Q?
	rename CBN_poor_UV_Q?? CBN_poor_UV_Q?
	
	
	
	*-----------------------------------------------*	
		*Regional Poverty Rates
	*------------------------------------------------*
*Unit Value
		
	foreach r in 1 2 3 4{
	 
	 *Food Poverty
	apoverty pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(d_upline) gen(food_poor_UV_`r')
	
	*CBN Poverty
	apoverty pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(m_pline) gen(CBN_poor_UV_`r')

		
		}
		
	
	
*------------------------------------------------------------------------------*
*Market Price Analysis at different Item Coverage
*------------------------------------------------------------------------------*	
	*----------------------------------*	
	*National
	*----------------------------------*
	
	local row 3
	foreach ic in 100  {
	    
	gen FM`ic'_pcrexp = FM`ic'_rexpagg/hhsize
	replace FM`ic'_pcrexp =  FM`ic'_pcrexp/365
	
	*Food Poverty rates across diff item coverage at the National Level
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize], varpl(FM`ic'_d_upline) gen(FM`ic'_food_poor)
		
	
	*CBN Poverty rates across diff item coverage at the National Level
	apoverty FM`ic'_pcrexp[w=hh_wgt*hhsize], varpl(FM`ic'_m_pline) gen(FM`ic'_CBN_poor)
	
		local row = `row'+1
	}
	
	
	
	
keep HHID-d_upline FM100_rexpagg FM100_m_pline FM100_d_upline time quarter pcrexp popw food_poor_UV1 CBN_poor_UV1 FM100_pcrexp FM100_food_poor1 FM100_CBN_poor1 FM100_expagg FM100_rexpagg FM100_expaggpc FM100_rexpaggpc expagg rexpagg expaggpc rexpaggpc exp_cat01 rexp_cat01 FM100_exp_cat01 FM100_rexp_cat01 hhsize


gen exp_cat01_pc = exp_cat01/hhsize
gen rexp_cat01_pc = rexp_cat01/hhsize
gen FM100_exp_cat01_pc = FM100_exp_cat01/hhsize
gen FM100_rexp_cat01_pc = FM100_rexp_cat01/hhsize


summ food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1[w=popw]

	preserve
	insheet using "$MS_Fin\IHS5_VIIRS_monthly.csv", clear
	save "$MS_Fin\IHS5_VIIRS_monthly.dta", replace
	restore
	
rename HHID hhid

merge 1:1 hhid using "$MS_Fin\IHS5_VIIRS_monthly.dta", keepusing(avg_rad)
destring avg_rad,  force gen(avg_rad2)

save "$MS_Fout\poverty_lights.dta", replace

use "$MS_Fout\poverty_lights.dta", clear




use "$MS_Fout\poverty_lights.dta", clear
*-------------------------------------------------------------------------------*
					/*Household level regressions  */
*-------------------------------------------------------------------------------*
*Log real HH tot cons per capita (UV)
gen ln_rexpaggpc = ln(rexpaggpc) 

*Log real HH tot cons per capita (MP)
gen ln_FM100_rexpaggpc = ln(FM100_rexpaggpc) 

*Log real HH food cons per capita (UV)
gen ln_rexp_cat01_pc = ln(rexp_cat01_pc ) 

*Log real HH tot cons per capita (MP)
gen ln_FM100_rexp_cat01_pc  = ln(FM100_rexp_cat01_pc) 

* Log HH lights
gen ln_avg_rad2 = ln(avg_rad2)



*-------------------------------------------------------------------------------*
					/*EA level regressions  */
*-------------------------------------------------------------------------------*

collapse (mean) rexpaggpc rexp_cat01_pc  FM100_rexpaggpc  FM100_rexp_cat01_pc avg_rad2  food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1[w=popw] , by(ea_id)


rename (food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1)  (ea_food_pov_UV ea_CBN_pov_UV ea_food_pov_MP ea_CBN_pov_MP)

foreach i in ea_food_pov_UV ea_CBN_pov_UV ea_food_pov_MP ea_CBN_pov_MP{
	replace `i' = `i'*100
}

gen ln_ea_food_pov_UV = ln(ea_food_pov_UV)
gen ln_ea_CBN_pov_UV = ln(ea_CBN_pov_UV)
gen ln_ea_food_pov_MP = ln(ea_food_pov_MP)
gen ln_ea_CBN_pov_MP = ln(ea_CBN_pov_MP)

rename (rexpaggpc rexp_cat01_pc  FM100_rexpaggpc FM100_rexp_cat01_pc  avg_rad2) (ea_avg_rexpaggpc  ea_avg_rexp_cat01_pc ea_avg_FM100_rexpaggpc ea_avg_FM100_rexp_cat01_pc  ea_avg_rad2)


*Log EA average real cons per capita (UV)
gen ln_ea_avg_rexpaggpc = ln(ea_avg_rexpaggpc) 
gen ln_ea_avg_rexp_cat01_pc = ln(ea_avg_rexp_cat01_pc) 

*Log EA average real cons per capita (MP)
gen ln_ea_avg_FM100_rexpaggpc = ln(ea_avg_FM100_rexpaggpc) 
gen ln_ea_avg_FM100_rexp_cat01_pc = ln(ea_avg_FM100_rexp_cat01_pc) 

* Log EA average lights
gen ln_ea_avg_rad2 = ln(ea_avg_rad2)




*-------------------------------------------------------------------------------*
					/*TA level regressions Poverty Only  */ 
*-------------------------------------------------------------------------------*
use "$MS_Fout\poverty_lights.dta", clear

collapse (mean) rexpaggpc rexp_cat01_pc  FM100_rexpaggpc  FM100_rexp_cat01_pc avg_rad2  food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1[w=popw] , by(TA)


rename (food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1)  (ta_food_pov_UV ta_CBN_pov_UV ta_food_pov_MP ta_CBN_pov_MP)

foreach i in ta_food_pov_UV ta_CBN_pov_UV ta_food_pov_MP ta_CBN_pov_MP{
	replace `i' = `i'*100
}

gen ln_ta_food_pov_UV = ln(ta_food_pov_UV)
gen ln_ta_CBN_pov_UV = ln(ta_CBN_pov_UV)
gen ln_ta_food_pov_MP = ln(ta_food_pov_MP)
gen ln_ta_CBN_pov_MP = ln(ta_CBN_pov_MP)

rename (rexpaggpc rexp_cat01_pc  FM100_rexpaggpc FM100_rexp_cat01_pc  avg_rad2) (ta_avg_rexpaggpc  ta_avg_rexp_cat01_pc ta_avg_FM100_rexpaggpc ta_avg_FM100_rexp_cat01_pc  ta_avg_rad2)


*Log TA average real cons per capita (UV)
gen ln_ta_avg_rexpaggpc = ln(ta_avg_rexpaggpc) 
gen ln_ta_avg_rexp_cat01_pc = ln(ta_avg_rexp_cat01_pc) 

*Log TA average real cons per capita (MP)
gen ln_ta_avg_FM100_rexpaggpc = ln(ta_avg_FM100_rexpaggpc) 
gen ln_ta_avg_FM100_rexp_cat01_pc = ln(ta_avg_FM100_rexp_cat01_pc) 

* Log TA average lights
gen ln_ta_avg_rad2 = ln(ta_avg_rad2)


*-------------------------------------------------------------------------------*
					/*District level regressions Poverty Only */
*-------------------------------------------------------------------------------*
use "$MS_Fout\poverty_lights.dta", clear

collapse (mean) rexpaggpc rexp_cat01_pc  FM100_rexpaggpc  FM100_rexp_cat01_pc avg_rad2  food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1[w=popw] , by(district)


rename (food_poor_UV1 CBN_poor_UV1 FM100_food_poor1 FM100_CBN_poor1)  (dist_food_pov_UV dist_CBN_pov_UV dist_food_pov_MP dist_CBN_pov_MP)

foreach i in dist_food_pov_UV dist_CBN_pov_UV dist_food_pov_MP dist_CBN_pov_MP{
	replace `i' = `i'*100
}

gen ln_dist_food_pov_UV = ln(dist_food_pov_UV)
gen ln_dist_CBN_pov_UV = ln(dist_CBN_pov_UV)
gen ln_dist_food_pov_MP = ln(dist_food_pov_MP)
gen ln_dist_CBN_pov_MP = ln(dist_CBN_pov_MP)

rename (rexpaggpc rexp_cat01_pc  FM100_rexpaggpc FM100_rexp_cat01_pc  avg_rad2) (dist_avg_rexpaggpc  dist_avg_rexp_cat01_pc dist_avg_FM100_rexpaggpc dist_avg_FM100_rexp_cat01_pc  dist_avg_rad2)


*Log dist average real cons per capita (UV)
gen ln_dist_avg_rexpaggpc = ln(dist_avg_rexpaggpc) 
gen ln_dist_avg_rexp_cat01_pc = ln(dist_avg_rexp_cat01_pc) 

*Log dist average real cons per capita (MP)
gen ln_dist_avg_FM100_rexpaggpc = ln(dist_avg_FM100_rexpaggpc) 
gen ln_dist_avg_FM100_rexp_cat01_pc = ln(dist_avg_FM100_rexp_cat01_pc) 

* Log EA average lights
gen ln_dist_avg_rad2 = ln(dist_avg_rad2)


* Log dist Poverty Rates on Log dist Average Lights
reg ln_dist_CBN_pov_UV  ln_dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2) excel replace

reg ln_dist_CBN_pov_MP  ln_dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append

reg ln_dist_food_pov_UV  ln_dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append

reg ln_dist_food_pov_MP  ln_dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append

* dist Poverty Rates on dist Average Lights

reg dist_CBN_pov_UV  dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append

reg dist_CBN_pov_MP  dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append

reg dist_food_pov_UV  dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append

reg dist_food_pov_MP  dist_avg_rad2
outreg2 using "$MS_Tout\Table19", dec(2)  excel append





