
	
	*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Data Development Grou[] 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement (Alternative Market Price measures)
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Alchian-Allen Test
** LAST UPDATE      Jan 2024
*------------------------------------------------------------------------------*
*Author: Niyi Alimi (Consultant, Data Development Group) 
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/


 ******************Identifying Main Markets and Products**********************
	use "${MS_Fin}\MOD_D", clear
	contract  MarketID_Visit MarketID
	rename (MarketID_Visit MarketID) (marketid_visit marketid)
	summ _freq
	tempfile id
	save `id'
	
  	insheet using "${MS_Fin}\Main_market_product_IDS_NSO.csv", clear
	*rename marketid_visit MarketID_Visit
	mmerge marketid_visit using `id', type(1:1) ukeep(marketid)
	gen mainmarket2 = 1 if mainmarket=="YES"|mainmarket=="Yes"
	tab mainmarket mainmarket2
	drop mainmarket _merge
	
	br if  mainmarket==1
	sort region district
	*br _all
	save "${MS_Fin}\markets_name_main_product", replace
	
	
**************Distance matrices**********************************************
 
 	insheet using "${MS_Fin}\Market travel time\OA_travel_time_AA.csv", clear
	reshape long m, i(marketid2) j(dest_market)
	rename marketid2 marketid
	rename m mins
	save "${MS_Fin}\distance_matrix_AA", replace
	
	
	insheet using "${MS_Fin}\Market distance km\OA_distance_km_AA.csv", clear
	reshape long m, i(marketid2) j(dest_market)
	rename marketid2 marketid
	rename m km
	save "${MS_Fin}\distance_matrix_AA_km", replace
 
 *******************************Testing AA effect****************************
	
*----------------------------------------------------------*
*Table 5: Test of Alchian Allen effect	
*Output in Excel file "${MS_dout}\output_`i'"
*----------------------------------------------------------*
	
//Beef in NSanje, Blantyre and Lilongwe
local apprep replace
foreach m in 331 358 191{
	
	*local m 331
 use "${MS_Fint}\hicks_regression_spatial_070921_others", clear
 local i 504 //beef
 keep if inlist(item_code, "`i'")
	*local m 75

 
 drop x item_name item_code tag ln_price* price_raw
 
 gen mrk_a01a = district
 
	//get regions
	preserve
	use  "${MS_Fint}\TA_urban_rural", clear
	contract mrk_a01a mrk_region
	tempfile regions
	save `regions'
	restore
	
 mmerge mrk_a01a using `regions', type(n:1) ukeep(mrk_region)
 drop _merge
 
 reshape wide price_* , i(marketid) j(item_code_ori) string	
 
 foreach v of varlist price_imp* {
 count if `v' ~=.
 }
 
 summ price_*
   gen ratio_pr_imp= price_imp`i'B/price_imp`i'A
/*
 		 preserve
		use  "${MS_Fin}\distance_matrix_AA", clear
		keep if marketid ==`m'
		rename marketid origin
		rename dest_market marketid
		tempfile tt_`m'
		save `tt_`m''
		restore
*/		
		preserve
		*local m 331
		use  "${MS_Fin}\distance_matrix_AA_km", clear
		keep if marketid ==`m'
		rename marketid origin
		rename dest_market marketid
		tempfile km_`m'
		save `km_`m''
		restore

*mmerge marketid using `tt_`m'', ukeep (mins)
mmerge marketid using `km_`m'', ukeep (km)		
		
drop _merge 

replace km = km/100

*reg ratio_pr_imp mins //National

		if `m' ==331{
		label var ratio_pr_imp "NsanjeBoma market" 
			}
		if `m' ==358{
		label var ratio_pr_imp "BlantyreCity market" 
			}
		if `m' ==191{
		label var ratio_pr_imp "Lilongwe Market" 
			}
	
reg ratio_pr_imp km //National
outreg2 using "${MS_Tout}\Table5output_`i'", excel `apprep' label
local apprep append	
}

