*STATA Version : STATA 16
*------------------------------------------------------------------------------*
*Author: Niyi Alimi (Consultant, Data Development Group) 
*Project:  Test of Hicksian Seperability and comparing the sensitivity of consumption estimates, 
*price deflators, poverty line, and poverty estimates to using market prices versus unit value
*Do file series: 1/7 (Hicksian Seperability Analysis only)
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Data Development Group	 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Clean of Market Data and Hicksian Seperability
** LAST UPDATE      Jan 2022
** MARKET SURVEY    Reduced
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
* This do file prepares the IHS market survey and tests for Hicksian Seperability using the reduced sample
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/




*------------------------------------------------------------------------------*
*1. Clean Market Survey Data 
*------------------------------------------------------------------------------*

	*------------------------------------------------------------------------------*
	*1a. Classification of TA into urban or rural and creating Urban_region variable
	*------------------------------------------------------------------------------*

	clear all
	set more off
	use "${MS_Fin}\MOD_A.dta", clear
	sort MarketID
	tab mrk_a02a, miss 
	tab mrk_a02b, miss 

	*Check that no duplicate interms of region, TA code, TA name and actual month of survey
			preserve
			contract mrk_region mrk_a02a mrk_a02b act_mnth_yr_survey
			duplicates list mrk_region mrk_a02a mrk_a02b act_mnth_yr_survey // (region, TA_code,TA_name, act_mnth_yr_survey is unique)
			tab  mrk_a02b act_mnth_yr_survey
			restore
			
	*Changing urban/rural classification of some TA (based on discussion with Wilbert)                        
			replace reside = 1 if mrk_a02b == 10620
			replace reside = 2 if mrk_a02b == 31005
			replace reside = 1 if mrk_a02b == 30720
							 
	*Checking consitency of urban-rural status of Market ID						 
	collapse (mean) reside, by( dist_name mrk_a01a mrk_region mrk_a02a mrk_a02b act_mnth_yr_survey) //Confirmed after 0308 email with Wilbert

	tab mrk_region reside
	tab dist_name reside

	*Making naming adjustments to  market in TAcode=10302 where district name has been entered for TA code and vice versa
	tab mrk_a02a if mrk_a01a== 103 //Nkhata Bay is a district name not a TA name. Naming have gotten mixed up

	replace dist_name = "Nkhata Bay" if mrk_a01a== 103 & dist_name ~= "Nkhata Bay"
	replace mrk_a02a = "TA Fukamapiri" if mrk_a01a== 103 & mrk_a02a == "Nkhata Bay"
	tab dist_name reside


	collapse (mean) reside, by( dist_name mrk_a01a mrk_region mrk_a02a mrk_a02b)
	tab reside

		rename reside urban															
		//Urban/rural Identifier
		label var urban "Urban/rural"
		label define region_1 1 North 2 Central 3 South
		label val mrk_region region_1
		gen urban_region = .														
		//Rura/Urban by Region
		replace urban_region = 1 if urban==1
		replace urban_region = 2 if urban==2 & mrk_region==1
		replace urban_region = 3 if urban==2 & mrk_region==2
		replace urban_region = 4 if urban==2 & mrk_region==3
		label var urban_region "Rural/Urban division by region"
		label define urban_region_l 1 "Urban" 2 "Rural North" 3 "Rural Centre" 4 "Rural South"
		label val urban_region urban_region_l
		
*Markets by urban and rural status			
	save "${MS_Rint}\TA_urban_rural", replace

	*------------------------------------------------------------------------------*
	*1b. Merge collected Price and Qty (MOD_D) with market details (MOD_A) with TA classification (TA_urban_rural)
	*------------------------------------------------------------------------------*
	use "${MS_Fin}\MOD_A.dta", clear
	replace dist_name = "Nkhata Bay" if mrk_a01a== 103 & dist_name ~= "Nkhata Bay"
	replace mrk_a02a = "TA Fukamapiri" if mrk_a01a== 103 & mrk_a02a == "Nkhata Bay"

	//Merge Market_details (MOD_A) with TA urban_rural identifier
	merge m:1 dist_name mrk_a02a mrk_a02b  using   "${MS_Rint}\TA_urban_rural" ,keepusing(urban urban_region) 
	drop _merge
			
	//Merge  with prices and qty (MOD_D)
	merge 1:m MarketID MarketID_Visit  using  "${MS_Fin}\MOD_D.dta"
	sort _merge
	tab _merge

	//Generating string month_year and year variables 
	generate act_mnth_str = string(act_mnth_yr, "%tm")
	gen year= substr(act_mnth_str,1,4)

	//Naming needed variables
	clonevar marketid = 	MarketID
	clonevar marketid_visit = 	MarketID_Visit
	clonevar item_avail = 	D01  
	clonevar item_name= 	d1_a 
	clonevar item_code =   	d1_b
	clonevar unit =  		d1_c
	clonevar unit_code =   	d1_d
	clonevar weight1 = 		d1_g
	clonevar price1 = 		d1_h
	clonevar weight2 =		d1_i
	clonevar price2 = 		d1_j
	clonevar weight3 = 		d1_k
	clonevar price3 = 		d1_l
	clonevar item_unit_avail = d1_m
	clonevar region = 		mrk_region
	clonevar district = 	mrk_a01a
	clonevar date =			mrk_a08
	clonevar ta_name = 		mrk_a02a
	clonevar ta_code = 		mrk_a02b

	drop MarketID MarketID_Visit D01 d1_a d1_b d1_c d1_d d1_g d1_h d1_i d1_j d1_k d1_l d1_m mrk_region mrk_a01a mrk_a08 mrk_a09 mrk_a02a mrk_a02b mrk_a06 start_date end_date _merge

	//replace GROUNDNUT ROASTED as ROASTED GROUNDNUT  after conversation with Wilbert
	replace item_name  = "ROASTED GROUNDNUTS"  if item_name =="GROUNDNUT ROASTED"

	*------------------------------------------------------------------------------*
	*1c. Checking consistency of Market Data i.e. one one item_unit combination in each market for each actual month of visit
	/*(Cases where there are multiple visits to the same market in the actual month of visit are collapsed).
	Difference between planned and actual data collection could lead to multiple prices for each actual month*/
	*------------------------------------------------------------------------------*
		sort district marketid act_mnth_yr_survey item_code unit_code
		duplicates tag marketid act_mnth_yr_survey item_code item_name unit_code unit ta_code, gen(dup_id)
		tab dup_id, m
		br if dup_id==1

		tab marketid if dup_id==1

		collapse (mean) weight* price*, by(act_mnth_yr act_mnth_str marketid item_name item_code unit unit_code region district ta_code ta_name dist_name urban_region urban) //Check sensitivity to median

		sort district marketid act_mnth_yr_survey item_code unit_code

		br _all

		tab act_mnth_yr
		
		//Confirm consistency of data. 1 single item-unit combination in each market in each act month of survey
		duplicates tag marketid act_mnth_yr_survey act_mnth_str item_code item_name unit_code unit  region district urban_region urban ta_name ta_code, gen(dup_id)
		tab dup_id, m
		drop dup_id

	//Confirm consistency of region and district
	tab district region, miss

	//Confirm consistency of region and urban-region
	tab urban_region region , miss

	
*------------------------------------------------------------------------------*
*2. Cleaning Price and Weight Data
*------------------------------------------------------------------------------*

	*------------------------------------------------------------------------------*
	*2a. Cleaning Price and Weight Data
	*------------------------------------------------------------------------------*

	//Generate one single prices for each of the 3 possible price observations
	egen single_price = rowmedian(price1 price2 price3) // Use median price of 3 prices
	summ single_price, d
	
	//one extreme value for onion. Seems to be an error. Niyi set to missing
	br if single_price> 300000 & single_price <. 
	replace price1 =. if single_price> 300000 & single_price <.
	replace price3 =. if single_price> 300000 & single_price <.
	replace single_price=. if single_price> 300000 & single_price <.


	//Winsorisation of prices and weights to deal with outliers - Discussed with rest of the team
		*Prices winsorised at the item_code, unit_code and month levels (5th and 95th level).
		*Weights winsorised at the item_code, unit_code and urban_region level (5th and 95th level).  
	winsor2 single_price, suffix(_win2)  by(item_code unit_code  act_mnth_str) cuts (5 95)	
	winsor2 weight*, suffix(_win2)  by(item_code unit_code  urban_region) cuts (5 95)	
	winsor2 price*, suffix(_win2)  by(item_code unit_code  act_mnth_str) cuts (5 95)	

	//Clean some extreme values in survey weights by comparing with official IHS conversion factor
	
	//With offical IHS conversion factor, largest weight is around 22kg but some items have weights greater than 100KG
	summ weight*_win2, d 

	*These 2 items have implausible weights (cheese and KALONGONDA MUCUNA)
	br if	weight2_win2	>30	&	weight2_win2~=.
	
	*Use plausible weights attached to first price 
	replace weight2_win2 = weight1_win2 if	weight2_win2	>30	&	weight2_win2~=.

	*This item (PIGEONPEA (NANDOLO), FRESH) has implausible weight on third price (372kg)
	br if	weight3_win2	>30	&	weight3_win2~=.
	replace weight3_win2 = weight1_win2 if	weight3_win2	>30	&	weight3_win2~=.

	summ weight*_win2,d 

	br if weight2_win2> 2*weight1_win2 &  weight2_win2~=. //227 Observations where the second weight is twice the first weight

	* Generate median survey weight
	egen weight_median = rowmedian( weight*_win2 )

	*Previously SMALL ANIMAL – RABBIT, MICE, ETC had an implasible weight in this district but new weight cleaning has fixed that
	br if district==206 & item_code=="510"

	
	*Cleaning Prices and removing some outlier prices
	summ single_price_win2, d
	br if single_price_win2>5440 & single_price_win2<. //checking items with prices in the 99th percentile
	tab unit if single_price_win2>5440 & single_price_win2<. //They seem to be large items - may be plausible

	br if unit=="KILOGRAM" & single_price_win2>5440 & single_price_win2<. //They seem to be items which may be expensive and recorded prices are consistens across multiple price observations

	br if unit=="PIECE" & single_price_win2>2800 & single_price_win2<.
	tab item_name if unit=="PIECE" & single_price_win2>2800 & single_price_win2<. //Where unit is "piece" and it is in the 95th percentile. Plausible as prices are consistent across multiple prices and items


	br if single_price_win2> 15000 & single_price_win2 ~=. // Items with prices in the 90th percentile
	tab unit if single_price_win2> 15000 & single_price_win2 ~=. //Everything greater than 15000 (90th percentile) is Pail Large unit. Plausible


	br _all

	*generate missing prices
	gen miss =1 if single_price_win2 ==.
	tab miss, m

	*------------------------------------------------------------------------------*
	*2b. Merge in official IHS conversion factors
	*------------------------------------------------------------------------------*
		
	*Gen item_code variable for merging with conversion factors
	*Market price data has multiple elementary goods in some case. Conversion factors does not have this so need to create new item_code excluding the multiple elementary coding ( e.g letters - A B C)
	rename item_code item_code_ori // for merging with conversion factors
	gen code3 = substr(item_code_ori,1,3)
	gen x = substr(item_code_ori,4,1)
	tab x
	gen str item_code = code3 + x if inlist(x, "1","2","3")
	replace item_code = code3 if item_code==""
	tab1 item_code item_code_ori if item_code ~= item_code_ori // This is also a tentative list of multiple elementary goods for Hickisan seperability + UFA + Maize Grain + Cooking Oil
	destring item_code, replace
	drop x code3
	
		* Official IHS conversion factors 
			preserve
			use "${MS_Fin}\IHS_Conversion_Factor_2020.dta",clear
			*rename unit_code unit
			drop if unit_code=="23" //Drop other units
			*rename item_code item 
			rename factor_ihs5 factor
			keep region item_code item_name unit_code factor 
			save "${MS_Rint}\IHS_Conversion_Factor_2020_formerge.dta",replace
			restore
			
	*Merge data with official IHS conversion factor
	merge m:1 item_code unit_code region using  "${MS_Rint}\IHS_Conversion_Factor_2020_formerge.dta", keepusing(factor) 
	tab _merge

	*Drop items in official conversion factor file but not in Market survye
	tab item_code_ori if _merge==2
	drop if _merge==2 //items in official conversion factor only

	*replacing unit =1 for 1kg items and 1 litre items
	tab unit if unit_code=="1" 
	replace factor = 1 if unit_code=="1" & missing(factor) // 1 kilogram
	tab	item_code unit	if	unit_code=="15"
	replace factor = 1 if unit_code=="15" & (inlist(item_code,803) | inrange(item_code,850,852)) & missing(factor)	 //1 litre
	
	
	summ weight* price* if factor==.
	tab item_name unit if factor==. & price1~=. //Apart from Condensed Milk (Sachet) All remaining item-unit without conversion factors do not have weight or prices.
	tab item_code item_name if price1 ~=. & factor==.
	replace  factor=0.39 if item_code==711 & unit_code=="22" & _merge==1 & factor==. & single_price_win2 ~=. & inlist(region,1,2) ~=. //condensed milk. Sold in standard Satchet/Tube (22) and available in North and South. Weight is 0.39
	
	br  if price1 ~=. & factor==.

	/* all products with no conversion factor have no prices except for one obs in district (103) where Ground nut being sold in No.10 Plate does not have official conversion factor  */	


	summ factor weight_median,d
	*br if district==206 & item_code_ori=="510"



	br if  factor==. & single_price_win2 ~=.
	//1 change for  Groundnut No.10 Plate with no conversion factor in district 103 in March. Replace official factor with survey factoe
	replace factor = weight_median if factor==. & single_price_win2 ~=. 
	br _all



	summ single_price_win2, d	
	br  _all

		
			
	sort marketid item_code unit_code act_mnth_yr_survey


	*------------------------------------------------------------------------------*
	*2c. Generate actual month and actual year of Data collecion
	*------------------------------------------------------------------------------*
	split act_mnth_str, p(m)
	rename act_mnth_str1 syear
	rename act_mnth_str2 smonth
	destring smonth, replace
	label define month_l 1 January 2 February 3 March 4 April 5 May 6 June 7 July 8 August  9 September 10 October 11 November 12 December
	label val smonth month_l

	*------------------------------------------------------------------------------*
	*2d. Generate KG equivalent prices using survey weights
	*------------------------------------------------------------------------------*
	
	gen kg_equi_price_sw = single_price_win2/weight_median

	summ kg_equi_price_*,d

	br if kg_equi_price_sw >10000 & kg_equi_price_sw ~=.
	tab item_name if kg_equi_price_sw >10000 & kg_equi_price_sw ~=.

	*additional cleaning for some unplausible data in KG equivalent terms
	br if kg_equi_price_sw <=1 //2 observations(sugar-2kg packet and Rice-Large Pail) where  KG_equivalent price is less than 1MK. This is because of errors in price2 and price3 which affects the single(median price).
	
	*Set price2 and price3 to missing
	replace price2_win = . if kg_equi_price <1 & kg_equi_price ~=. 
	replace price3_win = . if kg_equi_price <1 & kg_equi_price ~=.
	replace kg_equi_price_sw = price1_win2/weight1_win2 if kg_equi_price_sw <=1 

	br _all


*------------------------------------------------------------------------------*
*Save KG equivalent prices using survey weights for Hicksian Seperability analysis
*------------------------------------------------------------------------------*
save "${MS_Rint}\kg_equi_price_hicksian_sep", replace



*------------------------------------------------------------------------------*
*Reduced Market Sample Size
*------------------------------------------------------------------------------*

*------------------------------------------------------------------------------*
* Dropping some markets
*Using markets with the highest number of observations and highest visits
*USing 2 markets per districts
*------------------------------------------------------------------------------*

use "${MS_Rint}\kg_equi_price_hicksian_sep", clear
drop price* weight* 
*drop single_price* 

gen missing = cond(kg_equ ==.,1,0)
tab missing, miss

collapse (median) kg_equi_price_sw single_price_win2 , by( marketid  item_code item_code_ori  item_name district ta_name ta_code region smonth syear urban_region dist_name ta_name )
gen missing = cond(kg_equ ==.,1,0)
tab missing, miss


tab miss region, miss

destring syear, replace
gen time = ym(syear, smonth)
	label var time "Actual Year and Month of survey, GC"
	format %tm   time
	
tab time miss, m

save "${MS_Rint}\kg_equi_price_item", replace
*

use "${MS_Rint}\kg_equi_price_item", clear

*count of numbers of observations
gen n=1 if kg_equi_price_sw ~=.



collapse (sum) n, by(marketid time district urban_region )

* calculate the number of time each market has been visited
egen mnth_visit = count(time), by(marketid)


save "${MS_Rint}\markets_mnth_visit", replace

*Count number of items per markets 
collapse (sum) tot_num_items = n, by(marketid district urban_region ) //time 
sort district tot_num_items 


*gen decile rank for districts with more than 10 markets
gen mkt_decile=.
local tempdist  101 103 104 105 201 202 204 205 206 207 208 209 210 301 302 303 304 305 307 308 309 310 311 312 315
*levelsof district, local(tempdist)
foreach i in `tempdist' {
	*local i 101
xtile mkt_decile_rank=tot_num_items if district==`i', nq(10)
replace mkt_decile= mkt_decile_rank if missing(mkt_decile) & district==`i'
drop mkt_decile_rank
}


*gen  rank for districts with less than 10 markets *102 106 107 203 306 313 314 //districts with less than 10 markets

egen mkt_rank = rank (tot_num_items), by(district)

egen highest_rank = max(mkt_rank), by(district) 
gen rank = mkt_rank/highest_rank
replace rank = rank*10
format rank %9.1f


replace mkt_decile = rank if mkt_decile==.

drop highest_rank rank mkt_rank
format mkt_decile %9.0f

*replace mkt_decile = 5 if district==106 //106 district has only one market. Keeping it for every reduced market version
save "${MS_Rint}\markets_decile_rank", replace


		*foreach d in 5 6 7 8 9{
		foreach d in 1 2 3 4 5{

		use "${MS_Rint}\markets_decile_rank", clear
			
			//Num of items and number of markets in full data
			preserve
			gen num_markets = 1
			collapse (sum) num_markets  tot_num_items , by(urban_region) 
			gen market_coverage = 100
			save "${MS_Rint}\num_market_items_urbanregion_FM", replace
			restore
		
		
			*local d 1
			keep if mkt_decile >`d'
			sort district marketid
			
			preserve
			gen num_markets = 1
			collapse (sum) num_markets  tot_num_items , by(urban_region) 
			gen market_coverage = 10-`d'
			save "${MS_Rint}\num_market_items_urbanregion_RM`d'", replace
			restore
			
		merge 1:m marketid district using "${MS_Rint}\markets_mnth_visit"
		
		save "${MS_Rint}\markets_mnth_visit_`d'", replace

		keep if _merge==3
		drop _merge
		
		sort district mkt_decile time marketid


		gsort district -mkt_decile time  marketid  
		drop mkt_decile


		duplicates list marketid district time

		keep marketid district time 


		//Market Visits and monthly-market visit count in Reduced Dataset
			preserve
			contract market district
			collapse (count) marketid (sum) _freq, by(district)
			restore

		merge 1:m marketid district time using "${MS_Rint}\kg_equi_price_item", keepusing(dist_name urban urban_region item_name item_code_ori item_code region district ta_name ta_code kg_equi_price_sw single_price_win2)

		keep if _merge==3
		tab marketid

		sort marketid time item_code_ori


		save "${MS_Rint}\kg_equi_price_hicksian_sep_top`d'", replace
		}
		
//Check spatial distribution of markets visited by reduction of market coverage
		
use "${MS_Rint}\num_market_items_urbanregion_FM"
*gen market_coverage = 10
foreach d in 1 2 3 4 5{
append using "${MS_Rint}\num_market_items_urbanregion_RM`d'"
}

gsort urban_region -market_coverage
save "${MS_Rint}\num_market_items_urbanregion_FM_RM_all", replace

/*
//item district smonth syear level		
		egen pr_s1 = median(kg_equi_price_sw), by(item_code_ori item_code item_name district time)
		count if pr_s1>0 & pr_s1 <.


		//item urban_region smonth syear level
		egen pr_s2 = median(kg_equi_price_sw), by(item_code_ori item_code item_name urban_region time)
		count if pr_s2>0 & pr_s2 <.		
				
		//item urban_region level		
		egen pr_s3 = median(kg_equi_price_sw), by(item_code_ori item_code item_name urban_region )
		count if pr_s3>0 & pr_s3 <.				
				
		//item level	
		egen pr_s4 = median(kg_equi_price_sw), by(item_code_ori item_code item_name)

		gen price_CD =pr_s1
		replace price_CD = pr_s2 if price_CD==.  & pr_s2 ~=. 
		replace price_CD= pr_s3 if price_CD==. & pr_s3 ~=. 
		replace price_CD = pr_s4 if price_CD==. & pr_s4 ~=. 

		summ price_CD kg_equi_price_sw,d
		br if kg_equi_price_sw==. & pr_s1 ~=.
		drop  pr_s*
		br _all
		
		br if price_CD==.

*/



*------------------------------------------------------------------------------*
*3a Examining Missing Data and Imputation
*------------------------------------------------------------------------------*

	*------------------------------------------------------------------------------*
	*3a Examining Missing Data
	*------------------------------------------------------------------------------*
	
	*foreach d in 5 6 7 8 9{
	foreach d in 1 2 3 4 5{
		*local d 5
	use "${MS_Rint}\kg_equi_price_hicksian_sep_top`d'", clear
	*use "${MS_Rint}\kg_equi_price_hicksian_sep2", clear

	*drop price* weight* _merge
	*drop single_price* factor

	*Proportion missing at item-unit level
	gen missing = cond(kg_equ ==.,1,0)
	tab missing, miss

	*Proportion missing at item level. Median of KG-Equivalent price across KG-equivalent prices
	collapse (median) kg_equi_price_sw, by( marketid item_code_ori  item_name district ta_name ta_code region time)
	gen missing = cond(kg_equ ==.,1,0)
	tab missing, miss

	*Proportion of missing item prices at region level
	tab miss region, miss

	*Proportion of missing item prices at month level
	tab time miss, m

	*------------------------------------------------------------------------------*
	*3b Imputation of Missing Data
	*------------------------------------------------------------------------------*
	*Imputation uses a Cascading median approach.
		*First level is median price in TA
		*Second level is median price in district 

	*First level is the median price in TA	
	egen pr_s1 = median(kg_equi_price_sw), by(time item_code_ori ta_code ta_name)
	count if kg_equi_price_sw==. & pr_s1 ~=.

	*Second level is the median price in district
	egen pr_s2 = median(kg_equi_price_sw), by(time item_code_ori district)
	count if kg_equi_price_sw==. & pr_s2~=.

	rename kg_equi_price_sw price_raw

	gen price_imp = price_raw



	*Generating Imputed price and imputed category
	gen imputed = 0 if price_imp~=.
	replace imputed = 1 if price_imp==. & pr_s1 ~=.
	replace price_imp = pr_s1 if price_imp==. & pr_s1 ~=.

	replace imputed = 1 if price_imp==. & pr_s2 ~=.
	replace price_imp = pr_s2 if price_imp==. & pr_s2 ~=.


	drop pr_s* miss

	*Proportion missing of imputed prices at item level
	gen missing = cond(price_imp ==.,1,0)
	tab missing, miss
	
	*Proportion missing of imputed prices at item and region level
	tab missing region, miss
	
	*Proportion missing of imputed prices at item and month level
	tab time missing , miss


	*Proportion from raw data (0), imputed (1) and still missing(.)
	tab imputed, miss
	tab imputed region, miss
	tab  time imputed , miss

	}

 
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

// For poverty work, Spatial price indicators and valuation of consumption
*foreach d in 5 6 7 8 9 {
foreach d in 1 2 3 4 5{

foreach v in sw  {
	local v sw
		use "${MS_Rint}\kg_equi_price_hicksian_sep_top`d'", clear
		*drop weight* price* single_price*

		//item district smonth syear level		
		egen pr_s1 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name district time)
		count if pr_s1>0 & pr_s1 <.


		//item urban_region time level
		egen pr_s2 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name urban_region time)
		count if pr_s2>0 & pr_s2 <.		
				
		//item urban_region level		
		egen pr_s3 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name urban_region )
		count if pr_s3>0 & pr_s3 <.				
				
		//item level	
		egen pr_s4 = median(kg_equi_price_`v'), by(item_code_ori item_code item_name)


		gen price_CD =pr_s1
		replace price_CD = pr_s2 if price_CD==.  & pr_s2 ~=. 
		replace price_CD= pr_s3 if price_CD==. & pr_s3 ~=. 
		replace price_CD = pr_s4 if price_CD==. & pr_s4 ~=. 

		summ price_CD kg_equi_price_sw,d
		br if kg_equi_price_sw==. & pr_s1 ~=.
		drop  pr_s*
		br _all
		
		// gen imputation tag
		
egen miss_raw= rowmiss(single_price_win2)
tab miss_raw, miss //Table 1 (Note on Handling Missing)

//What is the proportion missing in  in all item_unit combination with this type of imputation
egen miss_CD= rowmiss(price_CD)
tab miss_CD, miss
br if miss_CD==1 //No Yellow Maize in the country based on limited sample
tab item_name if miss_CD==1

gen imputed_CD= 1 if miss_raw==1 & price_CD ~=. //gen tag for imputed prices
replace imputed_CD= 0 if single_price_win2 ~=. // non-imputed/actual prices
replace imputed_CD=. if single_price_win2==. & price_CD==. //no price and no imputation

//what is the proportion imputed
tab imputed_CD, miss

summ price_CD,d
********************************************************************************************************		

save "${MS_Rint}\MP_price_base_`v'_top`d'.dta", replace

local v sw	
use "${MS_Rint}\MP_price_base_`v'_top`d'.dta", clear		

local v sw
		preserve	
		collapse (median) price_CD, by(item_name item_code_ori item_code urban_region district dist_name region time)
		sort  time  urban_region district region dist_name item_code   item_code_ori item_name
		summ price_CD, d
		br if price_CD>10000
		save "${MS_Rint}\MP_item_price_district_`v'_top`d'.dta", replace
		
		local v sw
		collapse (median) price_CD, by(  item_code_ori item_name item_code   urban_region time)
		sort  time urban_region  item_code   item_code_ori item_name
		save "${MS_Rint}\MP_item_price_region_`v'_top`d'.dta", replace
		restore

	
local v sw
use "${MS_Rint}\MP_item_price_district_`v'_top`d'.dta", clear

reshape wide price_CD, i(item_code_ori urban_region district) j(time)		


use "${MS_Rint}\MP_item_price_region_`v'_top`d'.dta", clear

reshape wide price_CD, i(item_code_ori urban_region ) j(time)


*------------------------------------------------------------------------------* 
*15) Save median prices by month for CPI 
*------------------------------------------------------------------------------*
local v sw 
use "${MS_Rint}\MP_price_base_`v'_top`d'.dta", clear
	
	*--------------------------------------------------------------------------*
	*15.1) At the regional-time level
	*--------------------------------------------------------------------------*
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD , by(urban_region item_code_ori item_code item_name time)
	sort urban_region time item_code_ori
	foreach i in time price_CD{
	rename `i' `i'_MP
	}
	order urban_region time item_code_ori
	save "${MS_Rint}\MP_reg_month_`v'_top`d'", replace
	restore

	*--------------------------------------------------------------------------*
	*15.2) At the national-time level
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  time)
	sort  time item_code_ori
	foreach i in time price_CD {
	rename `i' `i'_MP
	}
	order  time item_code_ori item_code	
	save "${MS_Rint}\MP_nat_month_`v'_top`d'", replace
	restore 
	
	*--------------------------------------------------------------------------*
	*15.3) Item regional
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  urban_region)
	sort   item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code
	save "${MS_Rint}\MP_reg_`v'_top`d'", replace
	restore 
	
	*--------------------------------------------------------------------------*
	*15.4) Item national
	*--------------------------------------------------------------------------*
	
	preserve
	drop if missing(price_CD)
	collapse (p50) price_CD , by(item_code_ori item_code item_name )
	sort   item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code	
	save "${MS_Rint}\MP_nat_`v'_top`d'", replace
	restore 	
	
	local v sw
	use "${MS_Rint}\MP_price_base_`v'_top`d'.dta", clear
	*format time %10.0g
	gen date = dofm(time)
	format date %d
	generate smonth = month(date)
	generate syear =  year(date)
	*--------------------------------------------------------------------------*
	*15.6) Item national reference month
	*--------------------------------------------------------------------------*
	preserve
	keep if inlist(smonth,4,5) & inlist(syear,2019)
	drop if missing(price_CD)
	collapse (p50) price_CD , by(item_code_ori item_code item_name )
	sort  item_code_ori
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code
	save "${MS_Rint}\MP_nat_rm_`v'_top`d'", replace
	restore 
	

	*--------------------------------------------------------------------------*
	*15.7) Item regional reference month
	*--------------------------------------------------------------------------*
	
	preserve
	keep if inlist(smonth,4,5) & inlist(syear,2019)
	drop if missing(price_CD)
	collapse (p50) price_CD, by(item_code_ori item_code item_name  urban_region)
	sort item_code_ori item_code
	foreach i in price_CD {
	rename `i' `i'_MP
	}
	order item_code_ori item_code	
	save "${MS_Rint}\MP_reg_rm_`v'_top`d'", replace
	restore 
	

******************Create concodances between Market survey and IHS**************
use "${MS_Rint}\MP_nat_`v'_top`d'", clear
cap rename item_code item
//Creating concordances for some items
replace item=102 if inlist(item_code_ori, "119","120") //Maize, yellow flour and Maizena to Ufa,refined flour(IHS)
replace item=301 if inlist(item_code_ori, "316A","316B","316C") //Beans Demetta, Kenyata and spotted to Bean, brown(IHS)
replace item=811 if inlist(item_code_ori, "806","807","808") //Cinnamon, Ginger and curry powder to Spices(IHS)
replace item=803 if inlist(item_code_ori, "850","851","852") //Sun flower, Vegetable and Soya Bean oil to Cooking Oil(IHS)

save "${MS_Rint}\MP_nat_`v'_top`d'", replace
	
}
}

	
/*------------------------------------------------------------------------------*	
*********compare prices between reduced sample prices and full sample price*****
*------------------------------------------------------------------------------*	


*------------------------------------------------------------------------------*	
*At the national level	
*------------------------------------------------------------------------------*	

*global MS_intF  "C:\Users\niyia\Documents\IHS5 Review\Market Survey Review\Intermediate files"

* Full Sample
use "${MS_Fint}\MP_nat_sw", clear

*Use Full sample
use "${MS_Fint}\MP_nat_sw", clear
rename 	price_CD_MP full_sample

*Merge with reduced sample
mmerge  item item_code_ori using "${MS_Rint}\MP_nat_sw", type(1:1) ukeep(price_CD_MP) uname(R_)
sort item_code_ori	item
rename  R_price_CD_MP reduced_sample
drop _merge

*Merge with reduced sample - top 50-90 markets
*foreach d in 5 6 7 8 9{
foreach d in 1 2 3 4 5{
	
mmerge  item item_code_ori using "${MS_Rint}\MP_nat_sw_top`d'", type(1:1) ukeep(price_CD_MP) uname(R`d'_)
sort item_code_ori	item
rename  R`d'_price_CD_MP reduced_sample_`d'
drop _merge
}

gen percent_diff = (reduced_sample-full_sample)/full_sample
summ percent_diff*
gsort -percent


*foreach d in 5 6 7 8 9{
foreach d in 1 2 3 4 5{

gen percent_diff_top`d' = (reduced_sample_`d'-full_sample)/full_sample
summ percent_diff_top`d'
gsort -percent_diff_top`d'
}


*------------------------------------------------------------------------------*	
*At the urban-region level
*------------------------------------------------------------------------------*	

* Full Sample	
use "${MS_Fint}\MP_reg_sw", clear
rename 	price_CD_MP full_sample	

*Merge with reduced sample
mmerge  item_code item_code_ori urban_region using "${MS_Rint}\MP_reg_sw", type(1:1) ukeep(price_CD_MP) uname(R_)
sort item_code_ori	item_code
rename  R_price_CD_MP reduced_sample
drop _merge
gen percent_diff = (reduced_sample-full_sample)/full_sample

*foreach d in 5 6 7 8 9{
foreach d in 1 2 3 4 5{

mmerge  item_code item_code_ori urban_region using "${MS_Rint}\MP_reg_sw_top`d'", type(1:1) ukeep(price_CD_MP) uname(R`d'_)
sort item_code_ori	item_code
rename  R`d'_price_CD_MP reduced_sample_`d'
drop _merge
gen percent_diff_`d' = (reduced_sample_`d'-full_sample)/full_sample
}


reshape wide full_sample reduced_sample*  percent_diff*, i(item_code_ori item_code) j(urban_region)	
order	item_code_ori item_code item_name full_sample* reduced_sample* percent_diff*

summ percent_diff*

foreach i in 1 2 3 4{
count if percent_diff`i' >0
gen more_exp`i' = r(N)

}


*foreach d in 5 6 7 8 9{
foreach d in 1 2 3 4 5{

count if percent_diff_`d'1 >0
gen more_exp`d'1 = r(N)

count if percent_diff_`d'2 >0
gen more_exp`d'2 = r(N)

count if percent_diff_`d'3 >0
gen more_exp`d'3 = r(N)

count if percent_diff_`d'4 >0
gen more_exp`d'4 = r(N)
}


*------------------------------------------------------------------------------*	
* At the district level	
*------------------------------------------------------------------------------*	
* Full Sample	
use "${MS_Fint}\MP_item_price_district_sw.dta", clear
rename 	price_CD full_sample	

//merge with reduced sample
mmerge  item_code item_code_ori urban_region district time using "${MS_Rint}\\MP_item_price_district_sw.dta", type(1:1) ukeep(price_CD) uname(R_)
rename  R_price_CD reduced_sample

//merge with reduced sample- top 50-90 markets
*foreach d in 5 6 7 8 9{
foreach d in 1 2 3 4 5{
mmerge  item_code item_code_ori urban_region district time using "${MS_Rint}\\MP_item_price_district_sw_top`d'.dta", type(1:1) ukeep(price_CD) uname(R`d'_)
sort item_code_ori	item_code	
rename  R`d'_price_CD reduced_sample_`d'
}