
*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Data Development Group	 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Poverty head count ratio
** LAST UPDATE      Jan 2022
** MARKET SURVEY    Reduced
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/


	
*------------------------------------------------------------------------------*
*Use Total Cons and poverty line from Unit Value approach and merge with
*Total Cons and Poverty line from Market Price approaches
*------------------------------------------------------------------------------*

*foreach d in 5 6 7 8 9 {
foreach d in 1 2 3 4 5{
use "$MS_Rout\tconsumption_UV_sw_RM`d'_100.dta", clear
keep HHID-hh_wgt rexpagg 

//Merge Unit Value Poverty Line
gen m=1
mmerge m using "$MS_Rout\pline_ihs5_UV_2215_sw_RM`d'_100", type(n:1) ukeep(m_pline) 
mmerge m using "$MS_Rout\upline_ihs5_UV_2215_sw_RM`d'_100", type(n:1) ukeep(d_upline) 

//Merge real cons and poverty line from diff item coverage assumptions
foreach ic in 50 60 70 80 90 100 {
mmerge HHID using "$MS_Rout\tconsumption_CD2_sw_RM`d'_`ic'.dta", ukeep(rexpagg) uname(RM`ic'_) //Merge real cons from diff item coverage assimptions

	mmerge  m using "$MS_Rout\pline_ihs5_CD2_2215_sw_RM`d'_`ic'", type(n:1)  ukeep(m_pline) uname(RM`ic'_) //Merge poverty line
	mmerge  m using "$MS_Rout\upline_ihs5_CD2_2215_sw_RM`d'_`ic'", type(n:1)  ukeep(d_upline) uname(RM`ic'_) //Merge poverty line
	
	
}	

*******************Generate quarterly variables********************************
			gen time=ym(syear, smonth)                                               
			gen quarter=.
			replace quarter=1 if inrange(time, 711,713)
			replace quarter=2 if inrange(time, 714,716)
			replace quarter=3 if inrange(time, 717,719)
			replace quarter=4 if inrange(time, 720,723)
			
			label var time "Year and Month of survey, GC"
			format %tm   time
			tab time quarter
	


		putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", replace
		putexcel A1=("Geography") 
		putexcel B1=("Item Coverage") 
		putexcel C1=("Method") 
		putexcel D1=("Food Pov rate")
		putexcel E1=("CBN Pov rate") 
		putexcel F1=("Inequality (Gini)")
		putexcel G1=("Inequality (Gini)")
		putexcel H1=("Inequality (Gini-SE)")

	local row 2
*------------------------------------------------------------------------------*	
*UV analysis
*------------------------------------------------------------------------------*
	*----------------------------------*	
	*National
	*----------------------------------*

	gen pcrexp = rexpagg/hhsize
	replace pcrexp =  pcrexp/365
	gen popw = hh_wgt*hhsize
	svyset [w=popw]
	
	*Food Poverty rates across diff item coverage at the National Level
	apoverty pcrexp[w=hh_wgt*hhsize], varpl(d_upline) gen(food_poor_UV)
	putexcel A`row'=("National")
	putexcel B`row'=(100)
	putexcel C`row'=("Unit Value")
	putexcel D`row'=(r(head_1))

	*CBN Poverty rates across diff item coverage at the National Level
	apoverty pcrexp[w=hh_wgt*hhsize], varpl(m_pline) gen(CBN_poor_UV)
	putexcel E`row'=(r(head_1))
	
	*Consumption inequality
	inequal7 pcrexp[w=hh_wgt*hhsize]
	putexcel F`row'=(r(gini))
	
	*Consumption Inequality and Standard errors
	svylorenz pcrexp
	 putexcel G`row'= (e(gini))
	 putexcel H`row'= (e(se_gini))

	 
	*----------------------------------*	
	*Quarterly
	*----------------------------------*		
		mat prate_q_UV = J(4,6,.)
		mat rownames prate_q_UV  = Q1 Q2 Q3 Q4
		mat colnames prate_q_UV  = FoodPov CBNPov Gini Gini Gini-SE Theil
	foreach q in 1 2 3 4{
	*Food Poverty line
	apoverty pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(d_upline) gen(food_poor_UV_Q`q')
	mat prate_q_UV[`q',1]= `r(head_1)'

	*summ food_poor_`m'_`q'[w=hh_wgt*hhsize]
	*tab food_poor_`m'_`q'[iw=hh_wgt*hhsize]
	*svy: tab food_poor_`m'_`q'
	
	
	*CBN Poverty line
	apoverty pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(m_pline) gen(CBN_poor_UV_Q`q')
	mat prate_q_UV[`q',2]= `r(head_1)'

	*summ CBN_poor_`m'_`q'[w=hh_wgt*hhsize]
	*tab CBN_poor_`m'_`q'[iw=hh_wgt*hhsize]
	*svy: tab CBN_poor_`m'_`q'
	
	*Consumption inequality
	inequal7 pcrexp[w=hh_wgt*hhsize] if quarter==`q'
	mat prate_q_UV[`q',3]= `r(gini)'
	mat prate_q_UV[`q',6]= `r(theil)'

	
	*Consumption Inequality and Standard errors
	svylorenz pcrexp if quarter==`q'
	 mat prate_q_UV[`q',4]= (e(gini))
	 mat prate_q_UV[`q',5]= (e(se_gini))


	save "$MS_Rout\poor_UV_`q'", replace 	
	
	}
	
	matlist prate_q_UV
	
	
	
	
	rename food_poor_UV_Q?? food_poor_UV_Q?
	rename CBN_poor_UV_Q?? CBN_poor_UV_Q?
	
	
	
	*-----------------------------------------------*	
		*Regional Poverty Rates
	*------------------------------------------------*
*Unit Value
		mat prate_UV = J(4,6,.)
		mat rownames prate_UV = Urban Rural-North Rural-Centre Rural-South
		mat colnames prate_UV = FoodPov CBNPov Gini Gini Gini-SE Theil
	foreach r in 1 2 3 4{
	 
	 *Food Poverty
	apoverty pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(d_upline) gen(food_poor_UV_`r')
	mat prate_UV[`r',1] = `r(head_1)'
	
	*CBN Poverty
	apoverty pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(m_pline) gen(CBN_poor_UV_`r')
	mat prate_UV[`r',2] = `r(head_1)'

	*inequality
	inequal7 pcrexp[w=hh_wgt*hhsize] if urban_region==`r'
	mat prate_UV[`r',3] = `r(gini)'
	mat prate_UV[`r',6] = `r(theil)'
	
	*Inequality and SE
	svylorenz pcrexp if urban_region==`r'
	mat prate_UV[`r',4] = `e(gini)'
	mat prate_UV[`r',5] = `e(se_gini)'
	
		}
		
	matlist prate_UV
		
	putexcel A10=mat(prate_UV), names
	
*------------------------------------------------------------------------------*
*Market Price Analysis at different Item Coverage
*------------------------------------------------------------------------------*	
	*----------------------------------*	
	*National
	*----------------------------------*
	
	local row 3
	foreach ic in 100 90 80 70 60 50 {
	    
	gen RM`ic'_pcrexp = RM`ic'_rexpagg/hhsize
	replace RM`ic'_pcrexp =  RM`ic'_pcrexp/365
	
	*Food Poverty rates across diff item coverage at the National Level
	apoverty RM`ic'_pcrexp[w=hh_wgt*hhsize], varpl(RM`ic'_d_upline) gen(RM`ic'_food_poor)
	putexcel A`row'=("National")
	putexcel B`row'=(`ic')
	putexcel C`row'=("Market Price")
	putexcel D`row'=(r(head_1))
	
	
	*CBN Poverty rates across diff item coverage at the National Level
	apoverty RM`ic'_pcrexp[w=hh_wgt*hhsize], varpl(RM`ic'_m_pline) gen(RM`ic'_CBN_poor)
	putexcel E`row'=(r(head_1))
	
	*Consumption inequality
	inequal7 RM`ic'_pcrexp[w=hh_wgt*hhsize]
	putexcel F`row'=(r(gini))
	
	*Consumption Inequality and Standard errors
	svylorenz RM`ic'_pcrexp
	 putexcel G`row'= (e(gini))
	 putexcel H`row'= (e(se_gini))
	local row = `row'+1
	}
	
	
	*----------------------------------*	
	*Regional
	*----------------------------------*		
*Regional Poverty rates at different IC level
foreach ic in 100 90 80 70 60 50 {		
		mat prate_`ic' = J(4,7,.)
		mat rownames prate_`ic' = Urban Rural-North Rural-Centre Rural-South 
		mat colnames prate_`ic' = FoodPov CBNPov Gini Gini Gini-SE Theil IC
	foreach r in 1 2 3 4{
	 
	 *Food Poverty
	apoverty RM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(RM`ic'_d_upline) gen(RM`ic'_food_poor_`r')
	mat prate_`ic'[`r',1] = `r(head_1)'
	
	*CBN Poverty
	apoverty RM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(RM`ic'_m_pline) gen(RM`ic'_CBN_poor_`r')
	mat prate_`ic'[`r',2] = `r(head_1)'

	*inequality
	inequal7 RM`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r'
	mat prate_`ic'[`r',3] = `r(gini)'
	mat prate_`ic'[`r',6] = `r(theil)'
	
	*Inequality and SE
	svylorenz RM`ic'_pcrexp if urban_region==`r'
	mat prate_`ic'[`r',4] = `e(gini)'
	mat prate_`ic'[`r',5] = `e(se_gini)'
	
	mat prate_`ic'[`r',7] = `ic'

		}		
		
}	
		
putexcel A15=mat(prate_100), names
putexcel A20=mat(prate_90), names
putexcel A25=mat(prate_80), names
putexcel A30=mat(prate_70), names
putexcel A35=mat(prate_60), names
putexcel A40=mat(prate_50), names


	*----------------------------------*	
	*Quartely
	*----------------------------------*	
	foreach ic in 100 90 80 70 60 50 {	
		mat RM`ic'_prate_q = J(4,7,.)
		mat rownames RM`ic'_prate_q = Q1 Q2 Q3 Q4
		mat colnames RM`ic'_prate_q = FoodPov CBNPov Gini Gini Gini-SE Theil IC
	
	foreach q in 1 2 3 4{
	*Food Poverty line
	apoverty RM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(RM`ic'_d_upline) gen(RM`ic'_food_poor_Q`q')
	mat RM`ic'_prate_q[`q',1]= `r(head_1)'
	
	*CBN Poverty line
	apoverty RM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl( RM`ic'_m_pline) gen(RM`ic'_CBN_poor_Q`q')
	mat RM`ic'_prate_q[`q',2]= `r(head_1)'

	*Consumption inequality
	inequal7 RM`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q'
	mat RM`ic'_prate_q[`q',3]= `r(gini)'
	mat RM`ic'_prate_q[`q',6]= `r(theil)'

	*Consumption Inequality and Standard errors
	svylorenz RM`ic'_pcrexp if quarter==`q'
	 mat RM`ic'_prate_q[`q',4]= (e(gini))
	 mat RM`ic'_prate_q[`q',5]= (e(se_gini))

	mat RM`ic'_prate_q[`q',7]= `ic'

	save "$MS_Rout\RM`d'_`ic'_poor_`q'", replace 	
	
	mat list RM`ic'_prate_q
	}
	
		
		}
		
mat list RM100_prate_q
mat list RM90_prate_q		
mat list RM80_prate_q
mat list RM70_prate_q
mat list RM60_prate_q
mat list RM50_prate_q


	putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", sheet(sheet2) modify
	putexcel A1=mat(RM100_prate_q), names
	putexcel A6=mat(RM90_prate_q), names
	putexcel A11=mat(RM80_prate_q), names
	putexcel A16=mat(RM70_prate_q), names
	putexcel A21=mat(RM60_prate_q), names
	putexcel A26=mat(RM50_prate_q), names


	rename *_poor_UV_1? *_poor_UV_1
	rename *_poor_UV_2? *_poor_UV_2
	rename *_poor_UV_3? *_poor_UV_3
	rename *_poor_UV_4? *_poor_UV_4

	rename *_*_UV? *_*_UV
	
	rename *_CBN_poor? *_CBN_poor
	rename *_food_poor? *_food_poor

	rename *_food_poor_?? *_food_poor_?
	rename *_CBN_poor_?? *_CBN_poor_?
	
	rename *_food_poor_Q?? *_food_poor_Q?
	rename *_CBN_poor_Q?? *_CBN_poor_Q?	
*------------------------------------------------------------------------------*
*Test of difference in Food and CBN Poverty Rates at the National Level
*------------------------------------------------------------------------------*		

	*------------------------------------------------------------------------------*
	*Test of difference between market price and unit value at 100% item coverage
	*------------------------------------------------------------------------------*
	*Test for Difference in Means for Food Poverty rates  at the National level
	foreach i in food CBN{
	    
	  mat MP_UV_`i'_pov = J(1,5,.)
	  mat rownames  MP_UV_`i'_pov  = National
	  mat colnames  MP_UV_`i'_pov  =  est Tstat stderr pvalue  IC
	  matlist MP_UV_`i'_pov
	svy: mean `i'_poor_UV  RM100_`i'_poor
	lincom  RM100_`i'_poor-`i'_poor_UV 
	return list
	
	mat MP_UV_`i'_pov[1,1]= `r(estimate)'
	mat MP_UV_`i'_pov[1,2] = `r(t)'
	mat MP_UV_`i'_pov[1,3]= `r(se)'
	mat MP_UV_`i'_pov[1,4] = `r(p)'
	mat MP_UV_`i'_pov[1,5] = 100
			}
			
putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", modify
	putexcel J1=mat( MP_UV_food_pov), names
	putexcel P1=mat( MP_UV_CBN_pov), names		
			

	
	
	*Test for Difference at the quartely level for UV
*------------------------------------------------------------------------------*
*Test of difference in Food and CBN Poverty Rates at the quartely Level
*------------------------------------------------------------------------------*		

	*------------------------------------------------------------------------------*
	*Test of difference between market price and unit value at 100% item coverage
	*------------------------------------------------------------------------------*
	*Test for Difference in Means for Food Poverty rates  at the quartely level
	foreach i in   food CBN{
	  mat q_`i'_pov = J(4,5,.)
	  mat rownames q_`i'_pov = Q1 Q2 Q3 Q4 
	  mat colnames q_`i'_pov =  est Tstat stderr pvalue  IC
	  matlist q_`i'_pov
	  
	    foreach q in 1 2 3 4{
		    

	svy: mean `i'_poor_UV_Q`q'  RM100_`i'_poor_Q`q'
	lincom  RM100_`i'_poor_Q`q'-`i'_poor_UV_Q`q'  
	return list
	
	mat q_`i'_pov[`q',1]= `r(estimate)'
	mat q_`i'_pov[`q',2] = `r(t)'
	mat q_`i'_pov[`q',3]= `r(se)'
	mat q_`i'_pov[`q',4] = `r(p)'
	mat q_`i'_pov[`q',5] = 100
	
			}
	}
			
matlist q_food_pov
matlist q_CBN_pov
		
	putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", sheet(sheet2) modify
	putexcel J1=mat(q_food_pov), names
	putexcel S1=mat(q_CBN_pov), names
*---------------------------------------
*------------------------------------------------------------------------------*
	*Test of difference between market price approaches
	*Difference between complete item coverage and other levels of coverage
*------------------------------------------------------------------------------*
	
*Test for Difference in Means between diff item coverage levels (market price) for Food/CBN Poverty rates at the National level
	foreach i in  food CBN{
	foreach ic in 90 80 70 60 50 {
	    
	  mat MP100_MP`ic'_`i'_pov = J(1,4,.)
	  mat rownames  MP100_MP`ic'_`i'_pov  = National
	  mat colnames  MP100_MP`ic'_`i'_pov =  est Tstat stderr pvalue 
	  matlist MP100_MP`ic'_`i'_pov
	svy: mean RM100_`i'_poor  RM`ic'_`i'_poor
		
		lincom  RM100_`i'_poor -RM`ic'_`i'_poor
		return list
		
	mat MP100_MP`ic'_`i'_pov[1,1]= `r(estimate)'
	mat MP100_MP`ic'_`i'_pov[1,2] = `r(t)'
	mat MP100_MP`ic'_`i'_pov[1,3]= `r(se)'
	mat MP100_MP`ic'_`i'_pov[1,4] = `r(p)'
		
		local row = `row'+1
}	
	}
putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", modify
putexcel W1=mat(MP100_MP90_food_pov), names
putexcel W4=mat(MP100_MP80_food_pov), names
putexcel W7=mat(MP100_MP70_food_pov), names
putexcel W11=mat(MP100_MP60_food_pov), names
putexcel W14=mat(MP100_MP50_food_pov), names


putexcel AB1=mat(MP100_MP90_CBN_pov), names
putexcel AB4=mat(MP100_MP80_CBN_pov), names
putexcel AB7=mat(MP100_MP70_CBN_pov), names
putexcel AB11=mat(MP100_MP60_CBN_pov), names
putexcel AB14=mat(MP100_MP50_CBN_pov), names
		
*------------------------------------------------------------------------------*
*Test of regional difference between market price and unit value at 100% item coverage
*------------------------------------------------------------------------------*
		
	*Test for Difference in Means for Food and CBN Poverty rates  at the Regional level
	
	/*
	rename *_poor_UV_1? *_poor_UV_1
	rename *_poor_UV_2? *_poor_UV_2
	rename *_poor_UV_3? *_poor_UV_3
	rename *_poor_UV_4? *_poor_UV_4

	rename *_*_UV? *_*_UV
	
	rename *_CBN_poor? *_CBN_poor
	rename *_food_poor? *_food_poor

	rename *_food_poor_?? *_food_poor_?
	rename *_CBN_poor_?? *_CBN_poor_?
	
	rename *_food_poor_Q?? *_food_poor_Q?
	rename *_CBN_poor_Q?? *_CBN_poor_Q?
	*/
	

	foreach i in food CBN{
	mat reg_`i'_pov = J(4,4,.)
	 mat rownames reg_`i'_pov = Urban Rural-North Rural-Centre Rural-South 
	 mat colnames reg_`i'_pov =  est Tstat stderr pvalue  
	matlist reg_`i'_pov 
	  
	  foreach r in 1 2 3 4{
	svy: mean  RM100_`i'_poor_`r' `i'_poor_UV_`r'
	lincom  RM100_`i'_poor_`r'-`i'_poor_UV_`r' 
	return list
	mat reg_`i'_pov[`r',1]= `r(estimate)'
	mat reg_`i'_pov[`r',2] = `r(t)'
	mat reg_`i'_pov[`r',3]= `r(se)'
	mat reg_`i'_pov[`r',4] = `r(p)'
	
			}
			
	matlist reg_`i'_pov
	
}	
matlist reg_food_pov
matlist reg_CBN_pov

	putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", sheet(sheet3) modify
	putexcel A1=mat(reg_food_pov), names
	putexcel G1=mat(reg_CBN_pov), names
*------------------------------------------------------------------------------*
*Test for Difference in Means between 100% coverage and other item coverage levels (market price) for Food/CBN Poverty rates at the Regional level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 90 80 70 60 50{
	  mat reg_`i'_pov_`ic' = J(4,5,.)
	  mat rownames reg_`i'_pov_`ic' = Urban Rural-North Rural-Centre Rural-South 
	  mat colnames reg_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist reg_`i'_pov_`ic' 
	  
	
	  foreach r in 1 2 3 4{
	svy: mean  RM100_`i'_poor_`r' RM`ic'_`i'_poor_`r'
	lincom  RM100_`i'_poor_`r'-RM`ic'_`i'_poor_`r' 
	return list
	
	mat reg_`i'_pov_`ic'[`r',1]= `r(estimate)'
	mat reg_`i'_pov_`ic'[`r',2] = `r(t)'
	mat reg_`i'_pov_`ic'[`r',3]= `r(se)'
	mat reg_`i'_pov_`ic'[`r',4] = `r(p)'
	mat reg_`i'_pov_`ic'[`r',5] = `ic'

			}
			}
	
}

foreach i in food CBN{
mat all_`i' = reg_`i'_pov_90,reg_`i'_pov_80,reg_`i'_pov_70, reg_`i'_pov_60, reg_`i'_pov_50
mat list all_`i'
}


putexcel J15=mat(reg_food_pov_90), names
putexcel J20=mat(reg_food_pov_80), names
putexcel J25=mat(reg_food_pov_70), names
putexcel J30=mat(reg_food_pov_60), names
putexcel J35=mat(reg_food_pov_50), names

putexcel S15=mat(reg_CBN_pov_90), names
putexcel S20=mat(reg_CBN_pov_80), names
putexcel S25=mat(reg_CBN_pov_70), names
putexcel S30=mat(reg_CBN_pov_60), names
putexcel S35=mat(reg_CBN_pov_50), names



*------------------------------------------------------------------------------*
*Test for Difference in Means between 100% coverage and other item coverage levels (market price) for Food/CBN Poverty rates at the Quarterly level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 90 80 70 60 50{
	  mat q_`i'_pov_`ic' = J(4,5,.)
	  mat rownames q_`i'_pov_`ic' = Q1 Q2 Q3 Q4 
	  mat colnames q_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist q_`i'_pov_`ic' 
	  
	
	  foreach q in 1 2 3 4{
	svy: mean  RM100_`i'_poor_Q`q' RM`ic'_`i'_poor_Q`q'
	lincom  RM100_`i'_poor_Q`q'-RM`ic'_`i'_poor_Q`q' 
	return list
	
	mat q_`i'_pov_`ic'[`q',1]= `r(estimate)'
	mat q_`i'_pov_`ic'[`q',2] = `r(t)'
	mat q_`i'_pov_`ic'[`q',3]= `r(se)'
	mat q_`i'_pov_`ic'[`q',4] = `r(p)'
	mat q_`i'_pov_`ic'[`q',5] = `ic'

			}
			}
	
}

foreach i in food CBN{
mat all_`i' = q_`i'_pov_90,q_`i'_pov_80,q_`i'_pov_70, q_`i'_pov_60, q_`i'_pov_50
mat list all_`i'
}



putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", sheet(sheet2) modify

putexcel J6=mat(q_food_pov_90), names
putexcel J11=mat(q_food_pov_80), names
putexcel J16=mat(q_food_pov_70), names
putexcel J21=mat(q_food_pov_60), names
putexcel J26=mat(q_food_pov_50), names

putexcel S6=mat(q_CBN_pov_90), names
putexcel S11=mat(q_CBN_pov_80), names
putexcel S16=mat(q_CBN_pov_70), names
putexcel S21=mat(q_CBN_pov_60), names
putexcel S26=mat(q_CBN_pov_50), names


*------------------------------------------------------------------------------*
*Test for Difference in Means between unit value and market price (at different item coverage levels) for Food/CBN Poverty rates at the Regional and National  level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 100 90 80 70 60 50{
	  mat geo_`i'_pov_`ic' = J(5,5,.)
	  mat rownames geo_`i'_pov_`ic' = Urban Rural-North Rural-Centre Rural-South National 
	  mat colnames geo_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist geo_`i'_pov_`ic' 
	  
	//Region
	foreach r in 1 2 3 4{
	svy: mean  `i'_poor_UV_`r' RM`ic'_`i'_poor_`r'
	lincom  RM`ic'_`i'_poor_`r'-`i'_poor_UV_`r'
	return list
	
	mat geo_`i'_pov_`ic'[`r',1]= `r(estimate)'
	mat geo_`i'_pov_`ic'[`r',2] = `r(t)'
	mat geo_`i'_pov_`ic'[`r',3]= `r(se)'
	mat geo_`i'_pov_`ic'[`r',4] = `r(p)'
	mat geo_`i'_pov_`ic'[`r',5] = `ic'
			}
			
	//National 		
	svy: mean  `i'_poor_UV RM`ic'_`i'_poor
	lincom  RM`ic'_`i'_poor-`i'_poor_UV		
	mat geo_`i'_pov_`ic'[5,1]= `r(estimate)'
	mat geo_`i'_pov_`ic'[5,2] = `r(t)'
	mat geo_`i'_pov_`ic'[5,3]= `r(se)'
	mat geo_`i'_pov_`ic'[5,4] = `r(p)'
	mat geo_`i'_pov_`ic'[5,5] = `ic'
		
			}
	
}

putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", sheet(sheet4) modify

putexcel A1=mat(geo_food_pov_100), names
putexcel A7=mat(geo_food_pov_90), names
putexcel A13=mat(geo_food_pov_80), names
putexcel A19=mat(geo_food_pov_70), names
putexcel A25=mat(geo_food_pov_60), names
putexcel A31=mat(geo_food_pov_50), names

putexcel J1=mat(geo_CBN_pov_100), names
putexcel J7=mat(geo_CBN_pov_90), names
putexcel J13=mat(geo_CBN_pov_80), names
putexcel J19=mat(geo_CBN_pov_70), names
putexcel J25=mat(geo_CBN_pov_60), names
putexcel J31=mat(geo_CBN_pov_50), names

*------------------------------------------------------------------------------*
*Test for Difference in Means between unit value and market price (at different item coverage levels) for Food/CBN Poverty rates at the quarterly  level
*------------------------------------------------------------------------------*

foreach i in food CBN{
	foreach ic in 100 90 80 70 60 50{
	  mat q_`i'_pov_`ic' = J(4,5,.)
	  mat rownames q_`i'_pov_`ic' = Q1 Q2 Q3 Q4
	  mat colnames q_`i'_pov_`ic' =  est Tstat stderr pvalue  IC
	  matlist q_`i'_pov_`ic' 
	  
	//Region
	foreach q in 1 2 3 4{
	svy: mean  `i'_poor_UV_Q`q' RM`ic'_`i'_poor_Q`q'
	lincom  RM`ic'_`i'_poor_Q`q'-`i'_poor_UV_Q`q'
	return list
	
	mat q_`i'_pov_`ic'[`q',1]= `r(estimate)'
	mat q_`i'_pov_`ic'[`q',2] = `r(t)'
	mat q_`i'_pov_`ic'[`q',3]= `r(se)'
	mat q_`i'_pov_`ic'[`q',4] = `r(p)'
	mat q_`i'_pov_`ic'[`q',5] = `ic'
			}
						
	
}

}

putexcel set "$MS_Rout\Nat_pov_estimate_RM`d'", sheet(sheet5) modify

putexcel A1=mat(q_food_pov_100), names
putexcel A7=mat(q_food_pov_90), names
putexcel A13=mat(q_food_pov_80), names
putexcel A19=mat(q_food_pov_70), names
putexcel A25=mat(q_food_pov_60), names
putexcel A31=mat(q_food_pov_50), names

putexcel J1=mat(q_CBN_pov_100), names
putexcel J7=mat(q_CBN_pov_90), names
putexcel J13=mat(q_CBN_pov_80), names
putexcel J19=mat(q_CBN_pov_70), names
putexcel J25=mat(q_CBN_pov_60), names
putexcel J31=mat(q_CBN_pov_50), names



	
}
*---------------------------------------------------------------------------