
*------------------------------------------------------------------------------*
** 	  National Statistical Office (NSO) & World Bank Poverty and Equity GP 	  **
*------------------------------------------------------------------------------*
** PROJECT			2019-20 Poverty measurement
** COUNTRY			Malawi
** COUNTRYCODE  	MWI
** YEAR				2019-2020
** SURVEY NAME		IHS5
** SECTION 			Comparison of Poverty head count ratio
** LAST UPDATE      Jan 2022
*------------------------------------------------------------------------------*


*------------------------------------------------------------------------------*
*Directory shortcuts (Uncomment only if running script individually)
*------------------------------------------------------------------------------*
/*
local path C:\Users\omoni\OneDrive\Previously\Documents\IHS5 Consumption Aggregate and Poverty Analysis\Malawi for review MP\Replication Package //change this path for replication
	
	
*Unit values
	gl folder "`path'\UV"
	gl din "$folder\Input files"
	gl dout "$folder\Output files"
	
* Full sample market price analysis
	gl marketsurvey "`path'\Market Price"
	gl MS_Fin "$marketsurvey\Input files"
	gl MS_Fout "$marketsurvey\1_Full sample\Output files"
	gl MS_Fint "$marketsurvey\1_Full sample\Intermediate files"
		
* Reduced Sample Market price analysis
	gl MS_Rin "$marketsurvey\Input files"
	gl MS_Rout "$marketsurvey\2_Reduced sample\Output files"
	gl MS_Rint "$marketsurvey\2_Reduced sample\Intermediate files"
	
* Comparison of full sample and reduced sample market price analysis
	gl compOut "$marketsurvey\3_Comparison\Output"
	gl compInt "$marketsurvey\3_Comparison\Intermediate"
	
*Tables in Draft
	gl MS_Tout "$marketsurvey\Tables"
*/

*------------------------------------------------------------------------------*
*Use Total Cons and poverty line from Unit Value approach and merge with
*Total Cons and Poverty line from Market Price approaches
*------------------------------------------------------------------------------*
*local ic 50
*foreach d in 5 6 7 8 9{
foreach d in 1 2 3 4 5 {
foreach ic in 100 {
use "$MS_Fout\tconsumption_UV_sw_FM_100.dta", clear //use unit value
keep HHID-hh_wgt rexpagg 


mmerge HHID using "$MS_Fout\tconsumption_CD2_sw_FM_`ic'.dta", ukeep(rexpagg) uname(FM`ic'_) //Full sample

mmerge HHID using "$MS_Rout\tconsumption_CD2_sw_RM`d'_`ic'.dta", ukeep(rexpagg) uname(RM`ic'_) //Reduced sample

gen m=1

//Merge Unit Value Poverty Line
mmerge m using "$MS_Rout\pline_ihs5_UV_2215_sw_RM`d'_100", type(n:1) ukeep(m_pline) 
mmerge m using "$MS_Rout\upline_ihs5_UV_2215_sw_RM`d'_100", type(n:1) ukeep(d_upline) 


//Merge Reduced Market Poverty Line
foreach mk in RM  {
	mmerge  m using "$MS_Rout\pline_ihs5_CD2_2215_sw_`mk'`d'_`ic'", type(n:1)  ukeep(m_pline) uname(`mk'`ic'_) //Merge poverty line
	mmerge  m using "$MS_Rout\upline_ihs5_CD2_2215_sw_`mk'`d'_`ic'", type(n:1)  ukeep(d_upline) uname(`mk'`ic'_) //Merge poverty line
}

//Merge Full Market Poverty Line
foreach mk in  FM {
	mmerge  m using "$MS_Fout\pline_ihs5_CD2_2215_sw_`mk'_`ic'", type(n:1)  ukeep(m_pline) uname(`mk'`ic'_) //Merge poverty line
	mmerge  m using "$MS_Fout\upline_ihs5_CD2_2215_sw_`mk'_`ic'", type(n:1)  ukeep(d_upline) uname(`mk'`ic'_) //Merge poverty line
}


//Generate quarterly variables
	gen time=ym(syear, smonth)                                               
	gen quarter=.
	replace quarter=1 if inrange(time, 711,713)
	replace quarter=2 if inrange(time, 714,716)
	replace quarter=3 if inrange(time, 717,719)
	replace quarter=4 if inrange(time, 720,723)
	
	label var time "Year and Month of survey, GC"
	format %tm   time
	tab time quarter



//Weights and Survey Set
gen popw = hh_wgt*hhsize
svyset [w=popw]		


//Gen daily PC Real Expenditure for each type of measure
gen pcrexp = rexpagg/hhsize
replace pcrexp =  pcrexp/365


foreach mk in FM RM{
    gen `mk'`ic'_pcrexp = `mk'`ic'_rexpagg/hhsize
	replace `mk'`ic'_pcrexp =   `mk'`ic'_pcrexp/365
}



*----------------------------------*	
*Quarterly
*----------------------------------*		

//Gen quarterly  food & CBN poverty rates for each market survey type and item coverage assumptions

foreach mk in FM RM {
    *local ic 100
		mat prate_q_comp_`mk'`ic' = J(4,5,.)
		mat rownames prate_q_comp_`mk'`ic'  = Q1 Q2 Q3 Q4
		mat colnames prate_q_comp_`mk'`ic'  = FoodPov CBNPov Gini Gini-SE IC
		mat list prate_q_comp_`mk'`ic'
	
	
//Calculate Poverty Rates
	foreach q in 1 2 3 4{
	*Food Poverty line
	apoverty `mk'`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(`mk'`ic'_d_upline) gen(food_poor_`mk'`ic'_Q`q')
	mat prate_q_comp_`mk'`ic'[`q',1]= `r(head_1)'
	
	*CBN Poverty line
	apoverty `mk'`ic'_pcrexp[w=hh_wgt*hhsize] if quarter==`q', varpl(`mk'`ic'_m_pline) gen(CBN_poor_`mk'`ic'_Q`q')
	mat prate_q_comp_`mk'`ic'[`q',2]= `r(head_1)'
	
	*Consumption Inequality and Standard errors
	svylorenz `mk'`ic'_pcrexp if quarter==`q'
	 mat prate_q_comp_`mk'`ic'[`q',3]= (e(gini))
	 mat prate_q_comp_`mk'`ic'[`q',4]= (e(se_gini))

	 mat prate_q_comp_`mk'`ic'[`q',5]= `ic'

	save "$compInt\poor_`mk'`d'`ic'_`q'", replace 	
	
	}
	}
	
	matlist prate_q_comp_FM`ic'
	matlist prate_q_comp_RM`ic'
	
//Put results in Table Matrix
	
		*local ic 100
		mat Q_final_`ic' = J(4,15,.)
		mat rownames Q_final_`ic'  = Q1 Q2 Q3 Q4
		mat colnames Q_final_`ic'  = FMFood RMFood FoodTstat FoodSe FoodPval FMCBN RMCBN CBNTstat CBNSe CBNPval FMGini FMGini-SE RMGini RMGini-SE IC
		mat list Q_final_`ic' 

		foreach q in 1 2 3 4 {
		mat Q_final_`ic'[`q',1] = prate_q_comp_FM`ic'[`q',1] 
		mat Q_final_`ic'[`q',2] = prate_q_comp_RM`ic'[`q',1] 



		mat Q_final_`ic'[`q',6] = prate_q_comp_FM`ic'[`q',2] 
		mat Q_final_`ic'[`q',7] = prate_q_comp_RM`ic'[`q',2]


		mat Q_final_`ic'[`q',11] = prate_q_comp_FM`ic'[`q',3] 
		mat Q_final_`ic'[`q',12] = prate_q_comp_FM`ic'[`q',4]

		mat Q_final_`ic'[`q',13] = prate_q_comp_RM`ic'[`q',3] 
		mat Q_final_`ic'[`q',14] = prate_q_comp_RM`ic'[`q',4]

		mat Q_final_`ic'[`q',15] = `ic'

		matlist Q_final_`ic' 

}



rename *_poor_*_Q??  *_poor_*_Q?

//Test of difference between Full Market Sample and Reduced Market Sample

*foreach ic in 100 90 80 70 60 50{
    	*local ic 50
foreach i in food CBN{
		
	  mat test_`i'_Qpov`ic' = J(4,5,.)
	  mat rownames test_`i'_Qpov`ic' = Q1 Q2 Q3 Q4
	  mat colnames test_`i'_Qpov`ic'  =  est Tstat stderr pvalue  IC
	  matlist  test_`i'_Qpov`ic'
	  
	 foreach q in 1 2 3 4 {
	svy: mean `i'_poor_RM`ic'_Q`q'   `i'_poor_FM`ic'_Q`q'
	lincom  `i'_poor_RM`ic'_Q`q'-`i'_poor_FM`ic'_Q`q'
	return list
	
	mat test_`i'_Qpov`ic'[`q',1]= `r(estimate)'
	mat test_`i'_Qpov`ic'[`q',2] = `r(t)'
	mat test_`i'_Qpov`ic'[`q',3]= `r(se)'
	mat test_`i'_Qpov`ic'[`q',4] = `r(p)'
	mat test_`i'_Qpov`ic'[`q',5] = `ic'
			}
			
		matlist test_`i'_Qpov`ic'

}
	matlist test_food_Qpov`ic'
	matlist test_CBN_Qpov`ic'

//Put results in Table Matrix
		foreach q in 1 2 3 4 {
		    foreach i in food{
		mat Q_final_`ic'[`q',3] =  test_`i'_Qpov`ic'[`q',2] 
		mat Q_final_`ic'[`q',4] =  test_`i'_Qpov`ic'[`q',3] 
		mat Q_final_`ic'[`q',5] =  test_`i'_Qpov`ic'[`q',4] 
		}
			foreach i in CBN{
		mat Q_final_`ic'[`q',8] =  test_`i'_Qpov`ic'[`q',2] 
		mat Q_final_`ic'[`q',9] =  test_`i'_Qpov`ic'[`q',3]
		mat Q_final_`ic'[`q',10] = test_`i'_Qpov`ic'[`q',4] 
							}

		matlist Q_final_`ic' 	
	
	
	}		



*----------------------------------*	
*Regional and National
*----------------------------------*

*local ic 50
foreach mk in FM RM {
    *local ic 100
		mat prate_r_comp_`mk'`ic' = J(5,5,.)
		mat rownames prate_r_comp_`mk'`ic'  = Urban Rural-North Rural-Centre Rural-South National 
		mat colnames prate_r_comp_`mk'`ic'  = FoodPov CBNPov Gini Gini-SE IC
		mat list prate_r_comp_`mk'`ic'
		
//Regions		
		foreach r in 1 2 3 4{
		 *Food Poverty
		apoverty `mk'`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(`mk'`ic'_d_upline) gen(`mk'`ic'_food_poor_`r')
		mat prate_r_comp_`mk'`ic'[`r',1] = `r(head_1)'
		
		*CBN Poverty
		apoverty `mk'`ic'_pcrexp[w=hh_wgt*hhsize] if urban_region==`r', varpl(`mk'`ic'_m_pline) gen(`mk'`ic'_CBN_poor_`r')
		mat prate_r_comp_`mk'`ic'[`r',2] = `r(head_1)'


		*Inequality and SE
		svylorenz `mk'`ic'_pcrexp if urban_region==`r'
		mat prate_r_comp_`mk'`ic'[`r',3] = `e(gini)'
		mat prate_r_comp_`mk'`ic'[`r',4] = `e(se_gini)'
		
		mat prate_r_comp_`mk'`ic'[`r',5] = `ic'

					}
//National					
		*Food Poverty
		apoverty `mk'`ic'_pcrexp[w=hh_wgt*hhsize] , varpl(`mk'`ic'_d_upline) gen(`mk'`ic'_food_poor)
		mat prate_r_comp_`mk'`ic'[5,1] = `r(head_1)'
			
		*CBN Poverty
		apoverty `mk'`ic'_pcrexp[w=hh_wgt*hhsize], varpl(`mk'`ic'_m_pline) gen(`mk'`ic'_CBN_poor)
		mat prate_r_comp_`mk'`ic'[5,2] = `r(head_1)'					
					
		*Inequality and SE
		svylorenz `mk'`ic'_pcrexp 
		mat prate_r_comp_`mk'`ic'[5,3] = `e(gini)'
		mat prate_r_comp_`mk'`ic'[5,4] = `e(se_gini)'
		
		mat prate_r_comp_`mk'`ic'[5,5] = `ic'				

}

//Put results in Table Matrix
		mat R_final_`ic'_`d' = J(5,15,.)
		mat rownames R_final_`ic'_`d' = Urban Rural-North Rural-Centre Rural-South National 
		mat colnames R_final_`ic'_`d' = FMFood RMFood FoodTstat FoodSe FoodPval FMCBN RMCBN CBNTstat CBNSe CBNPval FMGini FMGini-SE RMGini RMGini-SE IC
		mat list R_final_`ic'_`d' 

		foreach r in 1 2 3 4 5{
		mat R_final_`ic'_`d'[`r',1] = prate_r_comp_FM`ic'[`r',1] 
		mat R_final_`ic'_`d'[`r',2] = prate_r_comp_RM`ic'[`r',1] 


		mat R_final_`ic'_`d'[`r',6] = prate_r_comp_FM`ic'[`r',2] 
		mat R_final_`ic'_`d'[`r',7] = prate_r_comp_RM`ic'[`r',2]


		mat R_final_`ic'_`d'[`r',11] = prate_r_comp_FM`ic'[`r',3] 
		mat R_final_`ic'_`d'[`r',12] = prate_r_comp_FM`ic'[`r',4]

		mat R_final_`ic'_`d'[`r',13] = prate_r_comp_RM`ic'[`r',3] 
		mat R_final_`ic'_`d'[`r',14] = prate_r_comp_RM`ic'[`r',4]

		mat R_final_`ic'_`d'[`r',15] = `ic'

		matlist R_final_`ic'_`d' 
		}

matlist R_final_`ic'_`d' 
*matlist R_final_100_1


//Regional
rename *_CBN_poor_??  *_CBN_poor_?
rename *_food_poor_??  *_food_poor_?

//National
rename  *_food_poor?   *_food_poor 
rename  *_CBN_poor?   *_CBN_poor 

//Test of difference between Full Market Sample and Reduced Market Sample


foreach i in food CBN{
		
	  mat test_`i'_Rpov`ic'_`d' = J(5,5,.)
	  mat rownames test_`i'_Rpov`ic'_`d' = Q1 Q2 Q3 Q4
	  mat colnames test_`i'_Rpov`ic'_`d' =  est Tstat stderr pvalue  IC
	  matlist  test_`i'_Rpov`ic'_`d'
	  
	 foreach r in 1 2 3 4 {
	svy: mean RM`ic'_`i'_poor_`r'   FM`ic'_`i'_poor_`r'
	lincom  RM`ic'_`i'_poor_`r'- FM`ic'_`i'_poor_`r'
	return list
	
	mat test_`i'_Rpov`ic'_`d'[`r',1]= `r(estimate)'
	mat test_`i'_Rpov`ic'_`d'[`r',2] = `r(t)'
	mat test_`i'_Rpov`ic'_`d'[`r',3]= `r(se)'
	mat test_`i'_Rpov`ic'_`d'[`r',4] = `r(p)'
	mat test_`i'_Rpov`ic'_`d'[`r',5] = `ic'
			}
			
		matlist test_`i'_Rpov`ic'_`d'
		
	svy: mean RM`ic'_`i'_poor   FM`ic'_`i'_poor
	lincom  RM`ic'_`i'_poor- FM`ic'_`i'_poor
	return list
	
	local r  5
	mat test_`i'_Rpov`ic'_`d'[`r',1]= `r(estimate)'
	mat test_`i'_Rpov`ic'_`d'[`r',2] = `r(t)'
	mat test_`i'_Rpov`ic'_`d'[`r',3]= `r(se)'
	mat test_`i'_Rpov`ic'_`d'[`r',4] = `r(p)'
	mat test_`i'_Rpov`ic'_`d'[`r',5] = `ic'


}
	matlist test_food_Rpov`ic'_`d'
	matlist test_CBN_Rpov`ic'_`d'
	

foreach r in 1 2 3 4 5 {
		    foreach i in food{
		mat R_final_`ic'_`d'[`r',3] =  test_`i'_Rpov`ic'_`d'[`r',2] 
		mat R_final_`ic'_`d'[`r',4] =  test_`i'_Rpov`ic'_`d'[`r',3] 
		mat R_final_`ic'_`d'[`r',5] =  test_`i'_Rpov`ic'_`d'[`r',4] 
		}
			foreach i in CBN{
		mat R_final_`ic'_`d'[`r',8] =  test_`i'_Rpov`ic'_`d'[`r',2] 
		mat R_final_`ic'_`d'[`r',9] =  test_`i'_Rpov`ic'_`d'[`r',3]
		mat R_final_`ic'_`d'[`r',10] = test_`i'_Rpov`ic'_`d'[`r',4] 
							}


}

matlist  R_final_`ic'_`d'


save  "$compInt\For_crosstabs`d'_`ic'", replace

}


*display results
foreach ic in /*5 6 7 8 9*/ 10{
matlist Q_final_`ic'0 
}


foreach ic in /*5 6 7 8 9*/ 10{
matlist R_final_`ic'0_`d' 
}

//Export results into Excel Sheet
putexcel set "$compOut\Comp_pov_estimate_RM`d'_FM", sheet(sheet1) modify

local row 1
foreach ic in 10 /*9 8 7 6 5*/{
matlist R_final_`ic'0_`d' 
putexcel A`row'=mat(R_final_`ic'0_`d'), names

local row = `row'+ 7

}


putexcel set "$compOut\Comp_pov_estimate_RM`d'_FM", sheet(sheet2) modify

local row 1
foreach ic in 10 {
matlist Q_final_`ic'0 
putexcel A`row'=mat(Q_final_`ic'0), names

local row = `row'+ 6

}
}

foreach d in 1 2 3 4 5{
matlist R_final_100_`d'
}

//Export results into Excel Sheet
putexcel set "$MS_Tout\Table22", sheet(sheet1) modify

local row 1
foreach d in 1 2 3 4 5{
matlist R_final_100_`d'

putexcel A`row'=mat(R_final_100_`d'), names

putexcel Q`row'= 100-`d'*10

local row = `row'+ 6

}

